@@ -35,7 +35,7 @@ import (
 	certificate2 "k8s.io/client-go/util/certificate"
 	aggregatorclient "k8s.io/kube-aggregator/pkg/client/clientset_generated/clientset"
 
-	exportv1 "kubevirt.io/api/export/v1alpha1"
+	exportv1 "kubevirt.io/api/export/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 	"kubevirt.io/client-go/log"
 	clientutil "kubevirt.io/client-go/util"
@@ -50,9 +50,8 @@ const (
 	defaultTlsKeyFilePath  = "/etc/virt-exportproxy/certificates/tls.key"
 
 	apiGroup           = "export.kubevirt.io"
-	apiVersion         = "v1alpha1"
+	apiVersions        = "v1alpha1|v1beta1"
 	exportResourceName = "virtualmachineexports"
-	gv                 = apiGroup + "/" + apiVersion
 )
 
 type exportProxyApp struct {
@@ -111,16 +110,16 @@ func (app *exportProxyApp) healthzHandler(w http.ResponseWriter, r *http.Request
 	io.WriteString(w, "OK")
 }
 
-var proxyPathMatcher = regexp.MustCompile(`^/api/` + gv + `/namespaces/([^/]+)/` + exportResourceName + `/([^/]+)/(.*)$`)
+var proxyPathMatcher = regexp.MustCompile(`^/api/` + apiGroup + "/" + "(" + apiVersions + ")" + `/namespaces/([^/]+)/` + exportResourceName + `/([^/]+)/(.*)$`)
 
 func (app *exportProxyApp) proxyHandler(w http.ResponseWriter, r *http.Request) {
 	match := proxyPathMatcher.FindStringSubmatch(r.URL.Path)
-	if len(match) != 4 {
+	if len(match) != 5 {
 		w.WriteHeader(http.StatusBadRequest)
 		return
 	}
 
-	key := fmt.Sprintf("%s/%s", match[1], match[2])
+	key := fmt.Sprintf("%s/%s", match[2], match[3])
 	obj, exists, err := app.exportInformer.GetStore().GetByKey(key)
 	if err != nil {
 		w.WriteHeader(http.StatusInternalServerError)
@@ -138,8 +137,8 @@ func (app *exportProxyApp) proxyHandler(w http.ResponseWriter, r *http.Request)
 		return
 	}
 
-	host := fmt.Sprintf("%s.%s.svc:443", export.Status.ServiceName, match[1])
-	targetPath := "/" + match[3]
+	host := fmt.Sprintf("%s.%s.svc:443", export.Status.ServiceName, match[2])
+	targetPath := "/" + match[4]
 
 	certPool, err := app.caManager.GetCurrent()
 	if err != nil {
