@@ -8,13 +8,8 @@ source "$(dirname "$0")/config.sh"
 TARGET_BRANCH=${1:-"main"}
 
 function latest_version() {
-    if [[ $TARGET_BRANCH == "main" ]]; then
-        curl --fail -s "https://api.github.com/repos/kubevirt/common-instancetypes/releases/latest" |
-            jq -r '.tag_name'
-    else
-        curl --fail -s "https://api.github.com/repos/kubevirt/common-instancetypes/releases?per_page=100" |
-            jq -r '.[] | select(.target_commitish == '\""${TARGET_BRANCH}"\"') | .tag_name' | head -n1
-    fi
+    curl --fail -s "https://api.github.com/repos/kubevirt/common-instancetypes/releases?per_page=100" |
+        jq -r '.[] | select(.target_commitish == '\""${TARGET_BRANCH}"\"') | .tag_name' | head -n1
 }
 
 function checksum() {
