@@ -120,7 +120,7 @@ _kubectl create -n ${namespace} -f ${MANIFESTS_OUT_DIR}/release/kubevirt-cr.yaml
 
 # Ensure the KubeVirt CR is created
 count=0
-until _kubectl -n kubevirt get kv kubevirt; do
+until _kubectl -n ${namespace} get kv kubevirt; do
     ((count++)) && ((count == 30)) && echo "KubeVirt CR not found" && exit 1
     echo "waiting for KubeVirt CR"
     sleep 1
@@ -128,7 +128,7 @@ done
 
 # Wait until KubeVirt is ready
 count=0
-until _kubectl wait -n kubevirt kv kubevirt --for condition=Available --timeout 5m; do
+until _kubectl wait -n ${namespace} kv kubevirt --for condition=Available --timeout 5m; do
     ((count++)) && ((count == 5)) && echo "KubeVirt not ready in time" && exit 1
     echo "Error waiting for KubeVirt to be Available, sleeping 1m and retrying"
     sleep 1m
