@@ -46,7 +46,9 @@ func DomainAttachmentByInterfaceName(vmiSpecIfaces []v1.Interface, networkBindin
 
 	domainAttachmentByInterfaceName := map[string]string{}
 	for _, iface := range vmiSpecIfaces {
-		if iface.Masquerade != nil || iface.Bridge != nil || iface.Macvtap != nil {
+		if iface.Masquerade != nil || iface.Bridge != nil || iface.DeprecatedMacvtap != nil {
+			// Macvtap is removed in v1.3.
+			// The macvtap scenario is tracking old VMIs that are still processed in the reconcile loop.
 			domainAttachmentByInterfaceName[iface.Name] = string(v1.Tap)
 		} else if iface.Binding != nil {
 			if domainAttachmentType, exist := domainAttachmentByPluginName[iface.Binding.Name]; exist {
@@ -58,7 +60,8 @@ func DomainAttachmentByInterfaceName(vmiSpecIfaces []v1.Interface, networkBindin
 }
 
 func BindingMigrationByInterfaceName(vmiSpecIfaces []v1.Interface,
-	networkBindings map[string]v1.InterfaceBindingPlugin) map[string]*cmdv1.InterfaceBindingMigration {
+	networkBindings map[string]v1.InterfaceBindingPlugin,
+) map[string]*cmdv1.InterfaceBindingMigration {
 	bindingMigrationByPluginName := map[string]*cmdv1.InterfaceBindingMigration{}
 	for name, binding := range networkBindings {
 		if binding.Migration != nil {
