@@ -78,8 +78,9 @@ var _ = Describe("VMI interfaces", func() {
 			InterfaceBindingMethod: v1.InterfaceBindingMethod{SRIOV: &v1.InterfaceSRIOV{}},
 		},
 		{
+			// Macvtap is removed in v1.3. This scenario is tracking old VMIs that are still processed in the reconcile loop.
 			Name:                   iface4,
-			InterfaceBindingMethod: v1.InterfaceBindingMethod{Macvtap: &v1.InterfaceMacvtap{}},
+			InterfaceBindingMethod: v1.InterfaceBindingMethod{DeprecatedMacvtap: &v1.DeprecatedInterfaceMacvtap{}},
 		},
 		{
 			Name:    iface5,
