@@ -78,7 +78,8 @@ func (n NetPod) discover(currentStatus *nmstate.Status) error {
 				return err
 			}
 
-		case vmiSpecIface.Passt != nil:
+		// passt is removed in v1.3. This scenario is tracking old VMIs that are still processed in the reconcile loop.
+		case vmiSpecIface.DeprecatedPasst != nil:
 			if !podIfaceExists {
 				return fmt.Errorf("pod link (%s) is missing", podIfaceName)
 			}
@@ -87,7 +88,8 @@ func (n NetPod) discover(currentStatus *nmstate.Status) error {
 				return err
 			}
 
-		case vmiSpecIface.Slirp != nil:
+		// SLIRP is removed in v1.3. This scenario is tracking old VMIs that are still processed in the reconcile loop.
+		case vmiSpecIface.DeprecatedSlirp != nil:
 			if !podIfaceExists {
 				return fmt.Errorf("pod link (%s) is missing", podIfaceName)
 			}
@@ -105,7 +107,8 @@ func (n NetPod) discover(currentStatus *nmstate.Status) error {
 			}
 
 		// Skip the discovery for all other known network interface bindings.
-		case vmiSpecIface.Macvtap != nil:
+		// Macvtap is removed in v1.3. This scenario is tracking old VMIs that are still processed in the reconcile loop.
+		case vmiSpecIface.DeprecatedMacvtap != nil:
 		case vmiSpecIface.SRIOV != nil:
 		default:
 			return fmt.Errorf("undefined binding method: %v", vmiSpecIface)
