@@ -22,6 +22,7 @@ package mutators
 import (
 	"encoding/json"
 	"fmt"
+	"net/http"
 	rt "runtime"
 
 	"k8s.io/utils/pointer"
@@ -42,6 +43,8 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
+	"kubevirt.io/kubevirt/pkg/libvmi"
+	kvpointer "kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/pkg/testutils"
 	"kubevirt.io/kubevirt/pkg/virt-api/webhooks"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
@@ -49,9 +52,9 @@ import (
 	"kubevirt.io/kubevirt/pkg/virt-operator/resource/generate/components"
 )
 
-var privilegedUser = fmt.Sprintf("%s:%s:%s:%s", "system", "serviceaccount", "kubevirt", components.ControllerServiceAccountName)
-
 var _ = Describe("VirtualMachineInstance Mutator", func() {
+	const kubeVirtNamespace = "kubevirt"
+
 	var vmi *v1.VirtualMachineInstance
 	var preset *v1.VirtualMachineInstancePreset
 	var presetInformer cache.SharedIndexInformer
@@ -131,11 +134,11 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		patchOps := []patch.PatchOperation{
 			{Value: vmiStatus},
 		}
-		err = json.Unmarshal(resp.Patch, &patchOps)
-		Expect(err).ToNot(HaveOccurred())
-		if len(patchOps) == 0 {
+		if resp.Patch == nil {
 			return &newVMI.Status
 		}
+		err = json.Unmarshal(resp.Patch, &patchOps)
+		Expect(err).ToNot(HaveOccurred())
 
 		return vmiStatus
 	}
@@ -152,47 +155,53 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 			},
 		}
 
-		selector := k8smetav1.LabelSelector{MatchLabels: map[string]string{"test": "test"}}
-		preset = &v1.VirtualMachineInstancePreset{
-			ObjectMeta: k8smetav1.ObjectMeta{
-				Name: "test-preset",
-			},
-			Spec: v1.VirtualMachineInstancePresetSpec{
-				Domain: &v1.DomainSpec{
-					CPU: &v1.CPU{Cores: 4},
-				},
-				Selector: selector,
-			},
-		}
-		presetInformer, _ = testutils.NewFakeInformerFor(&v1.VirtualMachineInstancePreset{})
-		presetInformer.GetIndexer().Add(preset)
-
 		mutator = &VMIsMutator{}
 		mutator.ClusterConfig, _, kvInformer = testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{})
+
+		presetInformer, _ = testutils.NewFakeInformerFor(&v1.VirtualMachineInstancePreset{})
 		mutator.VMIPresetInformer = presetInformer
+		mutator.KubeVirtServiceAccounts = webhooks.KubeVirtServiceAccounts(kubeVirtNamespace)
 	})
 
-	It("should apply presets on VMI create", func() {
-		_, vmiSpec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
-		Expect(vmiSpec.Domain.CPU).ToNot(BeNil())
-		Expect(vmiSpec.Domain.CPU.Cores).To(Equal(uint32(4)))
-	})
+	Context("with presets", func() {
+		BeforeEach(func() {
+			selector := k8smetav1.LabelSelector{MatchLabels: map[string]string{"test": "test"}}
+			preset = &v1.VirtualMachineInstancePreset{
+				ObjectMeta: k8smetav1.ObjectMeta{
+					Name: "test-preset",
+				},
+				Spec: v1.VirtualMachineInstancePresetSpec{
+					Domain: &v1.DomainSpec{
+						CPU: &v1.CPU{Cores: 4},
+					},
+					Selector: selector,
+				},
+			}
+			presetInformer.GetIndexer().Add(preset)
+		})
 
-	It("should include deprecation warning in response when presets are applied to VMI", func() {
-		resp := admitVMI(vmi.Spec.Architecture)
-		Expect(resp.Allowed).To(BeTrue())
-		Expect(resp.Warnings).ToNot(BeEmpty())
-		Expect(resp.Warnings[0]).To(ContainSubstring("VirtualMachineInstancePresets is now deprecated"))
+		It("should apply presets on VMI create", func() {
+			_, vmiSpec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+			Expect(vmiSpec.Domain.CPU).ToNot(BeNil())
+			Expect(vmiSpec.Domain.CPU.Cores).To(Equal(uint32(4)))
+		})
+
+		It("should include deprecation warning in response when presets are applied to VMI", func() {
+			resp := admitVMI(vmi.Spec.Architecture)
+			Expect(resp.Allowed).To(BeTrue())
+			Expect(resp.Warnings).ToNot(BeEmpty())
+			Expect(resp.Warnings[0]).To(ContainSubstring("VirtualMachineInstancePresets is now deprecated"))
+		})
 	})
 
 	DescribeTable("should apply defaults on VMI create", func(arch string, cpuModel string) {
 		// no limits wanted on this test, to not copy the limit to requests
 
 		if arch == "" {
-			if rt.GOARCH == "amd64" {
-				cpuModel = v1.DefaultCPUModel
-			} else {
+			if rt.GOARCH == "arm64" {
 				cpuModel = v1.CPUModeHostPassthrough
+			} else {
+				cpuModel = v1.DefaultCPUModel
 			}
 		}
 		_, vmiSpec, _ := getMetaSpecStatusFromAdmit(arch)
@@ -201,6 +210,8 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 			Expect(vmiSpec.Domain.Machine.Type).To(Equal("pseries"))
 		} else if webhooks.IsARM64(vmiSpec) {
 			Expect(vmiSpec.Domain.Machine.Type).To(Equal("virt"))
+		} else if webhooks.IsS390X(vmiSpec) {
+			Expect(vmiSpec.Domain.Machine.Type).To(Equal("s390-ccw-virtio"))
 		} else {
 			Expect(vmiSpec.Domain.Machine.Type).To(Equal("q35"))
 		}
@@ -211,7 +222,8 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 	},
 		Entry("when architecture is amd64", "amd64", v1.DefaultCPUModel),
 		Entry("when architecture is arm64", "arm64", v1.CPUModeHostPassthrough),
-		Entry("when architecture is ppcle64", "ppcle64", v1.DefaultCPUModel),
+		Entry("when architecture is ppc64le", "ppc64le", v1.DefaultCPUModel),
+		Entry("when architecture is s390x", "s390x", v1.DefaultCPUModel),
 		Entry("when architecture is not specified", "", v1.DefaultCPUModel))
 
 	DescribeTable("should apply configurable defaults on VMI create", func(arch string, cpuModel string) {
@@ -220,7 +232,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		}()
 		webhooks.Arch = arch
 
-		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), &v1.KubeVirt{
 			Spec: v1.KubeVirtSpec{
 				Configuration: v1.KubeVirtConfiguration{
 					CPUModel:   cpuModelFromConfig,
@@ -415,42 +427,44 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 	)
 
 	DescribeTable("should add the default network interface",
-		func(iface string) {
-			expectedIface := "bridge"
-			switch iface {
-			case "masquerade":
-				expectedIface = "masquerade"
-			case "slirp":
-				expectedIface = "slirp"
-			}
-
-			permit := true
-			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
+		func(expectedIface string, expectedIfaceBindingMethod v1.InterfaceBindingMethod) {
+			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), &v1.KubeVirt{
 				Spec: v1.KubeVirtSpec{
 					Configuration: v1.KubeVirtConfiguration{
 						NetworkConfiguration: &v1.NetworkConfiguration{
-							NetworkInterface:     expectedIface,
-							PermitSlirpInterface: &permit,
+							NetworkInterface: expectedIface,
 						},
 					},
 				},
 			})
 
 			_, vmiSpec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
-			switch expectedIface {
-			case "bridge":
-				Expect(vmiSpec.Domain.Devices.Interfaces[0].Bridge).NotTo(BeNil())
-			case "masquerade":
-				Expect(vmiSpec.Domain.Devices.Interfaces[0].Masquerade).NotTo(BeNil())
-			case "slirp":
-				Expect(vmiSpec.Domain.Devices.Interfaces[0].Slirp).NotTo(BeNil())
-			}
+			Expect(vmiSpec.Domain.Devices.Interfaces[0].InterfaceBindingMethod).To(Equal(expectedIfaceBindingMethod))
 		},
-		Entry("as bridge", "bridge"),
-		Entry("as masquerade", "masquerade"),
-		Entry("as slirp", "slirp"),
+		Entry("as bridge", "bridge", v1.InterfaceBindingMethod{Bridge: &v1.InterfaceBridge{}}),
+		Entry("as masquerade", "masquerade", v1.InterfaceBindingMethod{Masquerade: &v1.InterfaceMasquerade{}}),
 	)
 
+	It("should reject adding a default deprecated slirp interface", func() {
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), &v1.KubeVirt{
+			Spec: v1.KubeVirtSpec{
+				Configuration: v1.KubeVirtConfiguration{
+					NetworkConfiguration: &v1.NetworkConfiguration{
+						NetworkInterface:               string(v1.DeprecatedSlirpInterface),
+						DeprecatedPermitSlirpInterface: kvpointer.P(true),
+					},
+				},
+			},
+		})
+		resp := admitVMI(rt.GOARCH)
+		Expect(resp).To(Equal(&admissionv1.AdmissionResponse{
+			Result: &k8smetav1.Status{
+				Message: "slirp interface is deprecated as of v1.3",
+				Code:    http.StatusBadRequest,
+			},
+		}))
+	})
+
 	DescribeTable("should not add the default interfaces if", func(interfaces []v1.Interface, networks []v1.Network) {
 		vmi.Spec.Domain.Devices.Interfaces = append([]v1.Interface{}, interfaces...)
 		vmi.Spec.Networks = append([]v1.Network{}, networks...)
@@ -506,7 +520,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 	})
 
 	It("should not override specified properties with defaults on VMI create", func() {
-		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), &v1.KubeVirt{
 			Spec: v1.KubeVirtSpec{
 				Configuration: v1.KubeVirtConfiguration{
 					CPUModel:    cpuModelFromConfig,
@@ -533,7 +547,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 	DescribeTable("should not copy the EmulatorThreadCompleteToEvenParity annotation to the VMI",
 		func(featureGate string, annotations map[string]string, isolateEmulatorThread bool) {
 			if featureGate != "" || annotations != nil {
-				testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
+				testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), &v1.KubeVirt{
 					ObjectMeta: k8smetav1.ObjectMeta{
 						Annotations: annotations,
 					},
@@ -558,7 +572,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 	)
 
 	It("should copy the EmulatorThreadCompleteToEvenParity annotation to the VMI", func() {
-		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), &v1.KubeVirt{
 			ObjectMeta: k8smetav1.ObjectMeta{
 				Annotations: map[string]string{v1.EmulatorThreadCompleteToEvenParity: ""},
 			},
@@ -604,7 +618,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 
 	It("should apply memory-overcommit when guest-memory is set and memory-request is not set", func() {
 		// no limits wanted on this test, to not copy the limit to requests
-		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), &v1.KubeVirt{
 			Spec: v1.KubeVirtSpec{
 				Configuration: v1.KubeVirtConfiguration{
 					DeveloperConfiguration: &v1.DeveloperConfiguration{
@@ -669,6 +683,26 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		Expect(vmiSpec.Domain.Resources.Limits.Memory().String()).To(Equal("64M"))
 	})
 
+	DescribeTable("should always set memory.guest", func(options ...libvmi.Option) {
+		for _, option := range options {
+			option(vmi)
+		}
+		_, vmiSpec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+		Expect(vmiSpec.Domain.Memory.Guest).ToNot(BeNil())
+		Expect(vmiSpec.Domain.Memory.Guest.String()).To(Equal("1Gi"))
+	},
+		Entry("when requests are set",
+			libvmi.WithResourceMemory("1Gi")),
+		Entry("when limits are set",
+			libvmi.WithLimitMemory("1Gi")),
+		Entry("when both requests and limits are set",
+			libvmi.WithResourceMemory("1Gi"),
+			libvmi.WithLimitMemory("1Gi"),
+		),
+		Entry("when only hugepages pagesize is set",
+			libvmi.WithHugepages("1Gi")),
+	)
+
 	It("should set the hyperv dependencies", func() {
 		vmi.Spec.Domain.Features = &v1.Features{
 			Hyperv: &v1.FeatureHyperv{
@@ -850,8 +884,10 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 			Expect(&oldVMI.Status).To(Equal(status))
 		}
 	},
-		Entry("if our service accounts modfies it", privilegedUser, true),
-		Entry("not if the user is not one of ours", "unknown", false),
+		Entry("When the request originates from the virt-api ServiceAccount", fmt.Sprintf("system:serviceaccount:%s:%s", kubeVirtNamespace, components.ApiServiceAccountName), true),
+		Entry("When the request originates from the virt-controller ServiceAccount", fmt.Sprintf("system:serviceaccount:%s:%s", kubeVirtNamespace, components.ControllerServiceAccountName), true),
+		Entry("When the request originates from the virt-handler ServiceAccount", fmt.Sprintf("system:serviceaccount:%s:%s", kubeVirtNamespace, components.HandlerServiceAccountName), true),
+		Entry("When the request does not originate from KubeVirt", "unknown", false),
 	)
 
 	// Check following convert for ARM64
@@ -1074,7 +1110,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 	When("Root feature gate is enabled", func() {
 
 		BeforeEach(func() {
-			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, &v1.KubeVirt{
+			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), &v1.KubeVirt{
 				Spec: v1.KubeVirtSpec{
 					Configuration: v1.KubeVirtConfiguration{
 						DeveloperConfiguration: &v1.DeveloperConfiguration{
@@ -1218,7 +1254,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 
 			kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
 			kvCR.Spec.Configuration.EvictionStrategy = &noneStrategy
-			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kvCR)
+			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
 
 			return noneStrategy
 		}),
@@ -1228,7 +1264,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 
 			kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
 			kvCR.Spec.Configuration.EvictionStrategy = &clusterStrategy
-			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kvCR)
+			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
 
 			s.EvictionStrategy = &vmiStrategy
 
@@ -1239,7 +1275,7 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 
 			kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
 			kvCR.Spec.Configuration.EvictionStrategy = nil
-			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kvCR)
+			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
 
 			defaultStrategy := mutator.ClusterConfig.GetDefaultClusterConfig().EvictionStrategy
 			Expect(defaultStrategy).ToNot(BeNil())
@@ -1261,4 +1297,246 @@ var _ = Describe("VirtualMachineInstance Mutator", func() {
 		Expect(*status.Memory.GuestCurrent).To(Equal(memory))
 		Expect(*status.Memory.GuestRequested).To(Equal(memory))
 	})
+
+	Context("CPU topology", func() {
+		It("should set default CPU topology in Status when not provided by VMI", func() {
+			vmi.Spec.Domain.CPU = nil
+			_, _, status := getMetaSpecStatusFromAdmit(rt.GOARCH)
+			Expect(status.CurrentCPUTopology).ToNot(BeNil())
+			Expect(status.CurrentCPUTopology.Sockets).To(Equal(uint32(1)))
+			Expect(status.CurrentCPUTopology.Cores).To(Equal(uint32(1)))
+			Expect(status.CurrentCPUTopology.Threads).To(Equal(uint32(1)))
+		})
+
+		DescribeTable("should copy VMI provided", func(cpu *v1.CPU) {
+			vmi.Spec.Domain.CPU = cpu
+			_, _, status := getMetaSpecStatusFromAdmit(rt.GOARCH)
+			Expect(status.CurrentCPUTopology).ToNot(BeNil())
+			Expect(status.CurrentCPUTopology.Sockets).To(Equal(vmi.Spec.Domain.CPU.Sockets))
+			Expect(status.CurrentCPUTopology.Cores).To(Equal(vmi.Spec.Domain.CPU.Cores))
+			Expect(status.CurrentCPUTopology.Threads).To(Equal(vmi.Spec.Domain.CPU.Threads))
+		},
+			Entry("full guest CPU topology", &v1.CPU{Sockets: 3, Cores: 3, Threads: 2}),
+			Entry("partial guest CPU topology", &v1.CPU{Sockets: 1, Cores: 1, Threads: 0}),
+		)
+
+		It("should not overwrite existing CurrentCPUTopology within status", func() {
+			vmi.Status = v1.VirtualMachineInstanceStatus{
+				CurrentCPUTopology: &v1.CPUTopology{
+					Sockets: 1,
+					Cores:   1,
+					Threads: 1,
+				},
+			}
+			vmi.Spec.Domain.CPU = &v1.CPU{
+				Sockets: 2,
+				Cores:   1,
+				Threads: 1,
+			}
+			_, _, status := getMetaSpecStatusFromAdmit(rt.GOARCH)
+			Expect(status.CurrentCPUTopology.Sockets).To(Equal(vmi.Status.CurrentCPUTopology.Sockets))
+			Expect(status.CurrentCPUTopology.Cores).To(Equal(vmi.Status.CurrentCPUTopology.Cores))
+			Expect(status.CurrentCPUTopology.Threads).To(Equal(vmi.Status.CurrentCPUTopology.Threads))
+		})
+	})
+
+	Context("when LiveUpdate and VMLiveUpdateFeatures is enabled", func() {
+		BeforeEach(func() {
+			kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+			rolloutStrategy := v1.VMRolloutStrategyLiveUpdate
+			kvCR.Spec.Configuration.VMRolloutStrategy = &rolloutStrategy
+			kvCR.Spec.Configuration.DeveloperConfiguration = &v1.DeveloperConfiguration{
+				FeatureGates: []string{virtconfig.VMLiveUpdateFeaturesGate},
+			}
+			testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
+		})
+		Context("configure CPU hotplug", func() {
+			It("to use maximum sockets configured in cluster config when its not set in VMI spec", func() {
+				kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+				maxSockets := uint32(10)
+				kvCR.Spec.Configuration.LiveUpdateConfiguration = &v1.LiveUpdateConfiguration{
+					MaxCpuSockets: &maxSockets,
+				}
+				testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.CPU.MaxSockets).To(Equal(uint32(maxSockets)))
+			})
+			It("to prefer and use MaxCpuSockets from KV over MaxHotplugRatio", func() {
+				vmi.Spec.Domain.CPU = &v1.CPU{
+					Sockets: 2,
+				}
+				kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+				maxSockets := uint32(10)
+				kvCR.Spec.Configuration.LiveUpdateConfiguration = &v1.LiveUpdateConfiguration{
+					MaxCpuSockets:   &maxSockets,
+					MaxHotplugRatio: 2,
+				}
+				testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.CPU.Sockets).To(Equal(uint32(2)))
+				Expect(spec.Domain.CPU.MaxSockets).To(Equal(maxSockets))
+			})
+			It("to keep VMI values of max sockets when provided", func() {
+				vmi.Spec.Domain.CPU = &v1.CPU{
+					Sockets:    2,
+					MaxSockets: 16,
+				}
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.CPU.Sockets).To(Equal(uint32(2)))
+				Expect(spec.Domain.CPU.MaxSockets).To(Equal(uint32(16)))
+			})
+			It("to use hot plug ratio configured in cluster config when max sockets isn't provided in the VMI", func() {
+				kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+				kvCR.Spec.Configuration.LiveUpdateConfiguration = &v1.LiveUpdateConfiguration{
+					MaxHotplugRatio: 2,
+				}
+				testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.CPU.MaxSockets).To(Equal(uint32(2)))
+			})
+			It("to calculate max sockets to be 4x times the configured sockets when no max sockets defined", func() {
+				vmi.Spec.Domain.CPU = &v1.CPU{
+					Sockets: 2,
+				}
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.CPU.MaxSockets).To(Equal(uint32(8)))
+			})
+			It("to calculate max sockets to be 4x times the default sockets when default CPU topology used", func() {
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.CPU.MaxSockets).To(Equal(uint32(4)))
+			})
+		})
+		Context("configure Memory hotplug", func() {
+			It("to keep VMI values of max guest when provided", func() {
+				guest := resource.MustParse("2Gi")
+				maxGuest := resource.MustParse("6Gi")
+				vmi.Spec.Domain.Memory = &v1.Memory{
+					Guest:    &guest,
+					MaxGuest: &maxGuest,
+				}
+
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.Memory.Guest.Value()).To(Equal(guest.Value()))
+				Expect(spec.Domain.Memory.MaxGuest.Value()).To(Equal(maxGuest.Value()))
+			})
+			It("to use maxGuest configured in cluster config when its not set in VM spec", func() {
+				kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+				maxGuest := resource.MustParse("10Gi")
+				kvCR.Spec.Configuration.LiveUpdateConfiguration = &v1.LiveUpdateConfiguration{
+					MaxGuest: &maxGuest,
+				}
+				testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
+				guest := resource.MustParse("1Gi")
+				vmi.Spec.Domain.Memory = &v1.Memory{
+					Guest: &guest,
+				}
+
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.Memory.MaxGuest.Value()).To(Equal(maxGuest.Value()))
+			})
+			It("to prefer maxGuest from KV over MaxHotplugRatio", func() {
+				kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+				maxGuest := resource.MustParse("10Gi")
+				kvCR.Spec.Configuration.LiveUpdateConfiguration = &v1.LiveUpdateConfiguration{
+					MaxGuest:        &maxGuest,
+					MaxHotplugRatio: 2,
+				}
+				testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
+				guest := resource.MustParse("1Gi")
+				vmi.Spec.Domain.Memory = &v1.Memory{
+					Guest: &guest,
+				}
+
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.Memory.Guest.Value()).To(Equal(guest.Value()))
+				Expect(spec.Domain.Memory.MaxGuest.Value()).To(Equal(maxGuest.Value()))
+			})
+			It("to calculate maxGuest to be `MaxHotplugRatio` times the configured guest memory when no maxGuest is defined", func() {
+				guest := resource.MustParse("1Gi")
+				expectedMaxGuest := resource.MustParse("4Gi")
+				vmi.Spec.Domain.Memory = &v1.Memory{
+					Guest: &guest,
+				}
+
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.Memory.MaxGuest.Value()).To(Equal(expectedMaxGuest.Value()))
+			})
+			It("to use hot plug ratio configured in cluster config when max guest isn't provided in the VMI", func() {
+				kvCR := testutils.GetFakeKubeVirtClusterConfig(kvInformer)
+				kvCR.Spec.Configuration.LiveUpdateConfiguration = &v1.LiveUpdateConfiguration{
+					MaxHotplugRatio: 2,
+				}
+				testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kvCR)
+				guest := resource.MustParse("1Gi")
+				expectedMaxGuest := resource.MustParse("2Gi")
+				vmi.Spec.Domain.Memory = &v1.Memory{
+					Guest: &guest,
+				}
+
+				_, spec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(spec.Domain.Memory.MaxGuest.Value()).To(Equal(expectedMaxGuest.Value()))
+			})
+
+			DescribeTable("should leave MaxGuest empty when memory hotplug is incompatible", func(vmiSetup func(*v1.VirtualMachineInstanceSpec)) {
+				vmi := api.NewMinimalVMI("testvm")
+				vmi.Spec.Domain.Memory = &v1.Memory{Guest: kvpointer.P(resource.MustParse("128Mi"))}
+				vmiSetup(&vmi.Spec)
+
+				_, vmiSpec, _ := getMetaSpecStatusFromAdmit(rt.GOARCH)
+				Expect(vmiSpec.Domain.Memory.MaxGuest).To(BeNil())
+			},
+				Entry("realtime is configured", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					vmiSpec.Domain.CPU = &v1.CPU{
+						DedicatedCPUPlacement: true,
+						Realtime:              &v1.Realtime{},
+						NUMA: &v1.NUMA{
+							GuestMappingPassthrough: &v1.NUMAGuestMappingPassthrough{},
+						},
+					}
+					vmiSpec.Domain.Memory.Hugepages = &v1.Hugepages{
+						PageSize: "2Mi",
+					}
+				}),
+				Entry("launchSecurity is configured", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					vmiSpec.Domain.LaunchSecurity = &v1.LaunchSecurity{}
+				}),
+				Entry("guest mapping passthrough is configured", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					vmiSpec.Domain.CPU = &v1.CPU{
+						DedicatedCPUPlacement: true,
+						NUMA: &v1.NUMA{
+							GuestMappingPassthrough: &v1.NUMAGuestMappingPassthrough{},
+						},
+					}
+					vmiSpec.Domain.Memory.Hugepages = &v1.Hugepages{
+						PageSize: "2Mi",
+					}
+				}),
+				Entry("guest memory is not set", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					vmiSpec.Domain.Memory.Guest = nil
+				}),
+				Entry("guest memory is greater than maxGuest", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					moreThanMax := vmiSpec.Domain.Memory.Guest.DeepCopy()
+					moreThanMax.Mul(8)
+
+					vmiSpec.Domain.Memory.Guest = &moreThanMax
+				}),
+				Entry("maxGuest is not properly aligned", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					unAlignedMemory := resource.MustParse("333Mi")
+					vmiSpec.Domain.Memory.MaxGuest = &unAlignedMemory
+				}),
+				Entry("guest memory is not properly aligned", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					unAlignedMemory := resource.MustParse("123")
+					vmiSpec.Domain.Memory.Guest = &unAlignedMemory
+				}),
+				Entry("guest memory with hugepages is not properly aligned", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					vmiSpec.Domain.Memory.Guest = kvpointer.P(resource.MustParse("2G"))
+					vmiSpec.Domain.Memory.MaxGuest = kvpointer.P(resource.MustParse("16Gi"))
+					vmiSpec.Domain.Memory.Hugepages = &v1.Hugepages{PageSize: "1Gi"}
+				}),
+				Entry("architecture is not amd64 or arm64", func(vmiSpec *v1.VirtualMachineInstanceSpec) {
+					vmiSpec.Architecture = "risc-v"
+				}),
+			)
+		})
+	})
 })
