@@ -24,9 +24,7 @@ import (
 	"encoding/json"
 	"fmt"
 
-	"k8s.io/apimachinery/pkg/api/resource"
-
-	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/converter"
+	"kubevirt.io/kubevirt/pkg/virt-config/deprecation"
 
 	corev1 "k8s.io/api/core/v1"
 
@@ -44,9 +42,11 @@ import (
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
 	"kubevirt.io/kubevirt/pkg/controller"
+	netadmitter "kubevirt.io/kubevirt/pkg/network/admitter"
 	migrationutil "kubevirt.io/kubevirt/pkg/util/migrations"
 
 	"kubevirt.io/kubevirt/pkg/instancetype"
+	"kubevirt.io/kubevirt/pkg/liveupdate/memory"
 	metrics "kubevirt.io/kubevirt/pkg/monitoring/metrics/virt-api"
 	webhookutils "kubevirt.io/kubevirt/pkg/util/webhooks"
 	"kubevirt.io/kubevirt/pkg/virt-api/webhooks"
@@ -166,6 +166,17 @@ func (admitter *VMsAdmitter) Admit(ar *admissionv1.AdmissionReview) *admissionv1
 		}
 	}
 
+	if ar.Request.Operation == admissionv1.Create {
+		clusterCfg := admitter.ClusterConfig.GetConfig()
+		if devCfg := clusterCfg.DeveloperConfiguration; devCfg != nil {
+			causes = append(causes, deprecation.ValidateFeatureGates(devCfg.FeatureGates, &vm.Spec.Template.Spec)...)
+		}
+
+		netValidator := netadmitter.NewValidator(k8sfield.NewPath("spec"), &vmCopy.Spec.Template.Spec, admitter.ClusterConfig)
+		if causes = netValidator.ValidateCreation(); len(causes) > 0 {
+			return webhookutils.ToAdmissionResponse(causes)
+		}
+	}
 	causes = ValidateVirtualMachineSpec(k8sfield.NewPath("spec"), &vmCopy.Spec, admitter.ClusterConfig, accountName)
 	if len(causes) > 0 {
 		return webhookutils.ToAdmissionResponse(causes)
@@ -236,6 +247,49 @@ func (admitter *VMsAdmitter) AdmitStatus(ar *admissionv1.AdmissionReview) *admis
 	return &reviewResponse
 }
 
+const (
+	instancetypeCPUGuestPath              = "instancetype.spec.cpu.guest"
+	spreadAcrossSocketsCoresErrFmt        = "%d vCPUs provided by the instance type are not divisible by the Spec.PreferSpreadSocketToCoreRatio or Spec.CPU.PreferSpreadOptions.Ratio of %d provided by the preference"
+	spreadAcrossCoresThreadsErrFmt        = "%d vCPUs provided by the instance type are not divisible by the number of threads per core %d"
+	spreadAcrossSocketsCoresThreadsErrFmt = "%d vCPUs provided by the instance type are not divisible by the number of threads per core %d and Spec.PreferSpreadSocketToCoreRatio or Spec.CPU.PreferSpreadOptions.Ratio of %d"
+)
+
+func checkSpreadCPUTopology(instancetypeSpec *instancetypev1beta1.VirtualMachineInstancetypeSpec, preferenceSpec *instancetypev1beta1.VirtualMachinePreferenceSpec) []metav1.StatusCause {
+	if topology := instancetype.GetPreferredTopology(preferenceSpec); instancetypeSpec == nil || topology != instancetypev1beta1.PreferSpread {
+		return nil
+	}
+
+	ratio, across := instancetype.GetSpreadOptions(preferenceSpec)
+	switch across {
+	case instancetypev1beta1.SpreadAcrossSocketsCores:
+		if (instancetypeSpec.CPU.Guest % ratio) > 0 {
+			return []metav1.StatusCause{{
+				Type:    metav1.CauseTypeFieldValueInvalid,
+				Message: fmt.Sprintf(spreadAcrossSocketsCoresErrFmt, instancetypeSpec.CPU.Guest, ratio),
+				Field:   k8sfield.NewPath(instancetypeCPUGuestPath).String(),
+			}}
+		}
+	case instancetypev1beta1.SpreadAcrossCoresThreads:
+		if (instancetypeSpec.CPU.Guest % ratio) > 0 {
+			return []metav1.StatusCause{{
+				Type:    metav1.CauseTypeFieldValueInvalid,
+				Message: fmt.Sprintf(spreadAcrossCoresThreadsErrFmt, instancetypeSpec.CPU.Guest, ratio),
+				Field:   k8sfield.NewPath(instancetypeCPUGuestPath).String(),
+			}}
+		}
+	case instancetypev1beta1.SpreadAcrossSocketsCoresThreads:
+		const threadsPerCore = 2
+		if (instancetypeSpec.CPU.Guest%threadsPerCore) > 0 || ((instancetypeSpec.CPU.Guest/threadsPerCore)%ratio) > 0 {
+			return []metav1.StatusCause{{
+				Type:    metav1.CauseTypeFieldValueInvalid,
+				Message: fmt.Sprintf(spreadAcrossSocketsCoresThreadsErrFmt, instancetypeSpec.CPU.Guest, threadsPerCore, ratio),
+				Field:   k8sfield.NewPath(instancetypeCPUGuestPath).String(),
+			}}
+		}
+	}
+	return nil
+}
+
 func (admitter *VMsAdmitter) applyInstancetypeToVm(vm *v1.VirtualMachine) (*instancetypev1beta1.VirtualMachineInstancetypeSpec, *instancetypev1beta1.VirtualMachinePreferenceSpec, []metav1.StatusCause) {
 	instancetypeSpec, err := admitter.InstancetypeMethods.FindInstancetypeSpec(vm)
 	if err != nil {
@@ -255,19 +309,8 @@ func (admitter *VMsAdmitter) applyInstancetypeToVm(vm *v1.VirtualMachine) (*inst
 		}}
 	}
 
-	if topology := instancetype.GetPreferredTopology(preferenceSpec); instancetypeSpec != nil && topology == instancetypev1beta1.PreferSpread {
-		ratio := preferenceSpec.PreferSpreadSocketToCoreRatio
-		if ratio == 0 {
-			ratio = instancetype.DefaultSpreadRatio
-		}
-
-		if (instancetypeSpec.CPU.Guest % ratio) > 0 {
-			return nil, nil, []metav1.StatusCause{{
-				Type:    metav1.CauseTypeFieldValueInvalid,
-				Message: "Instancetype CPU Guest is not divisible by PreferSpreadSocketToCoreRatio",
-				Field:   k8sfield.NewPath("instancetype.spec.cpu.guest").String(),
-			}}
-		}
+	if spreadConflicts := checkSpreadCPUTopology(instancetypeSpec, preferenceSpec); len(spreadConflicts) > 0 {
+		return nil, nil, spreadConflicts
 	}
 
 	conflicts := admitter.InstancetypeMethods.ApplyToVmi(k8sfield.NewPath("spec", "template", "spec"), instancetypeSpec, preferenceSpec, &vm.Spec.Template.Spec, &vm.Spec.Template.ObjectMeta)
@@ -432,10 +475,33 @@ func validateLiveUpdateFeatures(field *k8sfield.Path, spec *v1.VirtualMachineSpe
 		return causes
 	}
 
-	causes = append(causes, validateLiveUpdateCPU(field, &spec.Template.Spec.Domain)...)
+	if spec.Template.Spec.Domain.CPU != nil {
+		causes = append(causes, validateLiveUpdateCPU(field, &spec.Template.Spec.Domain)...)
+	}
 
 	if spec.Template.Spec.Domain.Memory != nil && spec.Template.Spec.Domain.Memory.MaxGuest != nil {
-		causes = append(causes, validateLiveUpdateMemory(field, &spec.Template.Spec.Domain, spec.Template.Spec.Architecture)...)
+		if err := memory.ValidateLiveUpdateMemory(&spec.Template.Spec, spec.Template.Spec.Domain.Memory.MaxGuest); err != nil {
+			causes = append(causes, metav1.StatusCause{
+				Type:    metav1.CauseTypeFieldValueInvalid,
+				Message: err.Error(),
+				Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
+			})
+		}
+	}
+
+	if spec.UpdateVolumesStrategy != nil && !config.VolumesUpdateStrategyEnabled() {
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("%s feature gate is not enabled in kubevirt-config", virtconfig.VolumesUpdateStrategy),
+			Field:   "updateVolumesStrategy",
+		})
+	}
+	if spec.UpdateVolumesStrategy != nil && *spec.UpdateVolumesStrategy == v1.UpdateVolumesStrategyMigration && !config.VolumeMigrationEnabled() {
+		causes = append(causes, metav1.StatusCause{
+			Type:    metav1.CauseTypeFieldValueInvalid,
+			Message: fmt.Sprintf("%s feature gate is not enabled in kubevirt-config", virtconfig.VolumeMigration),
+			Field:   "updateVolumesStrategy",
+		})
 	}
 
 	return causes
@@ -453,95 +519,6 @@ func validateLiveUpdateCPU(field *k8sfield.Path, domain *v1.DomainSpec) (causes
 	return causes
 }
 
-func validateLiveUpdateMemory(field *k8sfield.Path, domain *v1.DomainSpec, architecture string) (causes []metav1.StatusCause) {
-	if domain.CPU != nil &&
-		domain.CPU.Realtime != nil {
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Memory hotplug is not compatible with realtime VMs"),
-			Field:   field.Child("template", "spec", "domain", "cpu", "realtime").String(),
-		})
-	}
-
-	if domain.CPU != nil &&
-		domain.CPU.NUMA != nil &&
-		domain.CPU.NUMA.GuestMappingPassthrough != nil {
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Memory hotplug is not compatible with guest mapping passthrough"),
-			Field:   field.Child("template", "spec", "domain", "cpu", "numa", "guestMappingPassthrough").String(),
-		})
-	}
-
-	if domain.LaunchSecurity != nil {
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Memory hotplug is not compatible with encrypted VMs"),
-			Field:   field.Child("template", "spec", "domain", "launchSecurity").String(),
-		})
-	}
-
-	if domain.CPU != nil &&
-		domain.CPU.DedicatedCPUPlacement {
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Memory hotplug is not compatible with dedicated CPUs"),
-			Field:   field.Child("template", "spec", "domain", "cpu", "dedicatedCpuPlacement").String(),
-		})
-	}
-
-	if domain.Memory != nil &&
-		domain.Memory.Hugepages != nil {
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Memory hotplug is not compatible with hugepages"),
-			Field:   field.Child("template", "spec", "domain", "memory", "hugepages").String(),
-		})
-	}
-
-	if domain.Memory == nil ||
-		domain.Memory.Guest == nil {
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Guest memory must be configured when memory hotplug is enabled"),
-			Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
-		})
-	} else if domain.Memory.Guest.Cmp(*domain.Memory.MaxGuest) > 0 {
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Guest memory is greater than the configured maxGuest memory"),
-			Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
-		})
-	} else if domain.Memory.Guest.Value()%converter.MemoryHotplugBlockAlignmentBytes != 0 {
-		alignment := resource.NewQuantity(converter.MemoryHotplugBlockAlignmentBytes, resource.BinarySI)
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Guest memory must be %s aligned", alignment),
-			Field:   field.Child("template", "spec", "domain", "memory", "guest").String(),
-		})
-	}
-
-	if domain.Memory.MaxGuest.Value()%converter.MemoryHotplugBlockAlignmentBytes != 0 {
-		alignment := resource.NewQuantity(converter.MemoryHotplugBlockAlignmentBytes, resource.BinarySI)
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("MaxGuest must be %s aligned", alignment),
-			Field:   field.Child("template", "spec", "domain", "memory", "maxGuest").String(),
-		})
-	}
-
-	if architecture != "amd64" {
-		causes = append(causes, metav1.StatusCause{
-			Type:    metav1.CauseTypeFieldValueInvalid,
-			Message: fmt.Sprintf("Memory hotplug is only available for x86_64 VMs"),
-			Field:   field.Child("template", "spec", "architecture").String(),
-		})
-		return causes
-	}
-
-	return causes
-}
-
 func (admitter *VMsAdmitter) validateVolumeRequests(vm *v1.VirtualMachine) ([]metav1.StatusCause, error) {
 	if len(vm.Status.VolumeRequests) == 0 {
 		return nil, nil
@@ -778,16 +755,3 @@ func validateSnapshotStatus(ar *admissionv1.AdmissionRequest, vm *v1.VirtualMach
 
 	return nil
 }
-
-func (admitter *VMsAdmitter) isMigrationInProgress(vmi *v1.VirtualMachineInstance) error {
-	if vmi.Status.MigrationState != nil &&
-		!vmi.Status.MigrationState.Completed {
-		return fmt.Errorf("cannot update while VMI migration is in progress")
-	}
-
-	err := EnsureNoMigrationConflict(admitter.VirtClient, vmi.Name, vmi.Namespace)
-	if err != nil {
-		return fmt.Errorf("cannot update while VMI migration is in progress: %v", err)
-	}
-	return nil
-}
