@@ -61,22 +61,22 @@ func NewClusterConfig(crdInformer cache.SharedIndexInformer,
 // 2. Check if the config got updated. If so, try to parse and return it
 // 3. In case of errors or no updates (resource version stays the same), it returns the values from the last good config
 func NewClusterConfigWithCPUArch(crdInformer cache.SharedIndexInformer,
-	kubeVirtInformer cache.SharedIndexInformer,
+	kubeVirtInformer cache.SharedInformer,
 	namespace, cpuArch string) (*ClusterConfig, error) {
 
 	defaultConfig := defaultClusterConfig(cpuArch)
 
 	c := &ClusterConfig{
-		crdInformer:      crdInformer,
-		kubeVirtInformer: kubeVirtInformer,
-		cpuArch:          cpuArch,
-		lock:             &sync.Mutex{},
-		namespace:        namespace,
-		lastValidConfig:  defaultConfig,
-		defaultConfig:    defaultConfig,
+		crdStore:        crdInformer.GetStore(),
+		kubeVirtStore:   kubeVirtInformer.GetStore(),
+		cpuArch:         cpuArch,
+		lock:            &sync.Mutex{},
+		namespace:       namespace,
+		lastValidConfig: defaultConfig,
+		defaultConfig:   defaultConfig,
 	}
 
-	_, err := c.crdInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
+	_, err := crdInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc:    c.crdAddedDeleted,
 		DeleteFunc: c.crdAddedDeleted,
 		UpdateFunc: c.crdUpdated,
@@ -85,7 +85,7 @@ func NewClusterConfigWithCPUArch(crdInformer cache.SharedIndexInformer,
 		return nil, err
 	}
 
-	_, err = c.kubeVirtInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
+	_, err = kubeVirtInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc:    c.configAddedDeleted,
 		UpdateFunc: c.configUpdated,
 	})
@@ -214,7 +214,7 @@ func defaultClusterConfig(cpuArch string) *v1.KubeVirtConfiguration {
 		CPURequest: &cpuRequestDefault,
 		NetworkConfiguration: &v1.NetworkConfiguration{
 			NetworkInterface:                  defaultNetworkInterface,
-			PermitSlirpInterface:              pointer.P(DefaultPermitSlirpInterface),
+			DeprecatedPermitSlirpInterface:    pointer.P(DefaultPermitSlirpInterface),
 			PermitBridgeInterfaceOnPodNetwork: pointer.P(DefaultPermitBridgeInterfaceOnPodNetwork),
 		},
 		SMBIOSConfig:                SmbiosDefaultConfig,
@@ -271,8 +271,8 @@ func defaultClusterConfig(cpuArch string) *v1.KubeVirtConfiguration {
 }
 
 type ClusterConfig struct {
-	crdInformer                      cache.SharedIndexInformer
-	kubeVirtInformer                 cache.SharedIndexInformer
+	crdStore                         cache.Store
+	kubeVirtStore                    cache.Store
 	namespace                        string
 	cpuArch                          string
 	lock                             *sync.Mutex
@@ -323,6 +323,9 @@ func getCPUArchSpecificDefault(cpuArch string) (string, string, []string) {
 	case "ppc64le":
 		emulatedMachinesDefault := strings.Split(DefaultPPC64LEEmulatedMachines, ",")
 		return DefaultARCHOVMFPath, DefaultPPC64LEMachineType, emulatedMachinesDefault
+	case "s390x":
+		emulatedMachinesDefault := strings.Split(DefaultS390XEmulatedMachines, ",")
+		return DefaultARCHOVMFPath, DefaultS390XMachineType, emulatedMachinesDefault
 	default:
 		emulatedMachinesDefault := strings.Split(DefaultAMD64EmulatedMachines, ",")
 		return DefaultARCHOVMFPath, DefaultAMD64MachineType, emulatedMachinesDefault
@@ -366,7 +369,7 @@ func (c *ClusterConfig) GetConfig() (config *v1.KubeVirtConfiguration) {
 }
 
 func (c *ClusterConfig) GetConfigFromKubeVirtCR() *v1.KubeVirt {
-	objects := c.kubeVirtInformer.GetStore().List()
+	objects := c.kubeVirtStore.List()
 	var kubeVirtName string
 	for _, obj := range objects {
 		if kv, ok := obj.(*v1.KubeVirt); ok && kv.DeletionTimestamp == nil {
@@ -380,7 +383,7 @@ func (c *ClusterConfig) GetConfigFromKubeVirtCR() *v1.KubeVirt {
 		return nil
 	}
 
-	if obj, exists, err := c.kubeVirtInformer.GetStore().GetByKey(c.namespace + "/" + kubeVirtName); err != nil {
+	if obj, exists, err := c.kubeVirtStore.GetByKey(c.namespace + "/" + kubeVirtName); err != nil {
 		log.DefaultLogger().Reason(err).Errorf("Error loading the cluster config from KubeVirt cache, falling back to last good resource version '%s'", c.lastValidConfigResourceVersion)
 		return nil
 	} else if !exists {
@@ -395,7 +398,7 @@ func (c *ClusterConfig) HasDataSourceAPI() bool {
 	c.lock.Lock()
 	defer c.lock.Unlock()
 
-	objects := c.crdInformer.GetStore().List()
+	objects := c.crdStore.List()
 	for _, obj := range objects {
 		if crd, ok := obj.(*extv1.CustomResourceDefinition); ok && crd.DeletionTimestamp == nil {
 			if isDataSourceCrd(crd) {
@@ -410,7 +413,7 @@ func (c *ClusterConfig) HasDataVolumeAPI() bool {
 	c.lock.Lock()
 	defer c.lock.Unlock()
 
-	objects := c.crdInformer.GetStore().List()
+	objects := c.crdStore.List()
 	for _, obj := range objects {
 		if crd, ok := obj.(*extv1.CustomResourceDefinition); ok && crd.DeletionTimestamp == nil {
 			if isDataVolumeCrd(crd) {
@@ -425,7 +428,7 @@ func (c *ClusterConfig) HasServiceMonitorAPI() bool {
 	c.lock.Lock()
 	defer c.lock.Unlock()
 
-	objects := c.crdInformer.GetStore().List()
+	objects := c.crdStore.List()
 	for _, obj := range objects {
 		if crd, ok := obj.(*extv1.CustomResourceDefinition); ok && crd.DeletionTimestamp == nil {
 			if isServiceMonitor(crd) {
@@ -440,7 +443,7 @@ func (c *ClusterConfig) HasPrometheusRuleAPI() bool {
 	c.lock.Lock()
 	defer c.lock.Unlock()
 
-	objects := c.crdInformer.GetStore().List()
+	objects := c.crdStore.List()
 	for _, obj := range objects {
 		if crd, ok := obj.(*extv1.CustomResourceDefinition); ok && crd.DeletionTimestamp == nil {
 			if isPrometheusRules(crd) {
@@ -486,7 +489,7 @@ func validateConfig(config *v1.KubeVirtConfiguration) error {
 
 	// set default network interface
 	switch config.NetworkConfiguration.NetworkInterface {
-	case "", string(v1.BridgeInterface), string(v1.SlirpInterface), string(v1.MasqueradeInterface):
+	case "", string(v1.BridgeInterface), string(v1.DeprecatedSlirpInterface), string(v1.MasqueradeInterface):
 		break
 	default:
 		return fmt.Errorf("invalid default-network-interface in config: %v", config.NetworkConfiguration.NetworkInterface)
