@@ -51,7 +51,7 @@ var _ = Describe("test configuration", func() {
 	DescribeTable(" when permitSlirpInterface", func(value *bool, result bool) {
 		clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKVConfig(&v1.KubeVirtConfiguration{
 			NetworkConfiguration: &v1.NetworkConfiguration{
-				PermitSlirpInterface: value,
+				DeprecatedPermitSlirpInterface: value,
 			},
 		})
 
@@ -118,7 +118,7 @@ var _ = Describe("test configuration", func() {
 	)
 
 	nodeSelectors := map[string]string{
-		"kubernetes.io/hostname":          "node02",
+		kubev1.LabelHostname:              "node02",
 		"node-role.kubernetes.io/compute": "true",
 	}
 	DescribeTable(" when nodeSelectors", func(value, result map[string]string) {
@@ -134,7 +134,7 @@ var _ = Describe("test configuration", func() {
 		Entry("is empty, GetNodeSelectors should return the default", map[string]string{}, nil),
 	)
 
-	DescribeTable(" when machineType", func(cpuArch string, machineTypeAMD64 string, machineTypeARM64 string, machineTypePPC64le string, result string) {
+	DescribeTable(" when machineType", func(cpuArch string, machineTypeAMD64 string, machineTypeARM64 string, machineTypePPC64le string, machineTypeS390X string, result string) {
 		clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKVWithCPUArch(&v1.KubeVirt{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "kubevirt",
@@ -155,12 +155,14 @@ var _ = Describe("test configuration", func() {
 		}, cpuArch)
 		Expect(clusterConfig.GetMachineType(cpuArch)).To(Equal(result))
 	},
-		Entry("when amd64 set, GetMachineType should return the value", "amd64", "pc-q35-3.0", "", "", "pc-q35-3.0"),
-		Entry("when arm64 set, GetMachineType should return the value", "arm64", "", "virt", "", "virt"),
-		Entry("when ppc64le set, GetMachineType should return the value", "ppc64le", "", "", "pseries", "pseries"),
-		Entry("when amd64 unset, GetMachineType should return the default with amd64", "amd64", "", "", "", virtconfig.DefaultAMD64MachineType),
-		Entry("when arm64 unset, GetMachineType should return the default with arm64", "arm64", "", "", "", virtconfig.DefaultAARCH64MachineType),
-		Entry("when ppc64le unset, GetMachineType should return the default with ppc64le", "ppc64le", "", "", "", virtconfig.DefaultPPC64LEMachineType),
+		Entry("when amd64 set, GetMachineType should return the value", "amd64", "pc-q35-3.0", "", "", "", "pc-q35-3.0"),
+		Entry("when arm64 set, GetMachineType should return the value", "arm64", "", "virt", "", "", "virt"),
+		Entry("when ppc64le set, GetMachineType should return the value", "ppc64le", "", "", "pseries", "", "pseries"),
+		Entry("when s390x set, GetMachineType should return the value", "s390x", "", "", "", "s390-ccw-virtio", "s390-ccw-virtio"),
+		Entry("when amd64 unset, GetMachineType should return the default with amd64", "amd64", "", "", "", "", virtconfig.DefaultAMD64MachineType),
+		Entry("when arm64 unset, GetMachineType should return the default with arm64", "arm64", "", "", "", "", virtconfig.DefaultAARCH64MachineType),
+		Entry("when ppc64le unset, GetMachineType should return the default with ppc64le", "ppc64le", "", "", "", "", virtconfig.DefaultPPC64LEMachineType),
+		Entry("when s390x unset, GetMachineType should return the default with s390x", "s390x", "", "", "", "", virtconfig.DefaultS390XMachineType),
 	)
 
 	It("architectureConfiguration fields should not have higher priority when deprecated options are set", func() {
@@ -242,7 +244,7 @@ var _ = Describe("test configuration", func() {
 		Entry("when negative, GetCPUAllocationRatio should return the default", -150, virtconfig.DefaultCPUAllocationRatio),
 	)
 
-	DescribeTable(" when emulatedMachines", func(cpuArch string, emuMachinesAMD64 []string, emuMachinesARM64 []string, emuMachinesAPC64le64 []string, result []string) {
+	DescribeTable(" when emulatedMachines", func(cpuArch string, emuMachinesAMD64 []string, emuMachinesARM64 []string, emuMachinesAPC64le64 []string, emuMachinesS390X []string, result []string) {
 		clusterConfig, _, _ := testutils.NewFakeClusterConfigUsingKVWithCPUArch(&v1.KubeVirt{
 			ObjectMeta: metav1.ObjectMeta{
 				Name:      "kubevirt",
@@ -264,15 +266,18 @@ var _ = Describe("test configuration", func() {
 		emulatedMachines := clusterConfig.GetEmulatedMachines(cpuArch)
 		Expect(emulatedMachines).To(ConsistOf(result))
 	},
-		Entry("when amd64 set, GetEmulatedMachines should return the value", "amd64", []string{"q35", "i440*"}, nil, nil, []string{"q35", "i440*"}),
-		Entry("when arm64 set, GetEmulatedMachines should return the value", "arm64", nil, []string{"virt*"}, nil, []string{"virt*"}),
-		Entry("when ppc64le set, GetEmulatedMachines should return the value", "ppc64le", nil, nil, []string{"pseries*"}, []string{"pseries*"}),
-		Entry("when unset, GetEmulatedMachines should return the defaults with amd64", "amd64", nil, nil, nil, strings.Split(virtconfig.DefaultAMD64EmulatedMachines, ",")),
-		Entry("when empty, GetEmulatedMachines should return the defaults with amd64", "amd64", []string{}, []string{}, []string{}, strings.Split(virtconfig.DefaultAMD64EmulatedMachines, ",")),
-		Entry("when unset, GetEmulatedMachines should return the defaults with arm64", "arm64", nil, nil, nil, strings.Split(virtconfig.DefaultAARCH64EmulatedMachines, ",")),
-		Entry("when empty, GetEmulatedMachines should return the defaults with arm64", "arm64", []string{}, []string{}, []string{}, strings.Split(virtconfig.DefaultAARCH64EmulatedMachines, ",")),
-		Entry("when unset, GetEmulatedMachines should return the defaults with ppc64le", "ppc64le", nil, nil, nil, strings.Split(virtconfig.DefaultPPC64LEEmulatedMachines, ",")),
-		Entry("when empty, GetEmulatedMachines should return the defaults with ppc64le", "ppc64le", []string{}, []string{}, []string{}, strings.Split(virtconfig.DefaultPPC64LEEmulatedMachines, ",")),
+		Entry("when amd64 set, GetEmulatedMachines should return the value", "amd64", []string{"q35", "i440*"}, nil, nil, nil, []string{"q35", "i440*"}),
+		Entry("when arm64 set, GetEmulatedMachines should return the value", "arm64", nil, []string{"virt*"}, nil, nil, []string{"virt*"}),
+		Entry("when ppc64le set, GetEmulatedMachines should return the value", "ppc64le", nil, nil, []string{"pseries*"}, nil, []string{"pseries*"}),
+		Entry("when s390x set, GetEmulatedMachines should return the value", "s390x", nil, nil, nil, []string{"s390-ccw-virtio*"}, []string{"s390-ccw-virtio*"}),
+		Entry("when unset, GetEmulatedMachines should return the defaults with amd64", "amd64", nil, nil, nil, nil, strings.Split(virtconfig.DefaultAMD64EmulatedMachines, ",")),
+		Entry("when empty, GetEmulatedMachines should return the defaults with amd64", "amd64", []string{}, []string{}, []string{}, nil, strings.Split(virtconfig.DefaultAMD64EmulatedMachines, ",")),
+		Entry("when unset, GetEmulatedMachines should return the defaults with arm64", "arm64", nil, nil, nil, nil, strings.Split(virtconfig.DefaultAARCH64EmulatedMachines, ",")),
+		Entry("when empty, GetEmulatedMachines should return the defaults with arm64", "arm64", []string{}, []string{}, nil, []string{}, strings.Split(virtconfig.DefaultAARCH64EmulatedMachines, ",")),
+		Entry("when unset, GetEmulatedMachines should return the defaults with ppc64le", "ppc64le", nil, nil, nil, nil, strings.Split(virtconfig.DefaultPPC64LEEmulatedMachines, ",")),
+		Entry("when empty, GetEmulatedMachines should return the defaults with ppc64le", "ppc64le", []string{}, []string{}, []string{}, nil, strings.Split(virtconfig.DefaultPPC64LEEmulatedMachines, ",")),
+		Entry("when unset, GetEmulatedMachines should return the defaults with s390x", "s390x", nil, nil, nil, nil, strings.Split(virtconfig.DefaultS390XEmulatedMachines, ",")),
+		Entry("when empty, GetEmulatedMachines should return the defaults with s390x", "s390x", []string{}, []string{}, []string{}, nil, strings.Split(virtconfig.DefaultS390XEmulatedMachines, ",")),
 	)
 
 	DescribeTable("when virtualMachineOptions", func(virtualMachineOptions *v1.VirtualMachineOptions, expected bool) {
@@ -433,7 +438,7 @@ var _ = Describe("test configuration", func() {
 				Phase: "Deployed",
 			},
 		}
-		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kv)
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kv)
 		Eventually(func() uint32 {
 			return *clusterConfig.GetMigrationConfiguration().ParallelOutboundMigrationsPerNode
 		}).Should(BeEquivalentTo(9))
@@ -460,7 +465,7 @@ var _ = Describe("test configuration", func() {
 				Phase: "Deployed",
 			},
 		}
-		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer, kv)
+		testutils.UpdateFakeKubeVirtClusterConfig(kvInformer.GetStore(), kv)
 
 		Consistently(func() kubev1.PullPolicy {
 			return clusterConfig.GetImagePullPolicy()
@@ -502,7 +507,7 @@ var _ = Describe("test configuration", func() {
 		Entry("when unset, GetSELinuxLauncherType should return the default", virtconfig.DefaultSELinuxLauncherType, virtconfig.DefaultSELinuxLauncherType),
 	)
 
-	DescribeTable(" when OVMFPath", func(cpuArch string, ovmfPathKeyAMD64 string, ovmfPathKeyARM64 string, ovmfPathKeyPPC64le64 string, result string) {
+	DescribeTable(" when OVMFPath", func(cpuArch string, ovmfPathKeyAMD64 string, ovmfPathKeyARM64 string, ovmfPathKeyPPC64le64 string, ovmfPathKeyS390X string, result string) {
 
 		kv := &v1.KubeVirt{
 			ObjectMeta: metav1.ObjectMeta{
@@ -527,12 +532,14 @@ var _ = Describe("test configuration", func() {
 		ovmfPath := clusterConfig.GetOVMFPath(cpuArch)
 		Expect(ovmfPath).To(Equal(result))
 	},
-		Entry("when amd64 set, GetOVMFPath should return the value", "amd64", "/usr/share/ovmf/x64", "", "", "/usr/share/ovmf/x64"),
-		Entry("when arm64 set, GetOVMFPath should return the value", "arm64", "", "/usr/share/AAVMF", "", "/usr/share/AAVMF"),
-		Entry("when ppc64le set, GetOVMFPath should return the value", "ppc64le", "", "", "/usr/share/ovmf/x64", "/usr/share/ovmf/x64"),
-		Entry("when unset, GetOVMFPath should return the default with amd64", "amd64", "", "", "", virtconfig.DefaultARCHOVMFPath),
-		Entry("when unset, GetOVMFPath should return the default with arm64", "arm64", "", "", "", virtconfig.DefaultAARCH64OVMFPath),
-		Entry("when unset, GetOVMFPath should return the default with ppc64le", "ppc64le", "", "", "", virtconfig.DefaultARCHOVMFPath),
+		Entry("when amd64 set, GetOVMFPath should return the value", "amd64", "/usr/share/ovmf/x64", "", "", "", "/usr/share/ovmf/x64"),
+		Entry("when arm64 set, GetOVMFPath should return the value", "arm64", "", "/usr/share/AAVMF", "", "", "/usr/share/AAVMF"),
+		Entry("when ppc64le set, GetOVMFPath should return the value", "ppc64le", "", "", "/usr/share/ovmf/x64", "", "/usr/share/ovmf/x64"),
+		Entry("when s390x set, GetOVMFPath should return the value", "s390x", "", "", "", "", ""),
+		Entry("when unset, GetOVMFPath should return the default with amd64", "amd64", "", "", "", "", virtconfig.DefaultARCHOVMFPath),
+		Entry("when unset, GetOVMFPath should return the default with arm64", "arm64", "", "", "", "", virtconfig.DefaultAARCH64OVMFPath),
+		Entry("when unset, GetOVMFPath should return the default with ppc64le", "ppc64le", "", "", "", "", virtconfig.DefaultARCHOVMFPath),
+		Entry("when unset, GetOVMFPath should return an empty string with s390x", "s390x", "", "", "", "", ""),
 	)
 
 	It("verifies that SetConfigModifiedCallback works as expected ", func() {
@@ -575,7 +582,7 @@ var _ = Describe("test configuration", func() {
 
 		Expect(clusterConfig.GetVirtLauncherVerbosity()).To(Equal(uint(3)))
 		KV.Spec.Configuration.DeveloperConfiguration.LogVerbosity.VirtLauncher = 6
-		testutils.UpdateFakeKubeVirtClusterConfig(kubeVirtInformer, KV)
+		testutils.UpdateFakeKubeVirtClusterConfig(kubeVirtInformer.GetStore(), KV)
 		Expect(clusterConfig.GetVirtLauncherVerbosity()).To(Equal(uint(6)))
 		Eventually(func() bool {
 			lock.Lock()
@@ -714,7 +721,7 @@ var _ = Describe("test configuration", func() {
 			v1.KubeVirtConfiguration{
 				NetworkConfiguration: &v1.NetworkConfiguration{
 					NetworkInterface:                  "test",
-					PermitSlirpInterface:              pointer.P(true),
+					DeprecatedPermitSlirpInterface:    pointer.P(true),
 					PermitBridgeInterfaceOnPodNetwork: pointer.P(false),
 				},
 			},
@@ -725,8 +732,8 @@ var _ = Describe("test configuration", func() {
 		Entry("when networkConfiguration set, should equal to result",
 			v1.KubeVirtConfiguration{
 				NetworkConfiguration: &v1.NetworkConfiguration{
-					NetworkInterface:                  string(v1.SlirpInterface),
-					PermitSlirpInterface:              pointer.P(true),
+					NetworkInterface:                  string(v1.DeprecatedSlirpInterface),
+					DeprecatedPermitSlirpInterface:    pointer.P(true),
 					PermitBridgeInterfaceOnPodNetwork: pointer.P(false),
 				},
 			},
@@ -737,7 +744,7 @@ var _ = Describe("test configuration", func() {
 		Entry("when networkConfiguration set with empty NetworkInterface, should use the default",
 			v1.KubeVirtConfiguration{
 				NetworkConfiguration: &v1.NetworkConfiguration{
-					PermitSlirpInterface:              pointer.P(true),
+					DeprecatedPermitSlirpInterface:    pointer.P(true),
 					PermitBridgeInterfaceOnPodNetwork: pointer.P(false),
 				},
 			},
