@@ -4,6 +4,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"maps"
 	"math/rand"
 	"strconv"
 	"strings"
@@ -40,16 +41,17 @@ import (
 
 // PoolController is the main PoolController struct.
 type PoolController struct {
-	clientset        kubecli.KubevirtClient
-	queue            workqueue.RateLimitingInterface
-	vmInformer       cache.SharedIndexInformer
-	vmiInformer      cache.SharedIndexInformer
-	poolInformer     cache.SharedIndexInformer
-	revisionInformer cache.SharedIndexInformer
-	recorder         record.EventRecorder
-	expectations     *controller.UIDTrackingControllerExpectations
-	burstReplicas    uint
-	statusUpdater    *status.VMPStatusUpdater
+	clientset       kubecli.KubevirtClient
+	queue           workqueue.RateLimitingInterface
+	vmIndexer       cache.Indexer
+	vmiStore        cache.Store
+	poolIndexer     cache.Indexer
+	revisionIndexer cache.Indexer
+	recorder        record.EventRecorder
+	expectations    *controller.UIDTrackingControllerExpectations
+	burstReplicas   uint
+	statusUpdater   *status.VMPStatusUpdater
+	hasSynced       func() bool
 }
 
 const (
@@ -80,19 +82,23 @@ func NewPoolController(clientset kubecli.KubevirtClient,
 	recorder record.EventRecorder,
 	burstReplicas uint) (*PoolController, error) {
 	c := &PoolController{
-		clientset:        clientset,
-		queue:            workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "virt-controller-pool"),
-		poolInformer:     poolInformer,
-		vmiInformer:      vmiInformer,
-		vmInformer:       vmInformer,
-		revisionInformer: revisionInformer,
-		recorder:         recorder,
-		expectations:     controller.NewUIDTrackingControllerExpectations(controller.NewControllerExpectations()),
-		burstReplicas:    burstReplicas,
-		statusUpdater:    status.NewVMPStatusUpdater(clientset),
+		clientset:       clientset,
+		queue:           workqueue.NewNamedRateLimitingQueue(workqueue.DefaultControllerRateLimiter(), "virt-controller-pool"),
+		poolIndexer:     poolInformer.GetIndexer(),
+		vmiStore:        vmiInformer.GetStore(),
+		vmIndexer:       vmInformer.GetIndexer(),
+		revisionIndexer: revisionInformer.GetIndexer(),
+		recorder:        recorder,
+		expectations:    controller.NewUIDTrackingControllerExpectations(controller.NewControllerExpectations()),
+		burstReplicas:   burstReplicas,
+		statusUpdater:   status.NewVMPStatusUpdater(clientset),
 	}
 
-	_, err := c.poolInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
+	c.hasSynced = func() bool {
+		return poolInformer.HasSynced() && vmInformer.HasSynced() && vmiInformer.HasSynced() && revisionInformer.HasSynced()
+	}
+
+	_, err := poolInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc:    c.addPool,
 		DeleteFunc: c.deletePool,
 		UpdateFunc: c.updatePool,
@@ -101,7 +107,7 @@ func NewPoolController(clientset kubecli.KubevirtClient,
 		return nil, err
 	}
 
-	_, err = c.vmInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
+	_, err = vmInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc:    c.addVMHandler,
 		DeleteFunc: c.deleteVMHandler,
 		UpdateFunc: c.updateVMHandler,
@@ -110,7 +116,7 @@ func NewPoolController(clientset kubecli.KubevirtClient,
 		return nil, err
 	}
 
-	_, err = c.revisionInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
+	_, err = revisionInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc:    c.addRevisionHandler,
 		UpdateFunc: c.updateRevisionHandler,
 	})
@@ -118,7 +124,7 @@ func NewPoolController(clientset kubecli.KubevirtClient,
 		return nil, err
 	}
 
-	_, err = c.vmiInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
+	_, err = vmiInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc:    c.addVMIHandler,
 		UpdateFunc: c.updateVMIHandler,
 	})
@@ -135,7 +141,7 @@ func (c *PoolController) resolveVMIControllerRef(namespace string, controllerRef
 	if controllerRef.Kind != virtv1.VirtualMachineGroupVersionKind.Kind {
 		return nil
 	}
-	vm, exists, err := c.vmInformer.GetStore().GetByKey(namespace + "/" + controllerRef.Name)
+	vm, exists, err := c.vmIndexer.GetByKey(namespace + "/" + controllerRef.Name)
 	if err != nil {
 		return nil
 	}
@@ -373,7 +379,7 @@ func (c *PoolController) resolveControllerRef(namespace string, controllerRef *m
 	if controllerRef.Kind != poolv1.VirtualMachinePoolKind {
 		return nil
 	}
-	pool, exists, err := c.poolInformer.GetStore().GetByKey(namespace + "/" + controllerRef.Name)
+	pool, exists, err := c.poolIndexer.GetByKey(namespace + "/" + controllerRef.Name)
 	if err != nil {
 		return nil
 	}
@@ -389,17 +395,9 @@ func (c *PoolController) resolveControllerRef(namespace string, controllerRef *m
 	return pool.(*poolv1.VirtualMachinePool)
 }
 
-func mapCopy(src map[string]string) map[string]string {
-	dst := map[string]string{}
-	for k, v := range src {
-		dst[k] = v
-	}
-	return dst
-}
-
 // listControllerFromNamespace takes a namespace and returns all Pools from the Pool cache which run in this namespace
 func (c *PoolController) listControllerFromNamespace(namespace string) ([]*poolv1.VirtualMachinePool, error) {
-	objs, err := c.poolInformer.GetIndexer().ByIndex(cache.NamespaceIndex, namespace)
+	objs, err := c.poolIndexer.ByIndex(cache.NamespaceIndex, namespace)
 	if err != nil {
 		return nil, err
 	}
@@ -442,7 +440,7 @@ func (c *PoolController) Run(threadiness int, stopCh <-chan struct{}) {
 	log.Log.Info("Starting pool controller.")
 
 	// Wait for cache sync before we start the pool controller
-	cache.WaitForCacheSync(stopCh, c.poolInformer.HasSynced, c.vmInformer.HasSynced, c.vmiInformer.HasSynced, c.revisionInformer.HasSynced)
+	cache.WaitForCacheSync(stopCh, c.hasSynced)
 
 	// Start the actual work
 	for i := 0; i < threadiness; i++ {
@@ -459,7 +457,7 @@ func (c *PoolController) runWorker() {
 }
 
 func (c *PoolController) listVMsFromNamespace(namespace string) ([]*virtv1.VirtualMachine, error) {
-	objs, err := c.vmInformer.GetIndexer().ByIndex(cache.NamespaceIndex, namespace)
+	objs, err := c.vmIndexer.ByIndex(cache.NamespaceIndex, namespace)
 	if err != nil {
 		return nil, err
 	}
@@ -622,7 +620,7 @@ func indexVMSpec(spec *virtv1.VirtualMachineSpec, idx int) *virtv1.VirtualMachin
 	}
 
 	dvNameMap := map[string]string{}
-	for i, _ := range spec.DataVolumeTemplates {
+	for i := range spec.DataVolumeTemplates {
 
 		indexName := fmt.Sprintf("%s-%d", spec.DataVolumeTemplates[i].Name, idx)
 		dvNameMap[spec.DataVolumeTemplates[i].Name] = indexName
@@ -710,7 +708,7 @@ func (c *PoolController) getControllerRevision(namespace, name string) (*poolv1.
 
 	key := controller.NamespacedKey(namespace, name)
 
-	storeObj, exists, err := c.revisionInformer.GetStore().GetByKey(key)
+	storeObj, exists, err := c.revisionIndexer.GetByKey(key)
 	if !exists || err != nil {
 		return nil, false, err
 	}
@@ -734,7 +732,7 @@ func (c *PoolController) scaleOut(pool *poolv1.VirtualMachinePool, count int) er
 
 	var wg sync.WaitGroup
 
-	newNames := calculateNewVMNames(count, pool.Name, pool.Namespace, c.vmInformer.GetStore())
+	newNames := calculateNewVMNames(count, pool.Name, pool.Namespace, c.vmIndexer)
 
 	revisionName, err := c.ensureControllerRevision(pool)
 	if err != nil {
@@ -764,8 +762,8 @@ func (c *PoolController) scaleOut(pool *poolv1.VirtualMachinePool, count int) er
 
 			vm := virtv1.NewVMReferenceFromNameWithNS(pool.Namespace, name)
 
-			vm.Labels = mapCopy(pool.Spec.VirtualMachineTemplate.ObjectMeta.Labels)
-			vm.Annotations = mapCopy(pool.Spec.VirtualMachineTemplate.ObjectMeta.Annotations)
+			vm.Labels = maps.Clone(pool.Spec.VirtualMachineTemplate.ObjectMeta.Labels)
+			vm.Annotations = maps.Clone(pool.Spec.VirtualMachineTemplate.ObjectMeta.Annotations)
 			vm.Spec = *indexVMSpec(pool.Spec.VirtualMachineTemplate.Spec.DeepCopy(), index)
 			vm = injectPoolRevisionLabelsIntoVM(vm, revisionName)
 
@@ -846,8 +844,8 @@ func (c *PoolController) opportunisticUpdate(pool *poolv1.VirtualMachinePool, vm
 
 			vmCopy := vm.DeepCopy()
 
-			vmCopy.Labels = mapCopy(pool.Spec.VirtualMachineTemplate.ObjectMeta.Labels)
-			vmCopy.Annotations = mapCopy(pool.Spec.VirtualMachineTemplate.ObjectMeta.Annotations)
+			vmCopy.Labels = maps.Clone(pool.Spec.VirtualMachineTemplate.ObjectMeta.Labels)
+			vmCopy.Annotations = maps.Clone(pool.Spec.VirtualMachineTemplate.ObjectMeta.Annotations)
 			vmCopy.Spec = *indexVMSpec(pool.Spec.VirtualMachineTemplate.Spec.DeepCopy(), index)
 			vmCopy = injectPoolRevisionLabelsIntoVM(vmCopy, revisionName)
 
@@ -884,7 +882,7 @@ func (c *PoolController) proactiveUpdate(pool *poolv1.VirtualMachinePool, vmUpda
 			vm := vmUpdatedList[idx]
 
 			vmiKey := controller.NamespacedKey(vm.Namespace, vm.Name)
-			obj, exists, _ := c.vmiInformer.GetStore().GetByKey(vmiKey)
+			obj, exists, _ := c.vmiStore.GetByKey(vmiKey)
 			if !exists {
 				// no VMI to update
 				return
@@ -1086,7 +1084,7 @@ func (c *PoolController) isOutdatedVM(pool *poolv1.VirtualMachinePool, vm *virtv
 
 func (c *PoolController) pruneUnusedRevisions(pool *poolv1.VirtualMachinePool, vms []*virtv1.VirtualMachine) syncError {
 
-	keys, err := c.revisionInformer.GetIndexer().IndexKeys("vmpool", string(pool.UID))
+	keys, err := c.revisionIndexer.IndexKeys("vmpool", string(pool.UID))
 	if err != nil {
 		if err != nil {
 			return &syncErrorImpl{fmt.Errorf("Error while pruning vmpool revisions: %v", err), FailedRevisionPruningReason}
@@ -1115,7 +1113,7 @@ func (c *PoolController) pruneUnusedRevisions(pool *poolv1.VirtualMachinePool, v
 		// Check to see what revision is used by the VMI, and remove
 		// that from the revision prune list
 		vmiKey := controller.NamespacedKey(vm.Namespace, vm.Name)
-		obj, exists, _ := c.vmiInformer.GetStore().GetByKey(vmiKey)
+		obj, exists, _ := c.vmiStore.GetByKey(vmiKey)
 		if exists {
 			vmi := obj.(*virtv1.VirtualMachineInstance)
 			revisionName, exists = vmi.Labels[virtv1.VirtualMachinePoolRevisionName]
@@ -1126,7 +1124,7 @@ func (c *PoolController) pruneUnusedRevisions(pool *poolv1.VirtualMachinePool, v
 		}
 	}
 
-	for revisionName, _ := range deletionMap {
+	for revisionName := range deletionMap {
 		err := c.clientset.AppsV1().ControllerRevisions(pool.Namespace).Delete(context.Background(), revisionName, v1.DeleteOptions{})
 		if err != nil {
 			return &syncErrorImpl{fmt.Errorf("Error while pruning vmpool revisions: %v", err), FailedRevisionPruningReason}
@@ -1266,7 +1264,7 @@ func (c *PoolController) execute(key string) error {
 
 	var syncErr syncError
 
-	obj, poolExists, err := c.poolInformer.GetStore().GetByKey(key)
+	obj, poolExists, err := c.poolIndexer.GetByKey(key)
 	if err != nil {
 		return err
 	}
