@@ -22,6 +22,7 @@ import (
 	"context"
 	"encoding/json"
 	"fmt"
+	"maps"
 	"time"
 
 	"github.com/golang/mock/gomock"
@@ -45,6 +46,7 @@ import (
 	"kubevirt.io/client-go/kubecli"
 
 	virtcontroller "kubevirt.io/kubevirt/pkg/controller"
+	"kubevirt.io/kubevirt/pkg/pointer"
 	testutils "kubevirt.io/kubevirt/pkg/testutils"
 )
 
@@ -312,7 +314,7 @@ var _ = Describe("Pool", func() {
 		It("should delete controller revisions when pool is being deleted", func() {
 			pool, _ := DefaultPool(1)
 			pool.Status.Replicas = 0
-			pool.DeletionTimestamp = now()
+			pool.DeletionTimestamp = pointer.P(metav1.Now())
 
 			poolRevision := createPoolRevision(pool)
 
@@ -344,7 +346,7 @@ var _ = Describe("Pool", func() {
 			vmi.Spec = vm.Spec.Template.Spec
 			vmi.Name = vm.Name
 			vmi.Namespace = vm.Namespace
-			vmi.Labels = mapCopy(vm.Spec.Template.ObjectMeta.Labels)
+			vmi.Labels = maps.Clone(vm.Spec.Template.ObjectMeta.Labels)
 			vmi.OwnerReferences = []metav1.OwnerReference{{
 				APIVersion:         virtv1.VirtualMachineGroupVersionKind.GroupVersion().String(),
 				Kind:               virtv1.VirtualMachineGroupVersionKind.Kind,
@@ -605,7 +607,7 @@ var _ = Describe("Pool", func() {
 			for x := 5; x < 10; x++ {
 				newVM := vm.DeepCopy()
 				newVM.Name = fmt.Sprintf("%s-%d", pool.Name, x)
-				newVM.DeletionTimestamp = now()
+				newVM.DeletionTimestamp = pointer.P(metav1.Now())
 				addVM(newVM)
 			}
 
