@@ -10,7 +10,6 @@ import (
 
 	"golang.org/x/time/rate"
 
-	"github.com/prometheus/client_golang/prometheus"
 	k8sv1 "k8s.io/api/core/v1"
 	policy "k8s.io/api/policy/v1beta1"
 	"k8s.io/apimachinery/pkg/api/errors"
@@ -25,12 +24,15 @@ import (
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
 
 	migrationutils "kubevirt.io/kubevirt/pkg/util/migrations"
+	volumemig "kubevirt.io/kubevirt/pkg/virt-controller/watch/volume-migration"
 
+	v1 "kubevirt.io/api/core/v1"
 	virtv1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/kubevirt/pkg/controller"
+	metrics "kubevirt.io/kubevirt/pkg/monitoring/metrics/virt-controller"
 	"kubevirt.io/kubevirt/pkg/util/status"
 )
 
@@ -43,15 +45,12 @@ const (
 	FailedEvictVirtualMachineInstanceReason = "FailedEvict"
 	// SuccessfulEvictVirtualMachineInstanceReason is added in an event if a deletion of a VMI Succeeds
 	SuccessfulEvictVirtualMachineInstanceReason = "SuccessfulEvict"
-)
-
-var (
-	outdatedVirtualMachineInstanceWorkloads = prometheus.NewGauge(
-		prometheus.GaugeOpts{
-			Name: "kubevirt_vmi_number_of_outdated",
-			Help: "Indication for the total number of VirtualMachineInstance workloads that are not running within the most up-to-date version of the virt-launcher environment.",
-		},
-	)
+	// SuccessfulChangeAbortionReason is added in an event if a deletion of a
+	// migration succeeds
+	SuccessfulChangeAbortionReason = "SuccessfulChangeAbortion"
+	// FailedChangeAbortionReason is added in an event if a deletion of a
+	// migration succeeds
+	FailedChangeAbortionReason = "FailedChangeAbortion"
 )
 
 // time to wait before re-enqueing when outdated VMIs are still detected
@@ -63,10 +62,6 @@ const defaultThrottleInterval = 5 * time.Second
 const defaultBatchDeletionIntervalSeconds = 60
 const defaultBatchDeletionCount = 10
 
-func init() {
-	prometheus.MustRegister(outdatedVirtualMachineInstanceWorkloads)
-}
-
 type WorkloadUpdateController struct {
 	clientset             kubecli.KubevirtClient
 	queue                 workqueue.RateLimitingInterface
@@ -87,6 +82,7 @@ type updateData struct {
 	allOutdatedVMIs        []*virtv1.VirtualMachineInstance
 	migratableOutdatedVMIs []*virtv1.VirtualMachineInstance
 	evictOutdatedVMIs      []*virtv1.VirtualMachineInstance
+	abortChangeVMIs        []*virtv1.VirtualMachineInstance
 
 	numActiveMigrations int
 }
@@ -218,7 +214,8 @@ func (c *WorkloadUpdateController) updateVmi(_, obj interface{}) {
 		return
 	}
 
-	if !isHotplugInProgress(vmi) || migrationutils.IsMigrating(vmi) {
+	if !(isHotplugInProgress(vmi) || isVolumesUpdateInProgress(vmi)) ||
+		migrationutils.IsMigrating(vmi) {
 		return
 	}
 
@@ -319,27 +316,54 @@ func (c *WorkloadUpdateController) isOutdated(vmi *virtv1.VirtualMachineInstance
 func isHotplugInProgress(vmi *virtv1.VirtualMachineInstance) bool {
 	condManager := controller.NewVirtualMachineInstanceConditionManager()
 	return condManager.HasCondition(vmi, virtv1.VirtualMachineInstanceVCPUChange) ||
-		condManager.HasCondition(vmi, virtv1.VirtualMachineInstanceMemoryChange)
+		condManager.HasConditionWithStatus(vmi, virtv1.VirtualMachineInstanceMemoryChange, k8sv1.ConditionTrue)
+}
+
+func isVolumesUpdateInProgress(vmi *virtv1.VirtualMachineInstance) bool {
+	return controller.NewVirtualMachineInstanceConditionManager().HasConditionWithStatus(vmi,
+		virtv1.VirtualMachineInstanceVolumesChange, k8sv1.ConditionTrue)
 }
 
 func (c *WorkloadUpdateController) doesRequireMigration(vmi *virtv1.VirtualMachineInstance) bool {
 	if vmi.IsFinal() || migrationutils.IsMigrating(vmi) {
 		return false
 	}
-
+	if metav1.HasAnnotation(vmi.ObjectMeta, v1.WorkloadUpdateMigrationAbortionAnnotation) {
+		return false
+	}
 	if isHotplugInProgress(vmi) {
 		return true
 	}
+	if isVolumesUpdateInProgress(vmi) {
+		return true
+	}
 
 	return false
 }
 
+func (c *WorkloadUpdateController) shouldAbortMigration(vmi *virtv1.VirtualMachineInstance) bool {
+	numMig := len(migrationutils.ListWorkloadUpdateMigrations(c.migrationInformer.GetStore(), vmi.Name, vmi.Namespace))
+	if metav1.HasAnnotation(vmi.ObjectMeta, virtv1.WorkloadUpdateMigrationAbortionAnnotation) {
+		return numMig > 0
+	}
+	if isHotplugInProgress(vmi) {
+		return false
+	}
+	if isVolumesUpdateInProgress(vmi) {
+		return false
+	}
+	if vmi.Status.MigrationState != nil && vmi.Status.MigrationState.TargetNodeDomainReadyTimestamp != nil {
+		return false
+	}
+	return numMig > 0
+}
+
 func (c *WorkloadUpdateController) getUpdateData(kv *virtv1.KubeVirt) *updateData {
 	data := &updateData{}
 
 	lookup := make(map[string]bool)
 
-	migrations := migrationutils.ListUnfinishedMigrations(c.migrationInformer)
+	migrations := migrationutils.ListUnfinishedMigrations(c.migrationInformer.GetStore())
 
 	for _, migration := range migrations {
 		lookup[migration.Namespace+"/"+migration.Spec.VMIName] = true
@@ -362,10 +386,14 @@ func (c *WorkloadUpdateController) getUpdateData(kv *virtv1.KubeVirt) *updateDat
 	objs := c.vmiInformer.GetStore().List()
 	for _, obj := range objs {
 		vmi := obj.(*virtv1.VirtualMachineInstance)
-		if !vmi.IsRunning() || vmi.IsFinal() || vmi.DeletionTimestamp != nil {
+		switch {
+		case !vmi.IsRunning() || vmi.IsFinal() || vmi.DeletionTimestamp != nil:
 			// only consider running VMIs that aren't being shutdown
 			continue
-		} else if !c.isOutdated(vmi) && !c.doesRequireMigration(vmi) {
+		case c.shouldAbortMigration(vmi) && !c.isOutdated(vmi):
+			data.abortChangeVMIs = append(data.abortChangeVMIs, vmi)
+			continue
+		case !c.isOutdated(vmi) && !c.doesRequireMigration(vmi):
 			continue
 		}
 
@@ -381,7 +409,7 @@ func (c *WorkloadUpdateController) getUpdateData(kv *virtv1.KubeVirt) *updateDat
 			continue
 		}
 
-		if automatedMigrationAllowed && vmi.IsMigratable() {
+		if automatedMigrationAllowed && (vmi.IsMigratable() || volumemig.CanVolumesUpdateMigration(vmi)) {
 			data.migratableOutdatedVMIs = append(data.migratableOutdatedVMIs, vmi)
 		} else if automatedShutdownAllowed {
 			data.evictOutdatedVMIs = append(data.evictOutdatedVMIs, vmi)
@@ -429,7 +457,7 @@ func (c *WorkloadUpdateController) sync(kv *virtv1.KubeVirt) error {
 		return err
 	}
 
-	outdatedVirtualMachineInstanceWorkloads.Set(float64(len(data.allOutdatedVMIs)))
+	metrics.SetOutdatedVirtualMachineInstanceWorkloads(len(data.allOutdatedVMIs))
 
 	// update outdated workload count on kv
 	if kv.Status.OutdatedVirtualMachineInstanceWorkloads == nil || *kv.Status.OutdatedVirtualMachineInstanceWorkloads != len(data.allOutdatedVMIs) {
@@ -466,7 +494,7 @@ func (c *WorkloadUpdateController) sync(kv *virtv1.KubeVirt) error {
 	// Rather than enqueing based on VMI activity, we keep periodically poping the loop
 	// until all VMIs are updated. Watching all VMI activity is chatty for this controller
 	// when we don't need to be that efficent in how quickly the updates are being processed.
-	if len(data.evictOutdatedVMIs) != 0 || len(data.migratableOutdatedVMIs) != 0 {
+	if len(data.evictOutdatedVMIs) != 0 || len(data.migratableOutdatedVMIs) != 0 || len(data.abortChangeVMIs) != 0 {
 		c.queue.AddAfter(key, periodicReEnqueueIntervalSeconds)
 	}
 
@@ -520,7 +548,7 @@ func (c *WorkloadUpdateController) sync(kv *virtv1.KubeVirt) error {
 		evictionCandidates = data.evictOutdatedVMIs[0:batchDeletionCount]
 	}
 
-	wgLen := len(migrationCandidates) + len(evictionCandidates)
+	wgLen := len(migrationCandidates) + len(evictionCandidates) + len(data.abortChangeVMIs)
 	wg := &sync.WaitGroup{}
 	wg.Add(wgLen)
 	errChan := make(chan error, wgLen)
@@ -528,12 +556,18 @@ func (c *WorkloadUpdateController) sync(kv *virtv1.KubeVirt) error {
 	c.migrationExpectations.ExpectCreations(key, migrateCount)
 	for _, vmi := range migrationCandidates {
 		go func(vmi *virtv1.VirtualMachineInstance) {
+			var labels map[string]string
+			if isVolumesUpdateInProgress(vmi) {
+				labels = make(map[string]string)
+				labels[virtv1.VolumesUpdateMigration] = vmi.Name
+			}
 			defer wg.Done()
 			createdMigration, err := c.clientset.VirtualMachineInstanceMigration(vmi.Namespace).Create(context.Background(), &virtv1.VirtualMachineInstanceMigration{
 				ObjectMeta: metav1.ObjectMeta{
 					Annotations: map[string]string{
 						virtv1.WorkloadUpdateMigrationAnnotation: "",
 					},
+					Labels:       labels,
 					GenerateName: "kubevirt-workload-update-",
 				},
 				Spec: virtv1.VirtualMachineInstanceMigrationSpec{
@@ -557,7 +591,7 @@ func (c *WorkloadUpdateController) sync(kv *virtv1.KubeVirt) error {
 		go func(vmi *virtv1.VirtualMachineInstance) {
 			defer wg.Done()
 
-			pod, err := controller.CurrentVMIPod(vmi, c.podInformer)
+			pod, err := controller.CurrentVMIPod(vmi, c.podInformer.GetIndexer())
 			if err != nil {
 
 				log.Log.Object(vmi).Reason(err).Errorf("Failed to detect active pod for vmi during workload update")
@@ -585,6 +619,25 @@ func (c *WorkloadUpdateController) sync(kv *virtv1.KubeVirt) error {
 		}(vmi)
 	}
 
+	for _, vmi := range data.abortChangeVMIs {
+		go func(vmi *virtv1.VirtualMachineInstance) {
+			defer wg.Done()
+			migList := migrationutils.ListWorkloadUpdateMigrations(c.migrationInformer.GetStore(), vmi.Name, vmi.Namespace)
+			for _, mig := range migList {
+				err = c.clientset.VirtualMachineInstanceMigration(vmi.Namespace).Delete(context.Background(), mig.Name, metav1.DeleteOptions{})
+				if err != nil && !errors.IsNotFound(err) {
+					log.Log.Object(vmi).Reason(err).Errorf("Failed to delete the migration due to a migration abortion")
+					c.recorder.Eventf(vmi, k8sv1.EventTypeNormal, FailedChangeAbortionReason, "Failed to abort change for vmi: %s: %v", vmi.Name, err)
+					errChan <- err
+				} else if err == nil {
+					log.Log.Infof("Delete migration %s due to an update change abortion", mig.Name)
+					c.recorder.Eventf(vmi, k8sv1.EventTypeNormal, SuccessfulChangeAbortionReason, "Aborted change for vmi: %s", vmi.Name)
+
+				}
+			}
+
+		}(vmi)
+	}
 	wg.Wait()
 
 	select {
