@@ -24,11 +24,9 @@ import (
 	"fmt"
 	"net"
 	"os"
-	"path"
 	"path/filepath"
 	"strings"
 	"sync"
-	"time"
 
 	"context"
 
@@ -54,71 +52,13 @@ type MDEV struct {
 }
 
 type MediatedDevicePlugin struct {
-	devs           []*pluginapi.Device
-	server         *grpc.Server
-	socketPath     string
-	stop           <-chan struct{}
-	health         chan deviceHealth
-	devicePath     string
-	resourceName   string
-	done           chan struct{}
-	deviceRoot     string
+	*DevicePluginBase
 	iommuToMDEVMap map[string]string
-	initialized    bool
-	lock           *sync.Mutex
-	deregistered   chan struct{}
 }
 
-func NewMediatedDevicePlugin(mdevs []*MDEV, resourceName string) *MediatedDevicePlugin {
-	s := strings.Split(resourceName, "/")
-	mdevTypeName := s[1]
-	serverSock := SocketPath(mdevTypeName)
-	iommuToMDEVMap := make(map[string]string)
-
-	initHandler()
-
-	devs := constructDPIdevicesFromMdev(mdevs, iommuToMDEVMap)
-	dpi := &MediatedDevicePlugin{
-		devs:           devs,
-		socketPath:     serverSock,
-		health:         make(chan deviceHealth),
-		resourceName:   resourceName,
-		devicePath:     vfioDevicePath,
-		deviceRoot:     util.HostRootMount,
-		iommuToMDEVMap: iommuToMDEVMap,
-		initialized:    false,
-		lock:           &sync.Mutex{},
-	}
-
-	return dpi
-}
-
-func constructDPIdevicesFromMdev(mdevs []*MDEV, iommuToMDEVMap map[string]string) (devs []*pluginapi.Device) {
-	for _, mdev := range mdevs {
-		iommuToMDEVMap[mdev.iommuGroup] = mdev.UUID
-		dpiDev := &pluginapi.Device{
-			ID:     string(mdev.iommuGroup),
-			Health: pluginapi.Healthy,
-		}
-		if mdev.numaNode >= 0 {
-			numaInfo := &pluginapi.NUMANode{
-				ID: int64(mdev.numaNode),
-			}
-			dpiDev.Topology = &pluginapi.TopologyInfo{
-				Nodes: []*pluginapi.NUMANode{numaInfo},
-			}
-		}
-		devs = append(devs, dpiDev)
-	}
-	return
-}
-
-// Start starts the device plugin
 func (dpi *MediatedDevicePlugin) Start(stop <-chan struct{}) (err error) {
 	logger := log.DefaultLogger()
 	dpi.stop = stop
-	dpi.done = make(chan struct{})
-	dpi.deregistered = make(chan struct{})
 
 	err = dpi.cleanup()
 	if err != nil {
@@ -162,8 +102,54 @@ func (dpi *MediatedDevicePlugin) Start(stop <-chan struct{}) (err error) {
 	return err
 }
 
-func (dpi *MediatedDevicePlugin) GetDeviceName() string {
-	return dpi.resourceName
+func NewMediatedDevicePlugin(mdevs []*MDEV, resourceName string) *MediatedDevicePlugin {
+	s := strings.Split(resourceName, "/")
+	mdevTypeName := s[1]
+	serverSock := SocketPath(mdevTypeName)
+	iommuToMDEVMap := make(map[string]string)
+
+	initHandler()
+
+	devs := constructDPIdevicesFromMdev(mdevs, iommuToMDEVMap)
+
+	dpi := &MediatedDevicePlugin{
+		DevicePluginBase: &DevicePluginBase{
+			devs:         devs,
+			socketPath:   serverSock,
+			resourceName: resourceName,
+			devicePath:   vfioDevicePath,
+			deviceRoot:   util.HostRootMount,
+			server:       grpc.NewServer([]grpc.ServerOption{}...),
+			initialized:  false,
+			lock:         &sync.Mutex{},
+			health:       make(chan deviceHealth),
+			done:         make(chan struct{}),
+			deregistered: make(chan struct{}),
+		},
+		iommuToMDEVMap: iommuToMDEVMap,
+	}
+
+	return dpi
+}
+
+func constructDPIdevicesFromMdev(mdevs []*MDEV, iommuToMDEVMap map[string]string) (devs []*pluginapi.Device) {
+	for _, mdev := range mdevs {
+		iommuToMDEVMap[mdev.iommuGroup] = mdev.UUID
+		dpiDev := &pluginapi.Device{
+			ID:     string(mdev.iommuGroup),
+			Health: pluginapi.Healthy,
+		}
+		if mdev.numaNode >= 0 {
+			numaInfo := &pluginapi.NUMANode{
+				ID: int64(mdev.numaNode),
+			}
+			dpiDev.Topology = &pluginapi.TopologyInfo{
+				Nodes: []*pluginapi.NUMANode{numaInfo},
+			}
+		}
+		devs = append(devs, dpiDev)
+	}
+	return
 }
 
 func (dpi *MediatedDevicePlugin) Allocate(_ context.Context, r *pluginapi.AllocateRequest) (*pluginapi.AllocateResponse, error) {
@@ -213,101 +199,6 @@ func (dpi *MediatedDevicePlugin) Allocate(_ context.Context, r *pluginapi.Alloca
 	return resp, nil
 }
 
-// Stop stops the gRPC server
-func (dpi *MediatedDevicePlugin) stopDevicePlugin() error {
-	defer func() {
-		if !IsChanClosed(dpi.done) {
-			close(dpi.done)
-		}
-	}()
-
-	// Give the device plugin one second to properly deregister
-	ticker := time.NewTicker(1 * time.Second)
-	defer ticker.Stop()
-	select {
-	case <-dpi.deregistered:
-	case <-ticker.C:
-	}
-
-	dpi.server.Stop()
-	dpi.setInitialized(false)
-	return dpi.cleanup()
-}
-
-// Register registers the device plugin for the given resourceName with Kubelet.
-func (dpi *MediatedDevicePlugin) register() error {
-	conn, err := gRPCConnect(pluginapi.KubeletSocket, connectionTimeout)
-	if err != nil {
-		return err
-	}
-	defer conn.Close()
-
-	client := pluginapi.NewRegistrationClient(conn)
-	reqt := &pluginapi.RegisterRequest{
-		Version:      pluginapi.Version,
-		Endpoint:     path.Base(dpi.socketPath),
-		ResourceName: dpi.resourceName,
-	}
-
-	_, err = client.Register(context.Background(), reqt)
-	if err != nil {
-		return err
-	}
-	return nil
-}
-
-func (dpi *MediatedDevicePlugin) ListAndWatch(_ *pluginapi.Empty, s pluginapi.DevicePlugin_ListAndWatchServer) error {
-	s.Send(&pluginapi.ListAndWatchResponse{Devices: dpi.devs})
-
-	done := false
-	for {
-		select {
-		case devHealth := <-dpi.health:
-			for _, dev := range dpi.devs {
-				if devHealth.DevId == dev.ID {
-					dev.Health = devHealth.Health
-				}
-			}
-			s.Send(&pluginapi.ListAndWatchResponse{Devices: dpi.devs})
-		case <-dpi.stop:
-			done = true
-		case <-dpi.done:
-			done = true
-		}
-		if done {
-			break
-		}
-	}
-	// Send empty list to increase the chance that the kubelet acts fast on stopped device plugins
-	// There exists no explicit way to deregister devices
-	emptyList := []*pluginapi.Device{}
-	if err := s.Send(&pluginapi.ListAndWatchResponse{Devices: emptyList}); err != nil {
-		log.DefaultLogger().Reason(err).Infof("%s device plugin failed to deregister", dpi.resourceName)
-	}
-	close(dpi.deregistered)
-	return nil
-}
-
-func (dpi *MediatedDevicePlugin) cleanup() error {
-	if err := os.Remove(dpi.socketPath); err != nil && !errors.Is(err, os.ErrNotExist) {
-		return err
-	}
-
-	return nil
-}
-
-func (dpi *MediatedDevicePlugin) GetDevicePluginOptions(_ context.Context, _ *pluginapi.Empty) (*pluginapi.DevicePluginOptions, error) {
-	options := &pluginapi.DevicePluginOptions{
-		PreStartRequired: false,
-	}
-	return options, nil
-}
-
-func (dpi *MediatedDevicePlugin) PreStartContainer(_ context.Context, _ *pluginapi.PreStartContainerRequest) (*pluginapi.PreStartContainerResponse, error) {
-	res := &pluginapi.PreStartContainerResponse{}
-	return res, nil
-}
-
 func discoverPermittedHostMediatedDevices(supportedMdevsMap map[string]string) map[string][]*MDEV {
 	initHandler()
 
@@ -351,7 +242,7 @@ func discoverPermittedHostMediatedDevices(supportedMdevsMap map[string]string) m
 	return mdevsMap
 }
 
-func (dpi *MediatedDevicePlugin) healthCheck() error {
+func (dpi *MediatedDevicePlugin) HealthCheck() error {
 	logger := log.DefaultLogger()
 	monitoredDevices := make(map[string]string)
 	watcher, err := fsnotify.NewWatcher()
@@ -458,15 +349,3 @@ func getMdevTypeName(mdevUUID string) (string, error) {
 	typeNameStr = strings.TrimSpace(typeNameStr)
 	return typeNameStr, nil
 }
-
-func (dpi *MediatedDevicePlugin) GetInitialized() bool {
-	dpi.lock.Lock()
-	defer dpi.lock.Unlock()
-	return dpi.initialized
-}
-
-func (dpi *MediatedDevicePlugin) setInitialized(initialized bool) {
-	dpi.lock.Lock()
-	dpi.initialized = initialized
-	dpi.lock.Unlock()
-}
