@@ -30,7 +30,6 @@ import (
 	"strconv"
 	"strings"
 	"sync"
-	"time"
 
 	"github.com/fsnotify/fsnotify"
 	"google.golang.org/grpc"
@@ -44,59 +43,22 @@ import (
 )
 
 type SocketDevicePlugin struct {
-	devs             []*pluginapi.Device
-	server           *grpc.Server
-	pluginSocketPath string
-	stop             <-chan struct{}
-	health           chan deviceHealth
-	socketDir        string
-	socket           string
-	socketName       string
-	resourceName     string
-	done             chan struct{}
-	initialized      bool
-	lock             *sync.Mutex
-	deregistered     chan struct{}
+	*DevicePluginBase
+	socketDir  string
+	socket     string
+	socketName string
 }
 
-func NewSocketDevicePlugin(socketName, socketDir, socket string, maxDevices int) *SocketDevicePlugin {
-	dpi := &SocketDevicePlugin{
-		pluginSocketPath: SocketPath(strings.Replace(socketName, "/", "-", -1)),
-		socket:           socket,
-		socketDir:        socketDir,
-		socketName:       socketName,
-		health:           make(chan deviceHealth),
-		resourceName:     fmt.Sprintf("%s/%s", DeviceNamespace, socketName),
-		initialized:      false,
-		lock:             &sync.Mutex{},
-	}
-	for i := 0; i < maxDevices; i++ {
-		deviceId := dpi.socketName + strconv.Itoa(i)
-		dpi.devs = append(dpi.devs, &pluginapi.Device{
-			ID:     deviceId,
-			Health: pluginapi.Healthy,
-		})
-	}
-	return dpi
-}
-
-func (dpi *SocketDevicePlugin) GetDeviceName() string {
-	return dpi.socketName
-}
-
-// Start starts the device plugin
 func (dpi *SocketDevicePlugin) Start(stop <-chan struct{}) (err error) {
 	logger := log.DefaultLogger()
 	dpi.stop = stop
-	dpi.done = make(chan struct{})
-	dpi.deregistered = make(chan struct{})
 
 	err = dpi.cleanup()
 	if err != nil {
 		return err
 	}
 
-	sock, err := net.Listen("unix", dpi.pluginSocketPath)
+	sock, err := net.Listen("unix", dpi.socketPath)
 	if err != nil {
 		return fmt.Errorf("error creating GRPC server socket: %v", err)
 	}
@@ -112,7 +74,7 @@ func (dpi *SocketDevicePlugin) Start(stop <-chan struct{}) (err error) {
 		errChan <- dpi.server.Serve(sock)
 	}()
 
-	err = waitForGRPCServer(dpi.pluginSocketPath, connectionTimeout)
+	err = waitForGRPCServer(dpi.socketPath, connectionTimeout)
 	if err != nil {
 		return fmt.Errorf("error starting the GRPC server: %v", err)
 	}
@@ -127,30 +89,36 @@ func (dpi *SocketDevicePlugin) Start(stop <-chan struct{}) (err error) {
 	}()
 
 	dpi.setInitialized(true)
-	logger.Infof("%s device plugin started", dpi.socketName)
+	logger.Infof("%s device plugin started", dpi.resourceName)
 	err = <-errChan
 
 	return err
 }
 
-// Stop stops the gRPC server
-func (dpi *SocketDevicePlugin) stopDevicePlugin() error {
-	defer func() {
-		if !IsChanClosed(dpi.done) {
-			close(dpi.done)
-		}
-	}()
-
-	// Give the device plugin one second to properly deregister
-	ticker := time.NewTicker(1 * time.Second)
-	defer ticker.Stop()
-	select {
-	case <-dpi.deregistered:
-	case <-ticker.C:
+func NewSocketDevicePlugin(socketName, socketDir, socket string, maxDevices int) *SocketDevicePlugin {
+	dpi := &SocketDevicePlugin{
+		DevicePluginBase: &DevicePluginBase{
+			health:       make(chan deviceHealth),
+			resourceName: fmt.Sprintf("%s/%s", DeviceNamespace, socketName),
+			initialized:  false,
+			lock:         &sync.Mutex{},
+			done:         make(chan struct{}),
+			deregistered: make(chan struct{}),
+			socketPath:   SocketPath(strings.Replace(socketName, "/", "-", -1)),
+		},
+		socket:     socket,
+		socketDir:  socketDir,
+		socketName: socketName,
 	}
-	dpi.server.Stop()
-	dpi.setInitialized(false)
-	return dpi.cleanup()
+
+	for i := 0; i < maxDevices; i++ {
+		deviceId := dpi.socketName + strconv.Itoa(i)
+		dpi.devs = append(dpi.devs, &pluginapi.Device{
+			ID:     deviceId,
+			Health: pluginapi.Healthy,
+		})
+	}
+	return dpi
 }
 
 // Register registers the device plugin for the given resourceName with Kubelet.
@@ -164,7 +132,7 @@ func (dpi *SocketDevicePlugin) register() error {
 	client := pluginapi.NewRegistrationClient(conn)
 	reqt := &pluginapi.RegisterRequest{
 		Version:      pluginapi.Version,
-		Endpoint:     path.Base(dpi.pluginSocketPath),
+		Endpoint:     path.Base(dpi.socketPath),
 		ResourceName: dpi.resourceName,
 	}
 
@@ -175,33 +143,6 @@ func (dpi *SocketDevicePlugin) register() error {
 	return nil
 }
 
-func (dpi *SocketDevicePlugin) ListAndWatch(e *pluginapi.Empty, s pluginapi.DevicePlugin_ListAndWatchServer) error {
-	s.Send(&pluginapi.ListAndWatchResponse{Devices: dpi.devs})
-
-	done := false
-	for {
-		select {
-		case <-dpi.health:
-			s.Send(&pluginapi.ListAndWatchResponse{Devices: dpi.devs})
-		case <-dpi.stop:
-			done = true
-		case <-dpi.done:
-			done = true
-		}
-		if done {
-			break
-		}
-	}
-	// Send empty list to increase the chance that the kubelet acts fast on stopped device plugins
-	// There exists no explicit way to deregister devices
-	emptyList := []*pluginapi.Device{}
-	if err := s.Send(&pluginapi.ListAndWatchResponse{Devices: emptyList}); err != nil {
-		log.DefaultLogger().Reason(err).Infof("%s device plugin failed to deregister", dpi.socketName)
-	}
-	close(dpi.deregistered)
-	return nil
-}
-
 func (dpi *SocketDevicePlugin) Allocate(ctx context.Context, r *pluginapi.AllocateRequest) (*pluginapi.AllocateResponse, error) {
 	log.DefaultLogger().Infof("Socket Allocate: resourceName: %s", dpi.socketName)
 	log.DefaultLogger().Infof("Socket Allocate: request: %v", r.ContainerRequests)
@@ -235,26 +176,6 @@ func (dpi *SocketDevicePlugin) Allocate(ctx context.Context, r *pluginapi.Alloca
 	return &response, nil
 }
 
-func (dpi *SocketDevicePlugin) cleanup() error {
-	if err := os.Remove(dpi.pluginSocketPath); err != nil && !errors.Is(err, os.ErrNotExist) {
-		return err
-	}
-
-	return nil
-}
-
-func (dpi *SocketDevicePlugin) GetDevicePluginOptions(_ context.Context, _ *pluginapi.Empty) (*pluginapi.DevicePluginOptions, error) {
-	options := &pluginapi.DevicePluginOptions{
-		PreStartRequired: false,
-	}
-	return options, nil
-}
-
-func (dpi *SocketDevicePlugin) PreStartContainer(_ context.Context, _ *pluginapi.PreStartContainerRequest) (*pluginapi.PreStartContainerResponse, error) {
-	res := &pluginapi.PreStartContainerResponse{}
-	return res, nil
-}
-
 func (dpi *SocketDevicePlugin) healthCheck() error {
 	logger := log.DefaultLogger()
 	watcher, err := fsnotify.NewWatcher()
@@ -281,13 +202,13 @@ func (dpi *SocketDevicePlugin) healthCheck() error {
 	}
 	logger.Infof("device '%s' is present.", devicePath)
 
-	dirName := filepath.Dir(dpi.pluginSocketPath)
+	dirName := filepath.Dir(dpi.socketPath)
 	err = watcher.Add(dirName)
 
 	if err != nil {
 		return fmt.Errorf("failed to add the device-plugin kubelet path to the watcher: %v", err)
 	}
-	_, err = os.Stat(dpi.pluginSocketPath)
+	_, err = os.Stat(dpi.socketPath)
 	if err != nil {
 		return fmt.Errorf("failed to stat the device-plugin socket: %v", err)
 	}
@@ -309,22 +230,10 @@ func (dpi *SocketDevicePlugin) healthCheck() error {
 					logger.Infof("monitored device %s disappeared", dpi.socketName)
 					dpi.health <- deviceHealth{Health: pluginapi.Unhealthy}
 				}
-			} else if event.Name == dpi.pluginSocketPath && event.Op == fsnotify.Remove {
+			} else if event.Name == dpi.socketPath && event.Op == fsnotify.Remove {
 				logger.Infof("device socket file for device %s was removed, kubelet probably restarted.", dpi.socketName)
 				return nil
 			}
 		}
 	}
 }
-
-func (dpi *SocketDevicePlugin) GetInitialized() bool {
-	dpi.lock.Lock()
-	defer dpi.lock.Unlock()
-	return dpi.initialized
-}
-
-func (dpi *SocketDevicePlugin) setInitialized(initialized bool) {
-	dpi.lock.Lock()
-	defer dpi.lock.Unlock()
-	dpi.initialized = initialized
-}
