@@ -25,7 +25,6 @@ import (
 	"os"
 	"path/filepath"
 	"runtime"
-	"strings"
 
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/log"
@@ -44,14 +43,6 @@ const (
 	supportedFeaturesXml = "supported_features.xml"
 )
 
-func (n *NodeLabeller) getMinCpuFeature() cpuFeatures {
-	minCPUModel := n.clusterConfig.GetMinCPUModel()
-	if minCPUModel == "" {
-		minCPUModel = util.DefaultMinCPUModel
-	}
-	return n.cpuInfo.usableModels[minCPUModel]
-}
-
 func (n *NodeLabeller) getSupportedCpuModels(obsoleteCPUsx86 map[string]bool) []string {
 	supportedCPUModels := make([]string, 0)
 
@@ -165,36 +156,6 @@ func (n *NodeLabeller) loadHostCapabilities() error {
 	return nil
 }
 
-// loadCPUInfo load info about all cpu models
-func (n *NodeLabeller) loadCPUInfo() error {
-	files, err := os.ReadDir(filepath.Join(n.volumePath, "cpu_map"))
-	if err != nil {
-		return err
-	}
-
-	models := make(map[string]cpuFeatures)
-	archPrefix, ok := util.DefaultArchitecturePrefix[runtime.GOARCH]
-	// Only arm64 and amd64 architectures are currently supported.
-	if !ok {
-		return fmt.Errorf("unsupported system architecture")
-	}
-	for _, f := range files {
-		fileName := f.Name()
-		if strings.HasPrefix(fileName, archPrefix) {
-			features, err := n.loadFeatures(fileName)
-			if err != nil {
-				return err
-			}
-			cpuName := strings.TrimSuffix(strings.TrimPrefix(fileName, archPrefix), ".xml")
-
-			models[cpuName] = features
-		}
-	}
-
-	n.cpuInfo.usableModels = models
-	return nil
-}
-
 func (n *NodeLabeller) getDomCapabilities() (HostDomCapabilities, error) {
 	domCapabilitiesFile := filepath.Join(n.volumePath, n.domCapabilitiesFileName)
 	hostDomCapabilities := HostDomCapabilities{}
@@ -212,31 +173,6 @@ func (n *NodeLabeller) getDomCapabilities() (HostDomCapabilities, error) {
 	return hostDomCapabilities, err
 }
 
-// LoadFeatures loads features for given cpu name
-func (n *NodeLabeller) loadFeatures(fileName string) (cpuFeatures, error) {
-	if fileName == "" {
-		return nil, fmt.Errorf("file name can't be empty")
-	}
-
-	cpuFeaturepath := getPathCPUFeatures(n.volumePath, fileName)
-	features := FeatureModel{}
-	err := n.getStructureFromXMLFile(cpuFeaturepath, &features)
-	if err != nil {
-		return nil, err
-	}
-
-	modelFeatures := cpuFeatures{}
-	for _, f := range features.Model.Features {
-		modelFeatures[f.Name] = true
-	}
-	return modelFeatures, nil
-}
-
-// getPathCPUFeatures creates path where folder with cpu models is
-func getPathCPUFeatures(volumePath string, name string) string {
-	return filepath.Join(volumePath, "cpu_map", name)
-}
-
 // GetStructureFromXMLFile load data from xml file and unmarshals them into given structure
 // Given structure has to be pointer
 func (n *NodeLabeller) getStructureFromXMLFile(path string, structure interface{}) error {
