@@ -184,7 +184,7 @@ var _ = Describe("Node-labeller config", func() {
 		nlController.removeLabellerLabels(node)
 
 		badKey := ""
-		for key, _ := range node.Labels {
+		for key := range node.Labels {
 			for _, labellerPrefix := range nodeLabellerLabels {
 				if strings.HasPrefix(key, labellerPrefix) {
 					badKey = key
@@ -331,7 +331,7 @@ var nodeLabels = map[string]string{
 	"hyperv.node.kubevirt.io/tlbflush":                                 "true",
 	"hyperv.node.kubevirt.io/vpindex":                                  "true",
 	"kubernetes.io/arch":                                               "amd64",
-	"kubernetes.io/hostname":                                           "node01",
+	k8sv1.LabelHostname:                                                "node01",
 	"kubernetes.io/os":                                                 "linux",
 	"kubevirt.io/schedulable":                                          "true",
 	"node-role.kubernetes.io/control-plane":                            "",
