@@ -31,7 +31,8 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/log"
 
-	"kubevirt.io/kubevirt/pkg/network/sriov"
+	"kubevirt.io/kubevirt/pkg/network/deviceinfo"
+	"kubevirt.io/kubevirt/pkg/network/downwardapi"
 	"kubevirt.io/kubevirt/pkg/network/vmispec"
 	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/api"
 	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/device"
@@ -49,7 +50,7 @@ func CreateHostDevices(vmi *v1.VirtualMachineInstance) ([]api.HostDevice, error)
 	if len(SRIOVInterfaces) == 0 {
 		return []api.HostDevice{}, nil
 	}
-	netStatusPath := path.Join(sriov.MountPath, sriov.VolumePath)
+	netStatusPath := path.Join(downwardapi.MountPath, downwardapi.NetworkInfoVolumePath)
 	pciAddressPoolWithNetworkStatus, err := newPCIAddressPoolWithNetworkStatusFromFile(netStatusPath)
 	if err != nil {
 		return nil, err
@@ -69,15 +70,15 @@ func CreateHostDevices(vmi *v1.VirtualMachineInstance) ([]api.HostDevice, error)
 // - file empty post-polling (timeout) - return err to fail SyncVMI.
 // - other error reading file (i.e. file not exist) - return no error but PCIAddressWithNetworkStatusPool.Len() will return 0.
 func newPCIAddressPoolWithNetworkStatusFromFile(path string) (*PCIAddressWithNetworkStatusPool, error) {
-	networkPCIMapBytes, err := readFileUntilNotEmpty(path)
+	networkDeviceInfoBytes, err := readFileUntilNotEmpty(path)
 	if err != nil {
-		if isFileEmptyAfterTimeout(err, networkPCIMapBytes) {
+		if isFileEmptyAfterTimeout(err, networkDeviceInfoBytes) {
 			return nil, err
 		}
 		return nil, nil
 	}
 
-	return NewPCIAddressPoolWithNetworkStatus(networkPCIMapBytes)
+	return NewPCIAddressPoolWithNetworkStatus(networkDeviceInfoBytes)
 }
 
 func readFileUntilNotEmpty(networkPCIMapPath string) ([]byte, error) {
@@ -103,7 +104,7 @@ func createHostDevicesMetadata(ifaces []v1.Interface) []hostdevice.HostDeviceMet
 	var hostDevicesMetaData []hostdevice.HostDeviceMetaData
 	for _, iface := range ifaces {
 		hostDevicesMetaData = append(hostDevicesMetaData, hostdevice.HostDeviceMetaData{
-			AliasPrefix:  sriov.AliasPrefix,
+			AliasPrefix:  deviceinfo.SRIOVAliasPrefix,
 			Name:         iface.Name,
 			ResourceName: iface.Name,
 			DecorateHook: newDecorateHook(iface),
@@ -130,7 +131,7 @@ func newDecorateHook(iface v1.Interface) func(hostDevice *api.HostDevice) error
 }
 
 func SafelyDetachHostDevices(domainSpec *api.DomainSpec, eventDetach hostdevice.EventRegistrar, dom hostdevice.DeviceDetacher, timeout time.Duration) error {
-	sriovDevices := hostdevice.FilterHostDevicesByAlias(domainSpec.Devices.HostDevices, sriov.AliasPrefix)
+	sriovDevices := hostdevice.FilterHostDevicesByAlias(domainSpec.Devices.HostDevices, deviceinfo.SRIOVAliasPrefix)
 	return hostdevice.SafelyDetachHostDevices(sriovDevices, eventDetach, dom, timeout)
 }
 
@@ -139,7 +140,7 @@ func GetHostDevicesToAttach(vmi *v1.VirtualMachineInstance, domainSpec *api.Doma
 	if err != nil {
 		return nil, err
 	}
-	currentAttachedSRIOVHostDevices := hostdevice.FilterHostDevicesByAlias(domainSpec.Devices.HostDevices, sriov.AliasPrefix)
+	currentAttachedSRIOVHostDevices := hostdevice.FilterHostDevicesByAlias(domainSpec.Devices.HostDevices, deviceinfo.SRIOVAliasPrefix)
 
 	sriovHostDevicesToAttach := hostdevice.DifferenceHostDevicesByAlias(sriovDevices, currentAttachedSRIOVHostDevices)
 
