@@ -464,6 +464,42 @@ func DeleteAll(kv *v1.KubeVirt,
 		}
 	}
 
+	objects = stores.ValidatingAdmissionPolicyBindingCache.List()
+	for _, obj := range objects {
+		if validatingAdmissionPolicyBinding, ok := obj.(*admissionregistrationv1.ValidatingAdmissionPolicyBinding); ok && validatingAdmissionPolicyBinding.DeletionTimestamp == nil {
+			if key, err := controller.KeyFunc(validatingAdmissionPolicyBinding); err == nil {
+				expectations.ValidatingAdmissionPolicyBinding.AddExpectedDeletion(kvkey, key)
+				err := clientset.AdmissionregistrationV1().ValidatingAdmissionPolicyBindings().Delete(context.Background(), validatingAdmissionPolicyBinding.Name, deleteOptions)
+				if err != nil {
+					expectations.ValidatingAdmissionPolicyBinding.DeletionObserved(kvkey, key)
+					log.Log.Errorf("Failed to delete validatingAdmissionPolicyBinding %+v: %v", validatingAdmissionPolicyBinding, err)
+					return err
+				}
+			}
+		} else if !ok {
+			log.Log.Errorf(castFailedFmt, obj)
+			return nil
+		}
+	}
+
+	objects = stores.ValidatingAdmissionPolicyCache.List()
+	for _, obj := range objects {
+		if validatingAdmissionPolicy, ok := obj.(*admissionregistrationv1.ValidatingAdmissionPolicy); ok && validatingAdmissionPolicy.DeletionTimestamp == nil {
+			if key, err := controller.KeyFunc(validatingAdmissionPolicy); err == nil {
+				expectations.ValidatingAdmissionPolicy.AddExpectedDeletion(kvkey, key)
+				err := clientset.AdmissionregistrationV1().ValidatingAdmissionPolicies().Delete(context.Background(), validatingAdmissionPolicy.Name, deleteOptions)
+				if err != nil {
+					expectations.ValidatingAdmissionPolicy.DeletionObserved(kvkey, key)
+					log.Log.Errorf("Failed to delete validatingAdmissionPolicy %+v: %v", validatingAdmissionPolicy, err)
+					return err
+				}
+			}
+		} else if !ok {
+			log.Log.Errorf(castFailedFmt, obj)
+			return nil
+		}
+	}
+
 	err = deleteDummyWebhookValidators(kv, clientset, stores, expectations)
 	if err != nil {
 		return err
