@@ -39,12 +39,14 @@ import (
 	"k8s.io/utils/pointer"
 
 	virtv1 "kubevirt.io/api/core/v1"
-	exportv1 "kubevirt.io/api/export/v1alpha1"
+	exportv1alpha1 "kubevirt.io/api/export/v1alpha1"
+	exportv1beta1 "kubevirt.io/api/export/v1beta1"
 	instancetypev1alpha1 "kubevirt.io/api/instancetype/v1alpha1"
 	instancetypev1alpha2 "kubevirt.io/api/instancetype/v1alpha2"
 	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
 	poolv1 "kubevirt.io/api/pool/v1alpha1"
-	snapshotv1 "kubevirt.io/api/snapshot/v1alpha1"
+	snapshotv1alpha1 "kubevirt.io/api/snapshot/v1alpha1"
+	snapshotv1beta1 "kubevirt.io/api/snapshot/v1beta1"
 )
 
 const (
@@ -62,9 +64,9 @@ var (
 	VIRTUALMACHINEINSTANCEMIGRATION  = "virtualmachineinstancemigrations." + virtv1.VirtualMachineInstanceMigrationGroupVersionKind.Group
 	KUBEVIRT                         = "kubevirts." + virtv1.KubeVirtGroupVersionKind.Group
 	VIRTUALMACHINEPOOL               = "virtualmachinepools." + poolv1.SchemeGroupVersion.Group
-	VIRTUALMACHINESNAPSHOT           = "virtualmachinesnapshots." + snapshotv1.SchemeGroupVersion.Group
-	VIRTUALMACHINESNAPSHOTCONTENT    = "virtualmachinesnapshotcontents." + snapshotv1.SchemeGroupVersion.Group
-	VIRTUALMACHINEEXPORT             = "virtualmachineexports." + exportv1.SchemeGroupVersion.Group
+	VIRTUALMACHINESNAPSHOT           = "virtualmachinesnapshots." + snapshotv1beta1.SchemeGroupVersion.Group
+	VIRTUALMACHINESNAPSHOTCONTENT    = "virtualmachinesnapshotcontents." + snapshotv1beta1.SchemeGroupVersion.Group
+	VIRTUALMACHINEEXPORT             = "virtualmachineexports." + exportv1beta1.SchemeGroupVersion.Group
 	MIGRATIONPOLICY                  = "migrationpolicies." + migrationsv1.MigrationPolicyKind.Group
 	VIRTUALMACHINECLONE              = "virtualmachineclones." + clonev1alpha1.VirtualMachineCloneKind.Group
 	PreserveUnknownFieldsFalse       = false
@@ -450,15 +452,23 @@ func NewVirtualMachineSnapshotCrd() (*extv1.CustomResourceDefinition, error) {
 
 	crd.ObjectMeta.Name = VIRTUALMACHINESNAPSHOT
 	crd.Spec = extv1.CustomResourceDefinitionSpec{
-		Group: snapshotv1.SchemeGroupVersion.Group,
+		Group: snapshotv1beta1.SchemeGroupVersion.Group,
 		Versions: []extv1.CustomResourceDefinitionVersion{
 			{
-				Name:    snapshotv1.SchemeGroupVersion.Version,
+				Name:    snapshotv1alpha1.SchemeGroupVersion.Version,
+				Served:  true,
+				Storage: false,
+			},
+			{
+				Name:    snapshotv1beta1.SchemeGroupVersion.Version,
 				Served:  true,
 				Storage: true,
 			},
 		},
 		Scope: "Namespaced",
+		Conversion: &extv1.CustomResourceConversion{
+			Strategy: extv1.NoneConverter,
+		},
 		Names: extv1.CustomResourceDefinitionNames{
 			Plural:     "virtualmachinesnapshots",
 			Singular:   "virtualmachinesnapshot",
@@ -492,15 +502,23 @@ func NewVirtualMachineSnapshotContentCrd() (*extv1.CustomResourceDefinition, err
 
 	crd.ObjectMeta.Name = VIRTUALMACHINESNAPSHOTCONTENT
 	crd.Spec = extv1.CustomResourceDefinitionSpec{
-		Group: snapshotv1.SchemeGroupVersion.Group,
+		Group: snapshotv1beta1.SchemeGroupVersion.Group,
 		Versions: []extv1.CustomResourceDefinitionVersion{
 			{
-				Name:    snapshotv1.SchemeGroupVersion.Version,
+				Name:    snapshotv1alpha1.SchemeGroupVersion.Version,
+				Served:  true,
+				Storage: false,
+			},
+			{
+				Name:    snapshotv1beta1.SchemeGroupVersion.Version,
 				Served:  true,
 				Storage: true,
 			},
 		},
 		Scope: "Namespaced",
+		Conversion: &extv1.CustomResourceConversion{
+			Strategy: extv1.NoneConverter,
+		},
 		Names: extv1.CustomResourceDefinitionNames{
 			Plural:     "virtualmachinesnapshotcontents",
 			Singular:   "virtualmachinesnapshotcontent",
@@ -529,17 +547,25 @@ func NewVirtualMachineSnapshotContentCrd() (*extv1.CustomResourceDefinition, err
 func NewVirtualMachineRestoreCrd() (*extv1.CustomResourceDefinition, error) {
 	crd := newBlankCrd()
 
-	crd.ObjectMeta.Name = "virtualmachinerestores." + snapshotv1.SchemeGroupVersion.Group
+	crd.ObjectMeta.Name = "virtualmachinerestores." + snapshotv1beta1.SchemeGroupVersion.Group
 	crd.Spec = extv1.CustomResourceDefinitionSpec{
-		Group: snapshotv1.SchemeGroupVersion.Group,
+		Group: snapshotv1beta1.SchemeGroupVersion.Group,
 		Versions: []extv1.CustomResourceDefinitionVersion{
 			{
-				Name:    snapshotv1.SchemeGroupVersion.Version,
+				Name:    snapshotv1alpha1.SchemeGroupVersion.Version,
+				Served:  true,
+				Storage: false,
+			},
+			{
+				Name:    snapshotv1beta1.SchemeGroupVersion.Version,
 				Served:  true,
 				Storage: true,
 			},
 		},
 		Scope: "Namespaced",
+		Conversion: &extv1.CustomResourceConversion{
+			Strategy: extv1.NoneConverter,
+		},
 		Names: extv1.CustomResourceDefinitionNames{
 			Plural:     "virtualmachinerestores",
 			Singular:   "virtualmachinerestore",
@@ -570,17 +596,25 @@ func NewVirtualMachineRestoreCrd() (*extv1.CustomResourceDefinition, error) {
 func NewVirtualMachineExportCrd() (*extv1.CustomResourceDefinition, error) {
 	crd := newBlankCrd()
 
-	crd.ObjectMeta.Name = "virtualmachineexports." + exportv1.SchemeGroupVersion.Group
+	crd.ObjectMeta.Name = "virtualmachineexports." + exportv1beta1.SchemeGroupVersion.Group
 	crd.Spec = extv1.CustomResourceDefinitionSpec{
-		Group: exportv1.SchemeGroupVersion.Group,
+		Group: exportv1beta1.SchemeGroupVersion.Group,
 		Versions: []extv1.CustomResourceDefinitionVersion{
 			{
-				Name:    exportv1.SchemeGroupVersion.Version,
+				Name:    exportv1alpha1.SchemeGroupVersion.Version,
+				Served:  true,
+				Storage: false,
+			},
+			{
+				Name:    exportv1beta1.SchemeGroupVersion.Version,
 				Served:  true,
 				Storage: true,
 			},
 		},
 		Scope: "Namespaced",
+		Conversion: &extv1.CustomResourceConversion{
+			Strategy: extv1.NoneConverter,
+		},
 		Names: extv1.CustomResourceDefinitionNames{
 			Plural:     "virtualmachineexports",
 			Singular:   "virtualmachineexport",
