@@ -64,6 +64,7 @@ const (
 
 	cloudInitDisk = "cloudinitdisk"
 	blank         = "blank"
+	gcs           = "gcs"
 	http          = "http"
 	imageIO       = "imageio"
 	pvc           = "pvc"
@@ -168,6 +169,14 @@ type dataVolumeSourceBlank struct {
 	Name string             `param:"name"`
 }
 
+type dataVolumeSourceGcs struct {
+	SecretRef string             `param:"secretref"`
+	URL       string             `param:"url"`
+	Size      *resource.Quantity `param:"size"`
+	Type      string             `param:"type"`
+	Name      string             `param:"name"`
+}
+
 type dataVolumeSourceHttp struct {
 	CertConfigMap      string             `param:"certconfigmap"`
 	ExtraHeaders       []string           `param:"extraheaders"`
@@ -235,10 +244,11 @@ type dataVolumeSourceSnapshot struct {
 	Type   string             `param:"type"`
 }
 
-type volumeImportFn func(string, *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error)
+type volumeImportFn func(string) (*cdiv1.DataVolumeSource, error)
 
 var volumeImportOptions = map[string]volumeImportFn{
 	blank:    withVolumeSourceBlank,
+	gcs:      withVolumeSourceGcs,
 	http:     withVolumeSourceHttp,
 	imageIO:  withVolumeSourceImageIO,
 	pvc:      withVolumeSourcePVC,
@@ -295,8 +305,9 @@ func NewCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
 	cmd.Flags().StringArrayVar(&c.pvcVolumes, PvcVolumeFlag, c.pvcVolumes, fmt.Sprintf("Specify a PVCs to be used by the VM. Can be provided multiple times.\nSupported parameters: %s", params.Supported(pvcVolume{})))
 	cmd.Flags().StringArrayVar(&c.blankVolumes, BlankVolumeFlag, c.blankVolumes, fmt.Sprintf("Specify a blank volume to be used by the VM. Can be provided multiple times.\nSupported parameters: %s", params.Supported(blankVolume{})))
 	cmd.Flags().StringArrayVar(&c.volumeImport, VolumeImportFlag, c.volumeImport, fmt.Sprintf(
-		"Specify the source for DataVolume. Can be provided multiple times.\nSupported parameters:\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s",
+		"Specify the source for DataVolume. Can be provided multiple times.\nSupported parameters:\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s\n  type %s - %s",
 		blank, params.Supported(dataVolumeSourceBlank{}),
+		gcs, params.Supported(dataVolumeSourceGcs{}),
 		http, params.Supported(dataVolumeSourceHttp{}),
 		imageIO, params.Supported(dataVolumeSourceImageIO{}),
 		pvc, params.Supported(dataVolumeSourcePVC{}),
@@ -1024,7 +1035,7 @@ func withImportedVolume(c *createVM, vm *v1.VirtualMachine) error {
 			return params.FlagErr(VolumeImportFlag, fmt.Sprintf("unknown source type used - %s", volumeSourceType))
 		}
 
-		source, err := sourceFn(volume, vm)
+		source, err := sourceFn(volume)
 		if err != nil {
 			return err
 		}
@@ -1048,7 +1059,7 @@ func withImportedVolume(c *createVM, vm *v1.VirtualMachine) error {
 	return nil
 }
 
-func withVolumeSourceBlank(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error) {
+func withVolumeSourceBlank(paramStr string) (*cdiv1.DataVolumeSource, error) {
 	sourceStruct := dataVolumeSourceBlank{}
 	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
 		return nil, err
@@ -1061,7 +1072,27 @@ func withVolumeSourceBlank(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataV
 	return &source, nil
 }
 
-func withVolumeSourceHttp(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error) {
+func withVolumeSourceGcs(paramStr string) (*cdiv1.DataVolumeSource, error) {
+	sourceStruct := dataVolumeSourceGcs{}
+	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
+		return nil, err
+	}
+
+	if sourceStruct.URL == "" {
+		return nil, params.FlagErr(VolumeImportFlag, "URL is required with GCS volume source")
+	}
+
+	source := cdiv1.DataVolumeSource{
+		GCS: &cdiv1.DataVolumeSourceGCS{
+			URL:       sourceStruct.URL,
+			SecretRef: sourceStruct.SecretRef,
+		},
+	}
+
+	return &source, nil
+}
+
+func withVolumeSourceHttp(paramStr string) (*cdiv1.DataVolumeSource, error) {
 	sourceStruct := dataVolumeSourceHttp{}
 	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
 		return nil, err
@@ -1084,7 +1115,7 @@ func withVolumeSourceHttp(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVo
 	return &source, nil
 }
 
-func withVolumeSourceImageIO(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error) {
+func withVolumeSourceImageIO(paramStr string) (*cdiv1.DataVolumeSource, error) {
 	sourceStruct := dataVolumeSourceImageIO{}
 	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
 		return nil, err
@@ -1106,7 +1137,7 @@ func withVolumeSourceImageIO(paramStr string, vm *v1.VirtualMachine) (*cdiv1.Dat
 	return &source, nil
 }
 
-func withVolumeSourcePVC(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error) {
+func withVolumeSourcePVC(paramStr string) (*cdiv1.DataVolumeSource, error) {
 	sourceStruct := dataVolumeSourcePVC{}
 	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
 		return nil, err
@@ -1135,7 +1166,7 @@ func withVolumeSourcePVC(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVol
 	return &source, nil
 }
 
-func withVolumeSourceRegistry(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error) {
+func withVolumeSourceRegistry(paramStr string) (*cdiv1.DataVolumeSource, error) {
 	sourceStruct := dataVolumeSourceRegistry{}
 	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
 		return nil, err
@@ -1176,7 +1207,7 @@ func withVolumeSourceRegistry(paramStr string, vm *v1.VirtualMachine) (*cdiv1.Da
 	return &source, nil
 }
 
-func withVolumeSourceS3(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error) {
+func withVolumeSourceS3(paramStr string) (*cdiv1.DataVolumeSource, error) {
 	sourceStruct := dataVolumeSourceS3{}
 	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
 		return nil, err
@@ -1197,12 +1228,32 @@ func withVolumeSourceS3(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolu
 	return &source, nil
 }
 
-func withVolumeSourceVDDK(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error) {
+func withVolumeSourceVDDK(paramStr string) (*cdiv1.DataVolumeSource, error) {
 	sourceStruct := dataVolumeSourceVDDK{}
 	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
 		return nil, err
 	}
 
+	if sourceStruct.URL == "" {
+		return nil, params.FlagErr(VolumeImportFlag, "URL is required with VDDK volume source")
+	}
+
+	if sourceStruct.UUID == "" {
+		return nil, params.FlagErr(VolumeImportFlag, "UUID is required with VDDK volume source")
+	}
+
+	if sourceStruct.ThumbPrint == "" {
+		return nil, params.FlagErr(VolumeImportFlag, "ThumbPrint is required with VDDK volume source")
+	}
+
+	if sourceStruct.SecretRef == "" {
+		return nil, params.FlagErr(VolumeImportFlag, "SecretRef is required with VDDK volume source")
+	}
+
+	if sourceStruct.BackingFile == "" {
+		return nil, params.FlagErr(VolumeImportFlag, "BackingFile is required with VDDK volume source")
+	}
+
 	source := cdiv1.DataVolumeSource{
 		VDDK: &cdiv1.DataVolumeSourceVDDK{
 			URL:          sourceStruct.URL,
@@ -1217,7 +1268,7 @@ func withVolumeSourceVDDK(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVo
 	return &source, nil
 }
 
-func withVolumeSourceSnapshot(paramStr string, vm *v1.VirtualMachine) (*cdiv1.DataVolumeSource, error) {
+func withVolumeSourceSnapshot(paramStr string) (*cdiv1.DataVolumeSource, error) {
 	sourceStruct := dataVolumeSourceSnapshot{}
 	if err := params.Map(VolumeImportFlag, paramStr, &sourceStruct); err != nil {
 		return nil, err
