@@ -4,9 +4,9 @@ import (
 	"github.com/spf13/cobra"
 	"k8s.io/client-go/tools/clientcmd"
 
-	add_key "kubevirt.io/kubevirt/pkg/virtctl/credentials/add-key"
-	remove_key "kubevirt.io/kubevirt/pkg/virtctl/credentials/remove-key"
-	set_password "kubevirt.io/kubevirt/pkg/virtctl/credentials/set-password"
+	"kubevirt.io/kubevirt/pkg/virtctl/credentials/addkey"
+	"kubevirt.io/kubevirt/pkg/virtctl/credentials/password"
+	"kubevirt.io/kubevirt/pkg/virtctl/credentials/removekey"
 	"kubevirt.io/kubevirt/pkg/virtctl/templates"
 )
 
@@ -20,9 +20,9 @@ func NewCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
 	}
 
 	cmd.AddCommand(
-		add_key.NewCommand(clientConfig),
-		remove_key.NewCommand(clientConfig),
-		set_password.SetPasswordCommand(clientConfig),
+		addkey.NewCommand(clientConfig),
+		removekey.NewCommand(clientConfig),
+		password.SetPasswordCommand(clientConfig),
 	)
 
 	cmd.SetUsageTemplate(templates.UsageTemplate())
