@@ -8,7 +8,6 @@ import (
 	"net"
 	"os"
 
-	"github.com/golang/glog"
 	"github.com/spf13/pflag"
 	"golang.org/x/crypto/ssh"
 	"golang.org/x/crypto/ssh/agent"
@@ -18,6 +17,7 @@ import (
 	kvcorev1 "kubevirt.io/client-go/generated/kubevirt/clientset/versioned/typed/core/v1"
 
 	"kubevirt.io/client-go/kubecli"
+	"kubevirt.io/client-go/log"
 )
 
 const (
@@ -113,7 +113,7 @@ func (o *NativeSSHConnection) trySSHAgent(methods []ssh.AuthMethod) []ssh.AuthMe
 	}
 	conn, err := net.Dial("unix", socket)
 	if err != nil {
-		glog.Error("no connection to ssh agent, skipping agent authentication:", err)
+		log.Log.Errorf("no connection to ssh agent, skipping agent authentication: %v", err)
 		return methods
 	}
 	agentClient := agent.NewClient(conn)
@@ -126,7 +126,7 @@ func (o *NativeSSHConnection) tryPrivateKey(methods []ssh.AuthMethod) []ssh.Auth
 	// not explicitly provided, don't add the authentication mechanism.
 	if !o.Options.IdentityFilePathProvided {
 		if _, err := os.Stat(o.Options.IdentityFilePath); errors.Is(err, os.ErrNotExist) {
-			glog.V(3).Infof("No ssh key at the default location %q found, skipping RSA authentication.", o.Options.IdentityFilePath)
+			log.Log.V(3).Infof("No ssh key at the default location %q found, skipping RSA authentication.", o.Options.IdentityFilePath)
 			return methods
 		}
 	}
