@@ -49,10 +49,10 @@ import (
 	kubectlutil "k8s.io/kubectl/pkg/util"
 
 	virtv1 "kubevirt.io/api/core/v1"
-	exportv1 "kubevirt.io/api/export/v1alpha1"
+	exportv1 "kubevirt.io/api/export/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 
-	snapshotv1 "kubevirt.io/api/snapshot/v1alpha1"
+	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
 
 	"kubevirt.io/kubevirt/pkg/util"
 	"kubevirt.io/kubevirt/pkg/virtctl/templates"
@@ -71,6 +71,7 @@ const (
 	SNAPSHOT_FLAG       = "--snapshot"
 	INSECURE_FLAG       = "--insecure"
 	KEEP_FLAG           = "--keep-vme"
+	DELETE_FLAG         = "--delete-vme"
 	FORMAT_FLAG         = "--format"
 	PVC_FLAG            = "--pvc"
 	TTL_FLAG            = "--ttl"
@@ -80,6 +81,7 @@ const (
 	INCLUDE_SECRET_FLAG = "--include-secret"
 	PORT_FORWARD_FLAG   = "--port-forward"
 	LOCAL_PORT_FLAG     = "--local-port"
+	RETRY_FLAG          = "--retry"
 
 	// Possible output format for manifests
 	OUTPUT_FORMAT_JSON = "json"
@@ -130,6 +132,7 @@ var (
 	outputFile           string
 	insecure             bool
 	keepVme              bool
+	deleteVme            bool
 	shouldCreate         bool
 	includeSecret        bool
 	exportManifest       bool
@@ -140,26 +143,29 @@ var (
 	volumeName           string
 	ttl                  string
 	manifestOutputFormat string
+	downloadRetries      int
 )
 
 type VMExportInfo struct {
-	ShouldCreate   bool
-	Insecure       bool
-	KeepVme        bool
-	IncludeSecret  bool
-	ExportManifest bool
-	Decompress     bool
-	PortForward    bool
-	LocalPort      string
-	OutputFile     string
-	OutputWriter   io.Writer
-	VolumeName     string
-	Namespace      string
-	Name           string
-	OutputFormat   string
-	ServiceURL     string
-	ExportSource   k8sv1.TypedLocalObjectReference
-	TTL            metav1.Duration
+	ShouldCreate    bool
+	Insecure        bool
+	KeepVme         bool
+	DeleteVme       bool
+	IncludeSecret   bool
+	ExportManifest  bool
+	Decompress      bool
+	PortForward     bool
+	LocalPort       string
+	OutputFile      string
+	OutputWriter    io.Writer
+	VolumeName      string
+	Namespace       string
+	Name            string
+	OutputFormat    string
+	ServiceURL      string
+	ExportSource    k8sv1.TypedLocalObjectReference
+	TTL             metav1.Duration
+	DownloadRetries int
 }
 
 type command struct {
@@ -229,22 +235,22 @@ func init() {
 func usage() string {
 	usage := `# Create a VirtualMachineExport to export a volume from a virtual machine:
 	{{ProgramName}} vmexport create vm1-export --vm=vm1
-  
+
 	# Create a VirtualMachineExport to export a volume from a virtual machine snapshot
 	{{ProgramName}} vmexport create snap1-export --snapshot=snap1
-  
+
 	# Create a VirtualMachineExport to export a volume from a PVC
 	{{ProgramName}} vmexport create pvc1-export --pvc=pvc1
-  
+
 	# Delete a VirtualMachineExport resource
 	{{ProgramName}} vmexport delete snap1-export
-  
+
 	# Download a volume from an already existing VirtualMachineExport (--volume is optional when only one volume is available)
 	{{ProgramName}} vmexport download vm1-export --volume=volume1 --output=disk.img.gz
 
 	# Download a volume as before but through local port 5410
 	{{ProgramName}} vmexport download vm1-export --volume=volume1 --output=disk.img.gz --port-forward --local-port=5410
-  
+
 	# Create a VirtualMachineExport and download the requested volume from it
 	{{ProgramName}} vmexport download vm1-export --vm=vm1 --volume=volume1 --output=disk.img.gz
 
@@ -269,6 +275,8 @@ func NewVirtualMachineExportCommand(clientConfig clientcmd.ClientConfig) *cobra.
 		},
 	}
 
+	shouldCreate = false
+
 	cmd.Flags().StringVar(&vm, "vm", "", "Sets VirtualMachine as vmexport kind and specifies the vm name.")
 	cmd.Flags().StringVar(&snapshot, "snapshot", "", "Sets VirtualMachineSnapshot as vmexport kind and specifies the snapshot name.")
 	cmd.Flags().StringVar(&pvc, "pvc", "", "Sets PersistentVolumeClaim as vmexport kind and specifies the PVC name.")
@@ -277,12 +285,15 @@ func NewVirtualMachineExportCommand(clientConfig clientcmd.ClientConfig) *cobra.
 	cmd.Flags().StringVar(&volumeName, "volume", "", "Specifies the volume to be downloaded.")
 	cmd.Flags().StringVar(&format, "format", "", "Used to specify the format of the downloaded image. There's two options: gzip (default) and raw.")
 	cmd.Flags().BoolVar(&insecure, "insecure", false, "When used with the 'download' option, specifies that the http request should be insecure.")
-	cmd.Flags().BoolVar(&keepVme, "keep-vme", false, "When used with the 'download' option, specifies that the vmexport object should not be deleted after the download finishes.")
+	cmd.Flags().BoolVar(&keepVme, "keep-vme", false, "When used with the 'download' option, specifies that the vmexport object should always be retained after the download finishes.")
+	cmd.Flags().BoolVar(&deleteVme, "delete-vme", false, "When used with the 'download' option, specifies that the vmexport object should always be deleted after the download finishes.")
+	cmd.MarkFlagsMutuallyExclusive("keep-vme", "delete-vme")
 	cmd.Flags().StringVar(&ttl, "ttl", "", "The time after the export was created that it is eligible to be automatically deleted, defaults to 2 hours by the server side if not specified")
 	cmd.Flags().StringVar(&manifestOutputFormat, "manifest-output-format", "", "Manifest output format, defaults to Yaml. Valid options are yaml or json")
 	cmd.Flags().StringVar(&serviceUrl, "service-url", "", "Specify service url to use in the returned manifest, instead of the external URL in the Virtual Machine export status. This is useful for NodePorts or if you don't have an external URL configured")
 	cmd.Flags().BoolVar(&portForward, "port-forward", false, "Configures port-forwarding on a random port. Useful to download without proper ingress/route configuration")
 	cmd.Flags().StringVar(&localPort, "local-port", "0", "Defines the specific port to be used in port-forward.")
+	cmd.Flags().IntVar(&downloadRetries, "retry", 0, "When export server returns a transient error, we retry this number of times before giving up")
 	cmd.Flags().BoolVar(&includeSecret, "include-secret", false, "When used with manifest and set to true include a secret that contains proper headers for CDI to import using the manifest")
 	cmd.Flags().BoolVar(&exportManifest, "manifest", false, "Instead of downloading a volume, retrieve the VM manifest")
 	cmd.SetUsageTemplate(templates.UsageTemplate())
@@ -381,9 +392,11 @@ func (c *command) initVMExportInfo(vmeInfo *VMExportInfo) error {
 	if format == RAW_FORMAT {
 		vmeInfo.Decompress = true
 	}
+	vmeInfo.DownloadRetries = downloadRetries
 	vmeInfo.ShouldCreate = shouldCreate
 	vmeInfo.Insecure = insecure
 	vmeInfo.KeepVme = keepVme
+	vmeInfo.DeleteVme = deleteVme
 	vmeInfo.VolumeName = volumeName
 	vmeInfo.ServiceURL = serviceUrl
 	vmeInfo.OutputFormat = manifestOutputFormat
@@ -478,120 +491,142 @@ func DeleteVirtualMachineExport(client kubecli.KubevirtClient, vmeInfo *VMExport
 
 // DownloadVirtualMachineExport handles the process of downloading the requested volume from a VirtualMachineExport object
 func DownloadVirtualMachineExport(client kubecli.KubevirtClient, vmeInfo *VMExportInfo) error {
+	for attempt := 0; attempt <= vmeInfo.DownloadRetries; attempt++ {
+		succeeded, err := downloadVirtualMachineExport(client, vmeInfo)
+		if err != nil {
+			return err
+		}
+		if succeeded {
+			return nil
+		}
+		if attempt < vmeInfo.DownloadRetries {
+			printToOutput("Retrying...\n")
+			time.Sleep(2 * time.Second)
+		}
+	}
+	return fmt.Errorf("retry count reached, exiting unsuccesfully")
+}
+
+func downloadVirtualMachineExport(client kubecli.KubevirtClient, vmeInfo *VMExportInfo) (bool, error) {
 	if vmeInfo.ShouldCreate {
 		if err := CreateVirtualMachineExport(client, vmeInfo); err != nil {
-			if !errExportAlreadyExists(err) {
-				return err
+			if errExportAlreadyExists(err) {
+				// Don't delete VMExports that already exist unless specified explicitely
+				vmeInfo.KeepVme = true
+			} else {
+				return false, err
 			}
 		}
 	}
 
-	if !vmeInfo.KeepVme && !vmeInfo.ExportManifest {
+	if shouldDeleteVMExport(vmeInfo) {
 		defer DeleteVirtualMachineExport(client, vmeInfo)
 	}
 
 	if vmeInfo.PortForward {
 		stopChan, err := setupPortForward(client, vmeInfo)
 		if err != nil {
-			return err
+			return false, err
 		}
 		defer close(stopChan)
 	}
 
 	// Wait for the vmexport object to be ready
 	if err := ExportProcessingComplete(client, vmeInfo, processingWaitInterval, processingWaitTotal); err != nil {
-		return err
+		return false, err
 	}
 
 	vmexport, err := getVirtualMachineExport(client, vmeInfo)
 	if err != nil {
-		return err
+		return false, err
 	}
 	if vmexport == nil {
-		return fmt.Errorf("unable to get '%s/%s' VirtualMachineExport", vmeInfo.Namespace, vmeInfo.Name)
+		return false, fmt.Errorf("unable to get '%s/%s' VirtualMachineExport", vmeInfo.Namespace, vmeInfo.Name)
 	}
 
+	// Grab the VM Manifest and display it.
 	if vmeInfo.ExportManifest {
-		// Grab the VM Manifest and display it.
-		if err := getVirtualMachineManifest(client, vmexport, vmeInfo); err != nil {
-			return err
-		}
-	} else {
-		// Download the exported volume
-		if err := downloadVolume(client, vmexport, vmeInfo); err != nil {
-			return err
-		}
+		return getVirtualMachineManifest(client, vmexport, vmeInfo)
 	}
-	return nil
+
+	// Download the exported volume
+	return downloadVolume(client, vmexport, vmeInfo)
 }
 
-func printRequestBody(client kubecli.KubevirtClient, vmexport *exportv1.VirtualMachineExport, vmeInfo *VMExportInfo, manifestUrl string, headers map[string]string) error {
+func printRequestBody(client kubecli.KubevirtClient, vmexport *exportv1.VirtualMachineExport, vmeInfo *VMExportInfo, manifestUrl string, headers map[string]string) (bool, error) {
 	resp, err := HandleHTTPRequest(client, vmexport, manifestUrl, vmeInfo.Insecure, vmeInfo.ServiceURL, headers)
 	if err != nil {
-		return err
+		return false, err
 	}
 	defer resp.Body.Close()
 
 	// Check server response
 	if resp.StatusCode != http.StatusOK {
-		return fmt.Errorf("bad status: %s", resp.Status)
+		printToOutput("Bad status: %s\n", resp.Status)
+		return false, nil
 	}
 	bodyAll, err := io.ReadAll(resp.Body)
 	if err != nil {
-		return err
+		return false, err
 	}
 	fmt.Fprintf(vmeInfo.OutputWriter, "%s", bodyAll)
-	return nil
+	return true, nil
 }
 
-func getVirtualMachineManifest(client kubecli.KubevirtClient, vmexport *exportv1.VirtualMachineExport, vmeInfo *VMExportInfo) error {
+func getVirtualMachineManifest(client kubecli.KubevirtClient, vmexport *exportv1.VirtualMachineExport, vmeInfo *VMExportInfo) (bool, error) {
 	manifestMap, err := GetManifestUrlsFromVirtualMachineExport(vmexport, vmeInfo)
 	if err != nil {
-		return err
+		return false, err
 	}
 	headers := make(map[string]string)
 	headers[ACCEPT] = APPLICATION_YAML
 	if strings.ToLower(vmeInfo.OutputFormat) == OUTPUT_FORMAT_JSON {
 		headers[ACCEPT] = APPLICATION_JSON
 	}
-	if err := printRequestBody(client, vmexport, vmeInfo, manifestMap[exportv1.AllManifests], headers); err != nil {
-		return err
+	succeeded, err := printRequestBody(client, vmexport, vmeInfo, manifestMap[exportv1.AllManifests], headers)
+	if err != nil || !succeeded {
+		return false, err
 	}
 	if vmeInfo.IncludeSecret {
-		if err := printRequestBody(client, vmexport, vmeInfo, manifestMap[exportv1.AuthHeader], headers); err != nil {
-			return err
-		}
+		return printRequestBody(client, vmexport, vmeInfo, manifestMap[exportv1.AuthHeader], headers)
 	}
-	return nil
+	return true, nil
 }
 
 // downloadVolume handles the process of downloading the requested volume from a VirtualMachineExport
-func downloadVolume(client kubecli.KubevirtClient, vmexport *exportv1.VirtualMachineExport, vmeInfo *VMExportInfo) error {
+func downloadVolume(client kubecli.KubevirtClient, vmexport *exportv1.VirtualMachineExport, vmeInfo *VMExportInfo) (bool, error) {
 	// Extract the URL from the vmexport
 	downloadUrl, err := GetUrlFromVirtualMachineExport(vmexport, vmeInfo)
 	if err != nil {
-		return err
+		return false, err
 	}
 
 	resp, err := HandleHTTPRequest(client, vmexport, downloadUrl, vmeInfo.Insecure, vmeInfo.ServiceURL, nil)
 	if err != nil {
-		return err
+		return false, err
 	}
 	defer resp.Body.Close()
 
 	// Check server response
 	if resp.StatusCode != http.StatusOK {
-		return fmt.Errorf("bad status: %s", resp.Status)
+		printToOutput("Bad status: %s\n", resp.Status)
+		return false, nil
 	}
 
 	// Lastly, copy the file to the expected output
 	if err := copyFileWithProgressBar(vmeInfo.OutputWriter, resp, vmeInfo.Decompress); err != nil {
-		return err
+		return false, err
 	}
 
 	printToOutput("Download finished succesfully\n")
 
-	return nil
+	return true, nil
+}
+
+// shouldDeleteVMExport decides wether we should retain or delete a VMExport after a download. If delete/retain are not explicitly specified,
+// the vmexport will be deleted when is created in the same instance as the download, retained otherwise.
+func shouldDeleteVMExport(vmeInfo *VMExportInfo) bool {
+	return !vmeInfo.ExportManifest && (vmeInfo.DeleteVme || (vmeInfo.ShouldCreate && !vmeInfo.KeepVme))
 }
 
 func replaceUrlWithServiceUrl(manifestUrl string, vmeInfo *VMExportInfo) (string, error) {
@@ -900,6 +935,9 @@ func handleCreateFlags() error {
 	if keepVme {
 		return fmt.Errorf(ErrIncompatibleFlag, KEEP_FLAG, CREATE)
 	}
+	if deleteVme {
+		return fmt.Errorf(ErrIncompatibleFlag, DELETE_FLAG, CREATE)
+	}
 	if portForward {
 		return fmt.Errorf(ErrIncompatibleFlag, PORT_FORWARD_FLAG, CREATE)
 	}
@@ -912,6 +950,9 @@ func handleCreateFlags() error {
 	if serviceUrl != "" {
 		return fmt.Errorf(ErrIncompatibleFlag, SERVICE_URL_FLAG, CREATE)
 	}
+	if downloadRetries != 0 {
+		return fmt.Errorf(ErrIncompatibleFlag, RETRY_FLAG, CREATE)
+	}
 
 	return nil
 }
@@ -934,6 +975,9 @@ func handleDeleteFlags() error {
 	if keepVme {
 		return fmt.Errorf(ErrIncompatibleFlag, KEEP_FLAG, DELETE)
 	}
+	if deleteVme {
+		return fmt.Errorf(ErrIncompatibleFlag, DELETE_FLAG, DELETE)
+	}
 	if portForward {
 		return fmt.Errorf(ErrIncompatibleFlag, PORT_FORWARD_FLAG, DELETE)
 	}
@@ -946,6 +990,9 @@ func handleDeleteFlags() error {
 	if serviceUrl != "" {
 		return fmt.Errorf(ErrIncompatibleFlag, SERVICE_URL_FLAG, DELETE)
 	}
+	if downloadRetries != 0 {
+		return fmt.Errorf(ErrIncompatibleFlag, RETRY_FLAG, DELETE)
+	}
 
 	return nil
 }
@@ -968,6 +1015,10 @@ func handleDownloadFlags() error {
 		return fmt.Errorf(ErrInvalidValue, FORMAT_FLAG, "gzip/raw")
 	}
 
+	if downloadRetries < 0 {
+		return fmt.Errorf(ErrInvalidValue, RETRY_FLAG, "positive integers")
+	}
+
 	if exportManifest {
 		if volumeName != "" {
 			return fmt.Errorf(ErrIncompatibleFlag, VOLUME_FLAG, MANIFEST_FLAG)
