@@ -32,12 +32,12 @@ import (
 	"runtime"
 	"time"
 
-	"github.com/golang/glog"
 	"github.com/spf13/cobra"
 	"k8s.io/client-go/tools/clientcmd"
 
 	kvcorev1 "kubevirt.io/client-go/generated/kubevirt/clientset/versioned/typed/core/v1"
 	"kubevirt.io/client-go/kubecli"
+	"kubevirt.io/client-go/log"
 
 	"kubevirt.io/kubevirt/pkg/virtctl/templates"
 	"kubevirt.io/kubevirt/pkg/virtctl/vnc/screenshot"
@@ -69,6 +69,7 @@ var proxyOnly bool
 var customPort = 0
 
 func NewCommand(clientConfig clientcmd.ClientConfig) *cobra.Command {
+	log.InitializeLogging("vnc")
 	cmd := &cobra.Command{
 		Use:     "vnc (VMI)",
 		Short:   "Open a vnc connection to a virtual machine instance.",
@@ -114,7 +115,7 @@ func (o *VNC) Run(cmd *cobra.Command, args []string) error {
 	// Set listenAddress to localhost if proxy-only flag is not set
 	if !proxyOnly {
 		listenAddress = "127.0.0.1"
-		glog.V(2).Infof("--proxy-only is set to false, listening on %s\n", listenAddress)
+		log.Log.V(2).Infof("--proxy-only is set to false, listening on %s\n", listenAddress)
 	}
 	listenAddressFmt = listenAddress + ":%d"
 	lnAddr, err := net.ResolveTCPAddr("tcp", fmt.Sprintf(listenAddressFmt, customPort))
@@ -155,7 +156,7 @@ func (o *VNC) Run(cmd *cobra.Command, args []string) error {
 	// wait for vnc client to connect to our local proxy server
 	go func() {
 		start := time.Now()
-		glog.Infof("connection timeout: %v", LISTEN_TIMEOUT)
+		log.Log.Infof("connection timeout: %v", LISTEN_TIMEOUT)
 		// Don't set deadline if only proxy is running and VNC is to be connected manually
 		if !proxyOnly {
 			// exit early if spawning vnc client fails
@@ -163,12 +164,12 @@ func (o *VNC) Run(cmd *cobra.Command, args []string) error {
 		}
 		fd, err := ln.Accept()
 		if err != nil {
-			glog.V(2).Infof("Failed to accept unix sock connection. %s", err.Error())
+			log.Log.V(2).Infof("Failed to accept unix sock connection. %s", err.Error())
 			listenResChan <- err
 		}
 		defer fd.Close()
 
-		glog.V(2).Infof("VNC Client connected in %v", time.Now().Sub(start))
+		log.Log.V(2).Infof("VNC Client connected in %v", time.Now().Sub(start))
 		templates.PrintWarningForPausedVMI(virtCli, vmi, namespace)
 
 		// write to FD <- pipeOutReader
@@ -281,19 +282,17 @@ func checkAndRunVNCViewer(doneChan chan struct{}, viewResChan chan error, port i
 	}
 
 	if vncBin == "" {
-		glog.Errorf("No supported VNC app found in %s", osType)
+		log.Log.Errorf("No supported VNC app found in %s", osType)
 		err = fmt.Errorf("No supported VNC app found in %s", osType)
 	} else {
-		if glog.V(4) {
-			glog.Infof("Executing commandline: '%s %v'", vncBin, args)
-		}
+		log.Log.V(4).Infof("Executing commandline: '%s %v'", vncBin, args)
 		// #nosec No risk for attacket injection. vncBin and args include predefined strings
 		cmnd := exec.Command(vncBin, args...)
 		output, err := cmnd.CombinedOutput()
 		if err != nil {
-			glog.Errorf("%s execution failed: %v, output: %v", vncBin, err, string(output))
+			log.Log.Errorf("%s execution failed: %v, output: %v", vncBin, err, string(output))
 		} else {
-			glog.V(2).Infof("%v output: %v", vncBin, string(output))
+			log.Log.V(2).Infof("%v output: %v", vncBin, string(output))
 		}
 	}
 	viewResChan <- err
@@ -301,7 +300,7 @@ func checkAndRunVNCViewer(doneChan chan struct{}, viewResChan chan error, port i
 
 func tigerVncArgs(port int) (args []string) {
 	args = append(args, fmt.Sprintf(listenAddressFmt, port))
-	if glog.V(4) {
+	if log.Log.Verbosity(4) {
 		args = append(args, "Log=*:stderr:100")
 	}
 	return
@@ -317,7 +316,7 @@ func realVncArgs(port int) (args []string) {
 	args = append(args, "-WarnUnencrypted=0")
 	args = append(args, "-Shared=0")
 	args = append(args, "-ShareFiles=0")
-	if glog.V(4) {
+	if log.Log.Verbosity(4) {
 		args = append(args, "-log=*:stderr:100")
 	}
 	return
@@ -325,7 +324,7 @@ func realVncArgs(port int) (args []string) {
 
 func remoteViewerArgs(port int) (args []string) {
 	args = append(args, fmt.Sprintf("vnc://127.0.0.1:%d", port))
-	if glog.V(4) {
+	if log.Log.Verbosity(4) {
 		args = append(args, "--debug")
 	}
 	return
