@@ -191,16 +191,6 @@ func DefaultBridgeNetworkInterface() *Interface {
 	return iface
 }
 
-func DefaultSlirpNetworkInterface() *Interface {
-	iface := &Interface{
-		Name: "default",
-		InterfaceBindingMethod: InterfaceBindingMethod{
-			Slirp: &InterfaceSlirp{},
-		},
-	}
-	return iface
-}
-
 func DefaultMasqueradeNetworkInterface() *Interface {
 	iface := &Interface{
 		Name: "default",
@@ -211,16 +201,6 @@ func DefaultMasqueradeNetworkInterface() *Interface {
 	return iface
 }
 
-func DefaultMacvtapNetworkInterface(ifaceName string) *Interface {
-	iface := &Interface{
-		Name: ifaceName,
-		InterfaceBindingMethod: InterfaceBindingMethod{
-			Macvtap: &InterfaceMacvtap{},
-		},
-	}
-	return iface
-}
-
 func DefaultPodNetwork() *Network {
 	defaultNet := &Network{
 		Name: "default",
