@@ -22,7 +22,6 @@ package kubecli
 import (
 	"context"
 
-	autov1 "k8s.io/api/autoscaling/v1"
 	k8smetav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/types"
 	"k8s.io/client-go/rest"
@@ -47,31 +46,6 @@ type rc struct {
 	resource   string
 }
 
-func (v *rc) GetScale(ctx context.Context, replicaSetName string, options k8smetav1.GetOptions) (result *autov1.Scale, err error) {
-	result = &autov1.Scale{}
-	err = v.restClient.Get().
-		Namespace(v.namespace).
-		Resource(v.resource).
-		Name(replicaSetName).
-		SubResource("scale").
-		Do(ctx).
-		Into(result)
-	return
-}
-
-func (v *rc) UpdateScale(ctx context.Context, replicaSetName string, scale *autov1.Scale) (result *autov1.Scale, err error) {
-	result = &autov1.Scale{}
-	err = v.restClient.Put().
-		Namespace(v.namespace).
-		Resource(v.resource).
-		Name(replicaSetName).
-		SubResource("scale").
-		Body(scale).
-		Do(ctx).
-		Into(result)
-	return
-}
-
 func (v *rc) Get(ctx context.Context, name string, options k8smetav1.GetOptions) (replicaset *v1.VirtualMachineInstanceReplicaSet, err error) {
 	replicaset, err = v.VirtualMachineInstanceReplicaSetInterface.Get(ctx, name, options)
 	replicaset.SetGroupVersionKind(v1.VirtualMachineInstanceReplicaSetGroupVersionKind)
@@ -106,10 +80,6 @@ func (v *rc) Patch(ctx context.Context, name string, pt types.PatchType, data []
 	return v.VirtualMachineInstanceReplicaSetInterface.Patch(ctx, name, pt, data, opts, subresources...)
 }
 
-func (v *rc) PatchStatus(ctx context.Context, name string, pt types.PatchType, data []byte, opts k8smetav1.PatchOptions) (result *v1.VirtualMachineInstanceReplicaSet, err error) {
-	return v.Patch(ctx, name, pt, data, opts, "status")
-}
-
 func (v *rc) UpdateStatus(ctx context.Context, replicaset *v1.VirtualMachineInstanceReplicaSet, opts k8smetav1.UpdateOptions) (result *v1.VirtualMachineInstanceReplicaSet, err error) {
 	result, err = v.VirtualMachineInstanceReplicaSetInterface.UpdateStatus(ctx, replicaset, opts)
 	result.SetGroupVersionKind(v1.VirtualMachineInstanceReplicaSetGroupVersionKind)
