@@ -8,13 +8,15 @@ import (
 
 	"k8s.io/apimachinery/pkg/api/errors"
 
+	"kubevirt.io/kubevirt/pkg/libvmi"
+
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/testsuite"
 
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 
 	virtsnapshot "kubevirt.io/api/snapshot"
-	"kubevirt.io/api/snapshot/v1alpha1"
+	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
@@ -36,15 +38,13 @@ import (
 	. "kubevirt.io/kubevirt/tests/framework/matcher"
 	"kubevirt.io/kubevirt/tests/libinstancetype"
 	"kubevirt.io/kubevirt/tests/libstorage"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 )
 
 const (
 	vmAPIGroup = "kubevirt.io"
 )
 
-type loginFunction func(*virtv1.VirtualMachineInstance) error
-
 var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 	var err error
 	var virtClient kubecli.KubevirtClient
@@ -58,7 +58,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 	})
 
 	createVM := func(options ...libvmi.Option) (vm *virtv1.VirtualMachine) {
-		vmi := libvmi.NewCirros(options...)
+		vmi := libvmifact.NewCirros(options...)
 		vmi.Namespace = testsuite.GetTestNamespace(nil)
 		vm = libvmi.NewVirtualMachine(vmi)
 		vm.Annotations = vmi.Annotations
@@ -73,15 +73,15 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 		return
 	}
 
-	createSnapshot := func(vm *virtv1.VirtualMachine) *v1alpha1.VirtualMachineSnapshot {
+	createSnapshot := func(vm *virtv1.VirtualMachine) *snapshotv1.VirtualMachineSnapshot {
 		var err error
 
-		snapshot := &v1alpha1.VirtualMachineSnapshot{
+		snapshot := &snapshotv1.VirtualMachineSnapshot{
 			ObjectMeta: v1.ObjectMeta{
 				Name:      "snapshot-" + vm.Name,
 				Namespace: vm.Namespace,
 			},
-			Spec: v1alpha1.VirtualMachineSnapshotSpec{
+			Spec: snapshotv1.VirtualMachineSnapshotSpec{
 				Source: k8sv1.TypedLocalObjectReference{
 					APIGroup: pointer.String(vmAPIGroup),
 					Kind:     "VirtualMachine",
@@ -96,7 +96,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 		return snapshot
 	}
 
-	waitSnapshotReady := func(snapshot *v1alpha1.VirtualMachineSnapshot) *v1alpha1.VirtualMachineSnapshot {
+	waitSnapshotReady := func(snapshot *snapshotv1.VirtualMachineSnapshot) *snapshotv1.VirtualMachineSnapshot {
 		var err error
 
 		EventuallyWithOffset(1, func() bool {
@@ -108,7 +108,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 		return snapshot
 	}
 
-	waitSnapshotContentsExist := func(snapshot *v1alpha1.VirtualMachineSnapshot) *v1alpha1.VirtualMachineSnapshot {
+	waitSnapshotContentsExist := func(snapshot *snapshotv1.VirtualMachineSnapshot) *snapshotv1.VirtualMachineSnapshot {
 		var contentsName string
 		EventuallyWithOffset(1, func() error {
 			snapshot, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Get(context.Background(), snapshot.Name, v1.GetOptions{})
@@ -152,7 +152,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 		return vmClone
 	}
 
-	generateCloneFromSnapshot := func(snapshot *v1alpha1.VirtualMachineSnapshot, targetVMName string) *clonev1alpha1.VirtualMachineClone {
+	generateCloneFromSnapshot := func(snapshot *snapshotv1.VirtualMachineSnapshot, targetVMName string) *clonev1alpha1.VirtualMachineClone {
 		vmClone := kubecli.NewMinimalCloneWithNS("testclone", snapshot.Namespace)
 
 		cloneSourceRef := &k8sv1.TypedLocalObjectReference{
@@ -187,7 +187,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 		}, 3*time.Minute, 3*time.Second).Should(Equal(clonev1alpha1.Succeeded), "clone should finish successfully")
 	}
 
-	expectVMRunnable := func(vm *virtv1.VirtualMachine, login loginFunction) *virtv1.VirtualMachine {
+	expectVMRunnable := func(vm *virtv1.VirtualMachine, login console.LoginToFunction) *virtv1.VirtualMachine {
 		By(fmt.Sprintf("Starting VM %s", vm.Name))
 		vm = StartVirtualMachine(vm)
 		targetVMI, err := virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, v1.GetOptions{})
@@ -672,6 +672,7 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 							snapshotStorageClass,
 							k8sv1.ReadWriteOnce,
 						)
+						sourceVM.Spec.Running = nil
 
 						sourceVM.Spec.Template.Spec.Domain.Resources = virtv1.ResourceRequirements{}
 						sourceVM.Spec.Instancetype = &virtv1.InstancetypeMatcher{
@@ -682,24 +683,19 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 							Name: preference.Name,
 							Kind: "VirtualMachinePreference",
 						}
+					})
 
+					DescribeTable("should create new ControllerRevisions for cloned VM", Label("instancetype", "clone"), func(runStrategy virtv1.VirtualMachineRunStrategy) {
+						sourceVM.Spec.RunStrategy = &runStrategy
 						sourceVM, err = virtClient.VirtualMachine(sourceVM.Namespace).Create(context.Background(), sourceVM, v1.CreateOptions{})
 						Expect(err).ToNot(HaveOccurred())
 
 						for _, dvt := range sourceVM.Spec.DataVolumeTemplates {
 							libstorage.EventuallyDVWith(sourceVM.Namespace, dvt.Name, 180, HaveSucceeded())
 						}
-					})
-
-					DescribeTable("should create new ControllerRevisions for cloned VM", Label("instancetype", "clone"), func(toRunSourceVM bool) {
 						By("Waiting until the source VM has instancetype and preference RevisionNames")
 						libinstancetype.WaitForVMInstanceTypeRevisionNames(sourceVM.Name, virtClient)
 
-						if toRunSourceVM {
-							By("Starting the VM and expecting it to run")
-							sourceVM = StartVMAndExpectRunning(virtClient, sourceVM)
-						}
-
 						vmClone = generateCloneFromVM()
 						createCloneAndWaitForFinish(vmClone)
 
@@ -719,8 +715,8 @@ var _ = Describe("[Serial]VirtualMachineClone Tests", Serial, func() {
 						Expect(libinstancetype.EnsureControllerRevisionObjectsEqual(sourceVM.Spec.Instancetype.RevisionName, targetVM.Spec.Instancetype.RevisionName, virtClient)).To(BeTrue(), "source and target instance type controller revisions are expected to be equal")
 						Expect(libinstancetype.EnsureControllerRevisionObjectsEqual(sourceVM.Spec.Preference.RevisionName, targetVM.Spec.Preference.RevisionName, virtClient)).To(BeTrue(), "source and target preference controller revisions are expected to be equal")
 					},
-						Entry("with a running VM", true),
-						Entry("with a stopped VM", false),
+						Entry("with a running VM", virtv1.RunStrategyAlways),
+						Entry("with a stopped VM", virtv1.RunStrategyHalted),
 					)
 				})
 
