@@ -27,7 +27,7 @@ import (
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/libmigration"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
@@ -43,10 +43,12 @@ import (
 	"k8s.io/client-go/util/retry"
 
 	v1 "kubevirt.io/api/core/v1"
-	"kubevirt.io/api/snapshot/v1alpha1"
+	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 
+	"kubevirt.io/kubevirt/pkg/libvmi"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+
 	"kubevirt.io/kubevirt/tests"
 	cd "kubevirt.io/kubevirt/tests/containerdisk"
 	"kubevirt.io/kubevirt/tests/testsuite"
@@ -64,11 +66,17 @@ var _ = Describe("[sig-compute]Dry-Run requests", decorators.SigCompute, func()
 	})
 
 	Context("VirtualMachineInstances", func() {
-		var vmi *v1.VirtualMachineInstance
+		var (
+			vmi *v1.VirtualMachineInstance
+		)
 		resource := "virtualmachineinstances"
 
 		BeforeEach(func() {
-			vmi = tests.NewRandomVMIWithEphemeralDisk(cd.ContainerDiskFor(cd.ContainerDiskAlpine))
+			vmi = libvmifact.NewAlpine(
+				libvmi.WithNamespace(testsuite.GetTestNamespace(nil)),
+				libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
 		})
 
 		It("[test_id:7627]create a VirtualMachineInstance", func() {
@@ -231,8 +239,11 @@ var _ = Describe("[sig-compute]Dry-Run requests", decorators.SigCompute, func()
 		resource := "virtualmachineinstancemigrations"
 
 		BeforeEach(func() {
-			vmi := tests.NewRandomVMIWithEphemeralDisk(cd.ContainerDiskFor(cd.ContainerDiskAlpine))
-			vmi, err = virtClient.VirtualMachineInstance(vmi.Namespace).Create(context.Background(), vmi, metav1.CreateOptions{})
+			vmi := libvmifact.NewAlpine(
+				libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+				libvmi.WithNetwork(v1.DefaultPodNetwork()),
+			)
+			vmi, err = virtClient.VirtualMachineInstance(testsuite.GetTestNamespace(vmi)).Create(context.Background(), vmi, metav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
 			vmim = libmigration.New(vmi.Name, vmi.Namespace)
 		})
@@ -527,7 +538,7 @@ var _ = Describe("[sig-compute]Dry-Run requests", decorators.SigCompute, func()
 	})
 
 	Context("VM Snapshots", func() {
-		var snap *v1alpha1.VirtualMachineSnapshot
+		var snap *snapshotv1.VirtualMachineSnapshot
 
 		BeforeEach(func() {
 			tests.EnableFeatureGate(virtconfig.SnapshotGate)
@@ -618,7 +629,7 @@ var _ = Describe("[sig-compute]Dry-Run requests", decorators.SigCompute, func()
 	})
 
 	Context("VM Restores", func() {
-		var restore *v1alpha1.VirtualMachineRestore
+		var restore *snapshotv1.VirtualMachineRestore
 
 		BeforeEach(func() {
 			tests.EnableFeatureGate(virtconfig.SnapshotGate)
@@ -738,7 +749,10 @@ func newVMIPreset(name, labelKey, labelValue string) *v1.VirtualMachineInstanceP
 }
 
 func newVMIReplicaSet(name string) *v1.VirtualMachineInstanceReplicaSet {
-	vmi := tests.NewRandomVMIWithEphemeralDisk(cd.ContainerDiskFor(cd.ContainerDiskAlpine))
+	vmi := libvmifact.NewAlpine(
+		libvmi.WithInterface(libvmi.InterfaceDeviceWithMasqueradeBinding()),
+		libvmi.WithNetwork(v1.DefaultPodNetwork()),
+	)
 
 	return &v1.VirtualMachineInstanceReplicaSet{
 		ObjectMeta: metav1.ObjectMeta{
@@ -763,15 +777,15 @@ func newVMIReplicaSet(name string) *v1.VirtualMachineInstanceReplicaSet {
 	}
 }
 
-func newVMSnapshot(vm *v1.VirtualMachine) *v1alpha1.VirtualMachineSnapshot {
+func newVMSnapshot(vm *v1.VirtualMachine) *snapshotv1.VirtualMachineSnapshot {
 	group := vm.GroupVersionKind().Group
 
-	return &v1alpha1.VirtualMachineSnapshot{
+	return &snapshotv1.VirtualMachineSnapshot{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      vm.Name + "-snapshot",
 			Namespace: testsuite.GetTestNamespace(vm),
 		},
-		Spec: v1alpha1.VirtualMachineSnapshotSpec{
+		Spec: snapshotv1.VirtualMachineSnapshotSpec{
 			Source: corev1.TypedLocalObjectReference{
 				APIGroup: &group,
 				Kind:     vm.GroupVersionKind().Kind,
@@ -781,15 +795,15 @@ func newVMSnapshot(vm *v1.VirtualMachine) *v1alpha1.VirtualMachineSnapshot {
 	}
 }
 
-func newVMRestore(vm *v1.VirtualMachine, snapshot *v1alpha1.VirtualMachineSnapshot) *v1alpha1.VirtualMachineRestore {
+func newVMRestore(vm *v1.VirtualMachine, snapshot *snapshotv1.VirtualMachineSnapshot) *snapshotv1.VirtualMachineRestore {
 	group := vm.GroupVersionKind().Group
 
-	return &v1alpha1.VirtualMachineRestore{
+	return &snapshotv1.VirtualMachineRestore{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      vm.Name + "-restore",
 			Namespace: testsuite.GetTestNamespace(vm),
 		},
-		Spec: v1alpha1.VirtualMachineRestoreSpec{
+		Spec: snapshotv1.VirtualMachineRestoreSpec{
 			Target: corev1.TypedLocalObjectReference{
 				APIGroup: &group,
 				Kind:     vm.GroupVersionKind().Kind,
@@ -800,7 +814,7 @@ func newVMRestore(vm *v1.VirtualMachine, snapshot *v1alpha1.VirtualMachineSnapsh
 	}
 }
 
-func waitForSnapshotToBeReady(virtClient kubecli.KubevirtClient, snapshot *v1alpha1.VirtualMachineSnapshot, timeoutSec int) {
+func waitForSnapshotToBeReady(virtClient kubecli.KubevirtClient, snapshot *snapshotv1.VirtualMachineSnapshot, timeoutSec int) {
 	By(fmt.Sprintf("Waiting for snapshot %s to be ready to use", snapshot.Name))
 	EventuallyWithOffset(1, func() bool {
 		updatedSnap, err := virtClient.VirtualMachineSnapshot(snapshot.Namespace).Get(context.Background(), snapshot.Name, metav1.GetOptions{})
