@@ -36,7 +36,7 @@ func IsCPUManagerPresent(node *v1.Node) bool {
 
 func IsRealtimeCapable(node *v1.Node) bool {
 	gomega.Expect(node).ToNot(gomega.BeNil())
-	for label, _ := range node.Labels {
+	for label := range node.Labels {
 		if label == v12.RealtimeLabel {
 			return true
 		}
@@ -70,7 +70,7 @@ func HasFeature(feature string) bool {
 
 func IsSEVCapable(node *v1.Node, sevLabel string) bool {
 	gomega.Expect(node).ToNot(gomega.BeNil())
-	for label, _ := range node.Labels {
+	for label := range node.Labels {
 		if label == sevLabel {
 			return true
 		}
