@@ -19,7 +19,6 @@ import (
 	k8sv1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/resource"
 	v1 "kubevirt.io/api/core/v1"
-	"kubevirt.io/client-go/kubecli"
 
 	"kubevirt.io/kubevirt/pkg/pointer"
 	"kubevirt.io/kubevirt/tests"
@@ -27,7 +26,8 @@ import (
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	. "kubevirt.io/kubevirt/tests/framework/matcher"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libpod"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/testsuite"
 )
 
@@ -37,19 +37,11 @@ const testString = "GuestConsoleTest3413254123535234523"
 var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func() {
 
 	var (
-		virtClient kubecli.KubevirtClient
-		alpineVmi  *v1.VirtualMachineInstance
-		cirrosVmi  *v1.VirtualMachineInstance
+		cirrosVmi *v1.VirtualMachineInstance
 	)
 
 	BeforeEach(func() {
-		virtClient = kubevirt.Client()
-
-		alpineVmi = libvmi.NewAlpine()
-		alpineVmi.Spec.Domain.Devices.AutoattachSerialConsole = pointer.P(true)
-		alpineVmi.Spec.Domain.Devices.LogSerialConsole = pointer.P(true)
-
-		cirrosVmi = libvmi.NewCirros()
+		cirrosVmi = libvmifact.NewCirros()
 		cirrosVmi.Spec.Domain.Devices.AutoattachSerialConsole = pointer.P(true)
 		cirrosVmi.Spec.Domain.Devices.LogSerialConsole = pointer.P(true)
 	})
@@ -58,12 +50,12 @@ var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func()
 		Context("set LogSerialConsole", func() {
 			DescribeTable("should successfully start with LogSerialConsole", func(autoattachSerialConsole, logSerialConsole, expected bool) {
 				By("Starting a VMI")
-				alpineVmi.Spec.Domain.Devices.AutoattachSerialConsole = pointer.P(autoattachSerialConsole)
-				alpineVmi.Spec.Domain.Devices.LogSerialConsole = pointer.P(logSerialConsole)
-				vmi := tests.RunVMIAndExpectLaunch(alpineVmi, cirrosStartupTimeout)
+				cirrosVmi.Spec.Domain.Devices.AutoattachSerialConsole = pointer.P(autoattachSerialConsole)
+				cirrosVmi.Spec.Domain.Devices.LogSerialConsole = pointer.P(logSerialConsole)
+				vmi := tests.RunVMIAndExpectLaunch(cirrosVmi, cirrosStartupTimeout)
 
 				By("Finding virt-launcher pod")
-				virtlauncherPod, err := libvmi.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+				virtlauncherPod, err := libpod.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
 				Expect(err).ToNot(HaveOccurred())
 				foundContainer := false
 				for _, container := range virtlauncherPod.Spec.Containers {
@@ -92,7 +84,7 @@ var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func()
 				vmi := tests.RunVMIAndExpectLaunch(cirrosVmi, cirrosStartupTimeout)
 
 				By("Finding virt-launcher pod")
-				virtlauncherPod, err := libvmi.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+				virtlauncherPod, err := libpod.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
 				Expect(err).ToNot(HaveOccurred())
 				foundContainer := false
 				for _, container := range virtlauncherPod.Spec.Containers {
@@ -135,13 +127,13 @@ var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func()
 				vmi = tests.RunVMIAndExpectLaunch(cirrosVmi, cirrosStartupTimeout)
 
 				By("Finding virt-launcher pod")
-				virtlauncherPod, err := libvmi.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+				virtlauncherPod, err := libpod.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
 				Expect(err).ToNot(HaveOccurred())
 
 				By("Getting logs with logs API and ensure the logs are correctly ordered with no unexpected line breaks")
 
 				Eventually(func(g Gomega) bool {
-					logs, err := getConsoleLogs(virtClient, virtlauncherPod)
+					logs, err := getConsoleLogs(virtlauncherPod)
 					g.Expect(err).ToNot(HaveOccurred())
 					return strings.Contains(logs, cirrosLogo)
 				}, cirrosStartupTimeout*time.Second, 2*time.Second).Should(BeTrue())
@@ -154,7 +146,7 @@ var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func()
 				}, 240)).To(Succeed())
 
 				By("Ensuring that log fetching is not breaking an open console")
-				expecter, errChan, eerr := console.NewExpecter(virtClient, vmi, 90*time.Second)
+				expecter, errChan, eerr := console.NewExpecter(kubevirt.Client(), vmi, 90*time.Second)
 				Expect(eerr).ToNot(HaveOccurred())
 				if eerr == nil {
 					defer func() {
@@ -165,7 +157,7 @@ var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func()
 
 				Consistently(errChan).ShouldNot(Receive())
 
-				logs, err := getConsoleLogs(virtClient, virtlauncherPod)
+				logs, err := getConsoleLogs(virtlauncherPod)
 				Expect(err).ToNot(HaveOccurred())
 
 				By("Ensuring that logs contain the login attempt")
@@ -184,23 +176,23 @@ var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func()
 				vmi = tests.RunVMIAndExpectLaunch(cirrosVmi, cirrosStartupTimeout)
 
 				By("Finding virt-launcher pod")
-				virtlauncherPod, err := libvmi.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+				virtlauncherPod, err := libpod.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
 				Expect(err).ToNot(HaveOccurred())
 
 				By("Generating 9MB of log data to force log rotation and discarding")
 				generateHugeLogData(vmi, 9)
 
 				By("Ensuring that log fetching is not failing")
-				_, err = getConsoleLogs(virtClient, virtlauncherPod)
+				_, err = getConsoleLogs(virtlauncherPod)
 				Expect(err).ToNot(HaveOccurred())
 
 				By("Ensuring that we have 4 rotated log files (+term one)")
-				outputString, err := exec.ExecuteCommandOnPod(virtClient, virtlauncherPod, "guest-console-log", []string{"/bin/ls", "-l", fmt.Sprintf("/var/run/kubevirt-private/%v", vmi.UID)})
+				outputString, err := exec.ExecuteCommandOnPod(virtlauncherPod, "guest-console-log", []string{"/bin/ls", "-l", fmt.Sprintf("/var/run/kubevirt-private/%v", vmi.UID)})
 				Expect(err).ToNot(HaveOccurred())
 				Expect(strings.Count(outputString, "virt-serial0-log")).To(Equal(4 + 1))
 			})
 
-			It("it should not skip any log line even trying to flood the serial console for QOSGuaranteed VMs", func() {
+			It("[QUARANTINE] it should not skip any log line even trying to flood the serial console for QOSGuaranteed VMs", decorators.Quarantine, func() {
 				cirrosVmi.Spec.Domain.Resources = v1.ResourceRequirements{
 					Requests: k8sv1.ResourceList{
 						k8sv1.ResourceCPU:    resource.MustParse("1000m"),
@@ -216,14 +208,14 @@ var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func()
 				Expect(*vmi.Status.QOSClass).To(Equal(k8sv1.PodQOSGuaranteed))
 
 				By("Finding virt-launcher pod")
-				virtlauncherPod, err := libvmi.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+				virtlauncherPod, err := libpod.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
 				Expect(err).ToNot(HaveOccurred())
 
 				By("Generating 1MB of log data")
 				generateHugeLogData(vmi, 1)
 
 				By("Ensuring that log fetching is not failing")
-				logs, err := getConsoleLogs(virtClient, virtlauncherPod)
+				logs, err := getConsoleLogs(virtlauncherPod)
 				Expect(err).ToNot(HaveOccurred())
 
 				By("Checking that log lines are sequential with no gaps")
@@ -254,10 +246,10 @@ var _ = Describe("[sig-compute]Guest console log", decorators.SigCompute, func()
 			AfterEach(func() {
 				if CurrentSpecReport().Failed() {
 					if vmi != nil {
-						virtlauncherPod, err := libvmi.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+						virtlauncherPod, err := libpod.GetPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
 						if err == nil {
 							artifactsDir, _ := os.LookupEnv("ARTIFACTS")
-							outputString, err := exec.ExecuteCommandOnPod(virtClient, virtlauncherPod, "guest-console-log", []string{"/bin/bash", "-c", "/bin/tail -v -n +1 " + fmt.Sprintf("/var/run/kubevirt-private/%v/virt-serial*-log*", vmi.UID)})
+							outputString, err := exec.ExecuteCommandOnPod(virtlauncherPod, "guest-console-log", []string{"/bin/bash", "-c", "/bin/tail -v -n +1 " + fmt.Sprintf("/var/run/kubevirt-private/%v/virt-serial*-log*", vmi.UID)})
 							if err == nil {
 								lpath := filepath.Join(artifactsDir, fmt.Sprintf("serial_logs_content_%v.txt", vmi.UID))
 								_, _ = fmt.Fprintf(GinkgoWriter, "Serial console log failed, serial console logs dump from virt-launcher pod collected at file at %s\n", lpath)
@@ -292,8 +284,8 @@ func generateHugeLogData(vmi *v1.VirtualMachineInstance, mb int) {
 	}, 240)).To(Succeed())
 }
 
-func getConsoleLogs(virtClient kubecli.KubevirtClient, virtlauncherPod *k8sv1.Pod) (string, error) {
-	logsRaw, err := virtClient.CoreV1().
+func getConsoleLogs(virtlauncherPod *k8sv1.Pod) (string, error) {
+	logsRaw, err := kubevirt.Client().CoreV1().
 		Pods(virtlauncherPod.Namespace).
 		GetLogs(virtlauncherPod.Name, &k8sv1.PodLogOptions{
 			Container: "guest-console-log",
