@@ -6,13 +6,16 @@ import (
 	"fmt"
 	"time"
 
+	"kubevirt.io/kubevirt/tests/libnet"
+
+	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/pointer"
 
 	v1 "kubevirt.io/api/core/v1"
 
 	util2 "kubevirt.io/kubevirt/tests/util"
 
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 
 	"kubevirt.io/kubevirt/tests/testsuite"
 
@@ -74,7 +77,7 @@ var _ = Describe("[sig-compute]VM Affinity", decorators.SigCompute, decorators.S
 						NodeSelectorTerms: []k8sv1.NodeSelectorTerm{
 							{
 								MatchExpressions: []k8sv1.NodeSelectorRequirement{
-									{Key: "kubernetes.io/hostname", Operator: k8sv1.NodeSelectorOpIn, Values: []string{nodeName}},
+									{Key: k8sv1.LabelHostname, Operator: k8sv1.NodeSelectorOpIn, Values: []string{nodeName}},
 								},
 							},
 						},
@@ -93,17 +96,16 @@ var _ = Describe("[sig-compute]VM Affinity", decorators.SigCompute, decorators.S
 			}
 			patchData1Str := fmt.Sprintf(`[ {"op":"%s","path":"/spec/template/spec/affinity"%s} ]`, op, value)
 			patchData1 := []byte(patchData1Str)
-			fmt.Println("patchData1: ", string(patchData1))
 			_, err = virtClient.VirtualMachine(vmNamespace).Patch(context.Background(), vmName, types.JSONPatchType, patchData1, k8smetav1.PatchOptions{})
 			Expect(err).ToNot(HaveOccurred())
 		}
 
-		It("should successfully update node selector", func() {
+		It("[test_id:11208]should successfully update node selector", func() {
 
 			By("Creating a running VM")
-			options := libvmi.WithMasqueradeNetworking()
+			options := libnet.WithMasqueradeNetworking()
 			options = append(options, libvmi.WithCPUCount(1, 2, 1))
-			vmi := libvmi.NewAlpineWithTestTooling(
+			vmi := libvmifact.NewAlpineWithTestTooling(
 				options...,
 			)
 			vmi.Namespace = testsuite.GetTestNamespace(vmi)
@@ -111,8 +113,8 @@ var _ = Describe("[sig-compute]VM Affinity", decorators.SigCompute, decorators.S
 
 			vm, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, k8smetav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
-			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(beReady())
-			libwait.WaitForSuccessfulVMIStart(vmi)
+			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(BeReady())
+			vmi = libwait.WaitForSuccessfulVMIStart(vmi)
 
 			By("Adding node selector")
 			vmNodeSelector := map[string]string{k8sv1.LabelOSStable: "not-existing-os"}
@@ -157,19 +159,19 @@ var _ = Describe("[sig-compute]VM Affinity", decorators.SigCompute, decorators.S
 			}, 240*time.Second, time.Second).Should(BeTrue())
 
 		})
-		It("should successfully update node affinity", func() {
+		It("[test_id:11209]should successfully update node affinity", func() {
 
 			By("Creating a running VM")
-			vmi := libvmi.NewAlpineWithTestTooling(
-				libvmi.WithMasqueradeNetworking()...,
+			vmi := libvmifact.NewAlpineWithTestTooling(
+				libnet.WithMasqueradeNetworking()...,
 			)
 			vmi.Namespace = testsuite.GetTestNamespace(vmi)
 			vm := libvmi.NewVirtualMachine(vmi, libvmi.WithRunning())
 
 			vm, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, k8smetav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
-			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(beReady())
-			libwait.WaitForSuccessfulVMIStart(vmi)
+			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(BeReady())
+			vmi = libwait.WaitForSuccessfulVMIStart(vmi)
 
 			By("Adding Affinity")
 			vmAffinity := generateNodeAffinity("fakeNode_1")
