@@ -6,16 +6,18 @@ import (
 	"fmt"
 	"time"
 
-	"kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/tests/libnet"
 
+	migrationsv1 "kubevirt.io/api/migrations/v1alpha1"
+
+	"kubevirt.io/kubevirt/pkg/libvmi"
+	"kubevirt.io/kubevirt/pkg/pointer"
+	"kubevirt.io/kubevirt/pkg/virt-launcher/virtwrap/api"
 	"kubevirt.io/kubevirt/tests/framework/checks"
 
 	"kubevirt.io/kubevirt/tests/libmigration"
 
-	"github.com/onsi/gomega/gstruct"
-	gomegatypes "github.com/onsi/gomega/types"
-
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 
 	"kubevirt.io/kubevirt/tests/flags"
 	util2 "kubevirt.io/kubevirt/tests/util"
@@ -36,7 +38,9 @@ import (
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	. "kubevirt.io/kubevirt/tests/framework/matcher"
+	"kubevirt.io/kubevirt/tests/libpod"
 	"kubevirt.io/kubevirt/tests/libwait"
+	testsmig "kubevirt.io/kubevirt/tests/migration"
 )
 
 var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, decorators.SigComputeMigrations, decorators.RequiresTwoSchedulableNodes, decorators.VMLiveUpdateFeaturesGate, Serial, func() {
@@ -66,11 +70,9 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 			enabled  int
 			disabled int
 		}
-		countDomCPUs := func(vmi *v1.VirtualMachineInstance) (count cpuCount) {
-			domSpec, err := tests.GetRunningVMIDomainSpec(vmi)
-			ExpectWithOffset(1, err).NotTo(HaveOccurred())
-			ExpectWithOffset(1, domSpec.VCPUs).NotTo(BeNil())
-			for _, cpu := range domSpec.VCPUs.VCPU {
+		countDomCPUs := func(spec *api.DomainSpec) (count cpuCount) {
+			ExpectWithOffset(1, spec.VCPUs).NotTo(BeNil())
+			for _, cpu := range spec.VCPUs.VCPU {
 				if cpu.Enabled == "yes" {
 					count.enabled++
 				} else {
@@ -81,15 +83,14 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 			}
 			return
 		}
-
-		It("should successfully plug vCPUs", func() {
+		It("[test_id:10811]should successfully plug vCPUs", func() {
 			By("Creating a running VM with 1 socket and 2 max sockets")
 			const (
 				maxSockets uint32 = 2
 			)
 
-			vmi := libvmi.NewAlpineWithTestTooling(
-				libvmi.WithMasqueradeNetworking()...,
+			vmi := libvmifact.NewAlpineWithTestTooling(
+				libnet.WithMasqueradeNetworking()...,
 			)
 			vmi.Namespace = testsuite.GetTestNamespace(vmi)
 			vmi.Spec.Domain.CPU = &v1.CPU{
@@ -102,11 +103,12 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 
 			vm, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, k8smetav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
-			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(beReady())
-			libwait.WaitForSuccessfulVMIStart(vmi)
+			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(BeReady())
+			vmi = libwait.WaitForSuccessfulVMIStart(vmi)
 
 			By("Ensuring the compute container has 200m CPU")
-			compute := tests.GetComputeContainerOfPod(tests.GetVmiPod(virtClient, vmi))
+			compute, err := libpod.LookupComputeContainerFromVmi(vmi)
+			Expect(err).ToNot(HaveOccurred())
 
 			Expect(compute).NotTo(BeNil(), "failed to find compute container")
 			reqCpu := compute.Resources.Requests.Cpu().Value()
@@ -114,7 +116,13 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 			Expect(reqCpu).To(Equal(expCpu.Value()))
 
 			By("Ensuring the libvirt domain has 2 enabled cores and 2 hotpluggable cores")
-			Expect(countDomCPUs(vmi)).To(Equal(cpuCount{
+			var domSpec *api.DomainSpec
+			Eventually(func() error {
+				domSpec, err = tests.GetRunningVMIDomainSpec(vmi)
+				return err
+			}).WithTimeout(20 * time.Second).WithPolling(time.Second).Should(Succeed())
+
+			Expect(countDomCPUs(domSpec)).To(Equal(cpuCount{
 				enabled:  2,
 				disabled: 2,
 			}))
@@ -145,17 +153,21 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 			libmigration.ExpectMigrationToSucceedWithDefaultTimeout(virtClient, migration)
 
 			By("Ensuring the libvirt domain has 4 enabled cores")
-			Eventually(func() cpuCount {
-				vmi, err = virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, k8smetav1.GetOptions{})
-				Expect(err).NotTo(HaveOccurred())
-				return countDomCPUs(vmi)
-			}, 240*time.Second, time.Second).Should(Equal(cpuCount{
+
+			Eventually(func() error {
+				domSpec, err = tests.GetRunningVMIDomainSpec(vmi)
+				return err
+			}).WithTimeout(20 * time.Second).WithPolling(time.Second).Should(Succeed())
+
+			Expect(countDomCPUs(domSpec)).To(Equal(cpuCount{
 				enabled:  4,
 				disabled: 0,
 			}))
 
 			By("Ensuring the virt-launcher pod now has 400m CPU")
-			compute = tests.GetComputeContainerOfPod(tests.GetVmiPod(virtClient, vmi))
+			compute, err = libpod.LookupComputeContainerFromVmi(vmi)
+			Expect(err).ToNot(HaveOccurred())
+
 			Expect(compute).NotTo(BeNil(), "failed to find compute container")
 			reqCpu = compute.Resources.Requests.Cpu().Value()
 			expCpu = resource.MustParse("400m")
@@ -181,13 +193,13 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 			Eventually(ThisVM(vm), 4*time.Minute, 2*time.Second).Should(HaveConditionMissingOrFalse(v1.VirtualMachineRestartRequired))
 		})
 
-		It("should successfully plug guaranteed vCPUs", decorators.RequiresTwoWorkerNodesWithCPUManager, func() {
+		It("[test_id:10822]should successfully plug guaranteed vCPUs", decorators.RequiresTwoWorkerNodesWithCPUManager, func() {
 			checks.ExpectAtLeastTwoWorkerNodesWithCPUManager(virtClient)
 			const maxSockets uint32 = 3
 
 			By("Creating a running VM with 1 socket and 2 max sockets")
-			vmi := libvmi.NewAlpineWithTestTooling(
-				libvmi.WithMasqueradeNetworking()...,
+			vmi := libvmifact.NewAlpineWithTestTooling(
+				libnet.WithMasqueradeNetworking()...,
 			)
 			vmi.Namespace = testsuite.GetTestNamespace(vmi)
 			vmi.Spec.Domain.CPU = &v1.CPU{
@@ -201,11 +213,12 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 
 			vm, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, k8smetav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
-			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(beReady())
-			libwait.WaitForSuccessfulVMIStart(vmi)
+			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(BeReady())
+			vmi = libwait.WaitForSuccessfulVMIStart(vmi)
 
 			By("Ensuring the compute container has 2 CPU")
-			compute := tests.GetComputeContainerOfPod(tests.GetVmiPod(virtClient, vmi))
+			compute, err := libpod.LookupComputeContainerFromVmi(vmi)
+			Expect(err).ToNot(HaveOccurred())
 
 			Expect(compute).NotTo(BeNil(), "failed to find compute container")
 			reqCpu := compute.Resources.Requests.Cpu().Value()
@@ -213,7 +226,13 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 			Expect(reqCpu).To(Equal(expCpu.Value()))
 
 			By("Ensuring the libvirt domain has 2 enabled cores and 4 disabled cores")
-			Expect(countDomCPUs(vmi)).To(Equal(cpuCount{
+			var domSpec *api.DomainSpec
+			Eventually(func() error {
+				domSpec, err = tests.GetRunningVMIDomainSpec(vmi)
+				return err
+			}).WithTimeout(20 * time.Second).WithPolling(time.Second).Should(Succeed())
+
+			Expect(countDomCPUs(domSpec)).To(Equal(cpuCount{
 				enabled:  2,
 				disabled: 4,
 			}))
@@ -242,17 +261,19 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 			))
 
 			By("Ensuring the libvirt domain has 4 enabled cores")
-			Eventually(func() cpuCount {
-				vmi, err = virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, k8smetav1.GetOptions{})
-				Expect(err).NotTo(HaveOccurred())
-				return countDomCPUs(vmi)
-			}, 30*time.Second, time.Second).Should(Equal(cpuCount{
+			Eventually(func() error {
+				domSpec, err = tests.GetRunningVMIDomainSpec(vmi)
+				return err
+			}).WithTimeout(20 * time.Second).WithPolling(time.Second).Should(Succeed())
+
+			Expect(countDomCPUs(domSpec)).To(Equal(cpuCount{
 				enabled:  4,
 				disabled: 2,
 			}))
 
 			By("Ensuring the virt-launcher pod now has 4 CPU")
-			compute = tests.GetComputeContainerOfPod(tests.GetVmiPod(virtClient, vmi))
+			compute, err = libpod.LookupComputeContainerFromVmi(vmi)
+			Expect(err).ToNot(HaveOccurred())
 
 			Expect(compute).NotTo(BeNil(), "failed to find compute container")
 			reqCpu = compute.Resources.Requests.Cpu().Value()
@@ -260,6 +281,84 @@ var _ = Describe("[sig-compute][Serial]CPU Hotplug", decorators.SigCompute, deco
 			Expect(reqCpu).To(Equal(expCpu.Value()))
 		})
 	})
+
+	Context("Abort CPU change", func() {
+		It("should cancel the automated workload update", func() {
+			vmi := libvmifact.NewAlpineWithTestTooling(
+				libnet.WithMasqueradeNetworking()...,
+			)
+			vmi.Namespace = testsuite.GetTestNamespace(vmi)
+			vmi.Spec.Domain.CPU = &v1.CPU{
+				Sockets:    1,
+				Cores:      2,
+				Threads:    1,
+				MaxSockets: 2,
+			}
+			By("Limiting the bandwidth of migrations in the test namespace")
+			policy := testsmig.PreparePolicyAndVMIWithBandwidthLimitation(vmi, resource.MustParse("1Ki"))
+			testsmig.CreateMigrationPolicy(virtClient, policy)
+			Eventually(func() *migrationsv1.MigrationPolicy {
+				policy, err := virtClient.MigrationPolicy().Get(context.Background(), policy.Name, metav1.GetOptions{})
+				if err != nil {
+					return nil
+				}
+				return policy
+			}, 30*time.Second, time.Second).ShouldNot(BeNil())
+
+			vm := libvmi.NewVirtualMachine(vmi, libvmi.WithRunning())
+
+			vm, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			Eventually(ThisVM(vm), 360*time.Second, 1*time.Second).Should(BeReady())
+			libwait.WaitForSuccessfulVMIStart(vmi)
+
+			// Update the CPU number and trigger the workload update
+			// and migration
+			By("Enabling the second socket to trigger the migration update")
+			p, err := patch.New(patch.WithReplace("/spec/template/spec/domain/cpu/sockets", 2)).GeneratePayload()
+			Expect(err).NotTo(HaveOccurred())
+			_, err = virtClient.VirtualMachine(vm.Namespace).Patch(context.Background(), vm.Name, types.JSONPatchType, p, k8smetav1.PatchOptions{})
+			Expect(err).ToNot(HaveOccurred())
+
+			Eventually(func() bool {
+				migrations, err := virtClient.VirtualMachineInstanceMigration(vm.Namespace).List(context.Background(), k8smetav1.ListOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				for _, mig := range migrations.Items {
+					if mig.Spec.VMIName == vmi.Name {
+						return true
+					}
+				}
+				return false
+			}, 30*time.Second, time.Second).Should(BeTrue())
+
+			// Add annotation to cancel the workload update
+			By("Patching the workload migration abortion annotation")
+			vmi.ObjectMeta.Annotations[v1.WorkloadUpdateMigrationAbortionAnnotation] = ""
+			p, err = patch.New(patch.WithAdd("/metadata/annotations", vmi.ObjectMeta.Annotations)).GeneratePayload()
+			Expect(err).ToNot(HaveOccurred())
+			_, err = virtClient.VirtualMachineInstance(vmi.Namespace).Patch(context.Background(), vmi.Name, types.JSONPatchType, p, metav1.PatchOptions{})
+			Expect(err).ToNot(HaveOccurred())
+			Eventually(func() bool {
+				vmi, err = virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				return metav1.HasAnnotation(vmi.ObjectMeta, v1.WorkloadUpdateMigrationAbortionAnnotation)
+			}, 30*time.Second, time.Second).Should(BeTrue())
+
+			// Wait until the migration is cancelled by the workload
+			// updater
+			Eventually(func() bool {
+				migrations, err := virtClient.VirtualMachineInstanceMigration(vm.Namespace).List(context.Background(), k8smetav1.ListOptions{})
+				Expect(err).ToNot(HaveOccurred())
+				for _, mig := range migrations.Items {
+					if mig.Spec.VMIName == vmi.Name {
+						return true
+					}
+				}
+				return false
+			}, 30*time.Second, time.Second).Should(BeFalse())
+
+		})
+	})
 })
 
 func patchWorkloadUpdateMethodAndRolloutStrategy(kvName string, virtClient kubecli.KubevirtClient, updateStrategy *v1.KubeVirtWorkloadUpdateStrategy, rolloutStrategy *v1.VMRolloutStrategy) {
@@ -277,11 +376,3 @@ func patchWorkloadUpdateMethodAndRolloutStrategy(kvName string, virtClient kubec
 		return err
 	}, 10*time.Second, 1*time.Second).ShouldNot(HaveOccurred())
 }
-
-func beReady() gomegatypes.GomegaMatcher {
-	return gstruct.PointTo(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
-		"Status": gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
-			"Ready": BeTrue(),
-		}),
-	}))
-}
