@@ -81,7 +81,7 @@ type pvcOption func(*corev1.PersistentVolumeClaimSpec)
 func WithPVC(options ...pvcOption) dvOption {
 	pvc := &corev1.PersistentVolumeClaimSpec{
 		AccessModes: []corev1.PersistentVolumeAccessMode{corev1.ReadWriteOnce},
-		Resources: corev1.ResourceRequirements{
+		Resources: corev1.VolumeResourceRequirements{
 			Requests: corev1.ResourceList{
 				"storage": resource.MustParse(cd.CirrosVolumeSize),
 			},
