@@ -23,6 +23,8 @@ import (
 	"kubevirt.io/kubevirt/tests/clientcmd"
 	"kubevirt.io/kubevirt/tests/flags"
 	"kubevirt.io/kubevirt/tests/framework/matcher"
+	"kubevirt.io/kubevirt/tests/libmonitoring"
+	"kubevirt.io/kubevirt/tests/libnet"
 	"kubevirt.io/kubevirt/tests/util"
 
 	. "github.com/onsi/ginkgo/v2"
@@ -261,7 +263,7 @@ func EnsureNoMigrationMetadataInPersistentXML(vmi *v1.VirtualMachineInstance) {
 
 func GetValidSourceNodeAndTargetNodeForHostModelMigration(virtCli kubecli.KubevirtClient) (sourceNode *k8sv1.Node, targetNode *k8sv1.Node, err error) {
 	getNodeHostRequiredFeatures := func(node *k8sv1.Node) (features []string) {
-		for key, _ := range node.Labels {
+		for key := range node.Labels {
 			if strings.HasPrefix(key, v1.HostModelRequiredFeaturesLabel) {
 				features = append(features, strings.TrimPrefix(key, v1.HostModelRequiredFeaturesLabel))
 			}
@@ -270,7 +272,7 @@ func GetValidSourceNodeAndTargetNodeForHostModelMigration(virtCli kubecli.Kubevi
 	}
 	areFeaturesSupportedOnNode := func(node *k8sv1.Node, features []string) bool {
 		isFeatureSupported := func(feature string) bool {
-			for key, _ := range node.Labels {
+			for key := range node.Labels {
 				if strings.HasPrefix(key, v1.CPUFeatureLabel) && strings.Contains(key, feature) {
 					return true
 				}
@@ -296,12 +298,12 @@ func GetValidSourceNodeAndTargetNodeForHostModelMigration(virtCli kubecli.Kubevi
 				continue
 			}
 
-			sourceHostCpuModel = tests.GetNodeHostModel(&potentialSourceNode)
+			sourceHostCpuModel = libnode.GetNodeHostModel(&potentialSourceNode)
 			if sourceHostCpuModel == "" {
 				continue
 			}
 			supportedInTarget := false
-			for key, _ := range potentialTargetNode.Labels {
+			for key := range potentialTargetNode.Labels {
 				if strings.HasPrefix(key, v1.SupportedHostModelMigrationCPU) && strings.Contains(key, sourceHostCpuModel) {
 					supportedInTarget = true
 					break
@@ -331,7 +333,7 @@ func CreateNodeAffinityRuleToMigrateFromSourceToTargetAndBack(sourceNode *k8sv1.
 				{
 					MatchExpressions: []k8sv1.NodeSelectorRequirement{
 						{
-							Key:      "kubernetes.io/hostname",
+							Key:      k8sv1.LabelHostname,
 							Operator: k8sv1.NodeSelectorOpIn,
 							Values:   []string{sourceNode.Name, targetNode.Name},
 						},
@@ -344,7 +346,7 @@ func CreateNodeAffinityRuleToMigrateFromSourceToTargetAndBack(sourceNode *k8sv1.
 				Preference: k8sv1.NodeSelectorTerm{
 					MatchExpressions: []k8sv1.NodeSelectorRequirement{
 						{
-							Key:      "kubernetes.io/hostname",
+							Key:      k8sv1.LabelHostname,
 							Operator: k8sv1.NodeSelectorOpIn,
 							Values:   []string{sourceNode.Name},
 						},
@@ -529,7 +531,7 @@ func RunMigrationAndCollectMigrationMetrics(vmi *v1.VirtualMachineInstance, migr
 	}
 
 	By("Waiting until the Migration Completes")
-	ip := libinfra.GetSupportedIP(metricsIPs, family)
+	ip := libnet.GetIP(metricsIPs, family)
 
 	_ = RunMigration(virtClient, migration)
 
@@ -539,6 +541,7 @@ func RunMigrationAndCollectMigrationMetrics(vmi *v1.VirtualMachineInstance, migr
 		keys := libinfra.GetKeysFromMetrics(metrics)
 		for _, key := range keys {
 			value := metrics[key]
+
 			if value == 0 {
 				return fmt.Errorf("metric value for %s is not expected to be zero", key)
 			}
@@ -546,9 +549,8 @@ func RunMigrationAndCollectMigrationMetrics(vmi *v1.VirtualMachineInstance, migr
 		return nil
 	}
 
-	getKubevirtVMMetricsFunc := tests.GetKubevirtVMMetricsFunc(&virtClient, pod)
 	Eventually(func() error {
-		out := getKubevirtVMMetricsFunc(ip)
+		out := libmonitoring.GetKubevirtVMMetrics(pod, ip)
 		for _, metricName := range migrationMetrics {
 			lines := libinfra.TakeMetricsWithPrefix(out, metricName)
 			metrics, err := libinfra.ParseMetricsToMap(lines)
@@ -562,3 +564,13 @@ func RunMigrationAndCollectMigrationMetrics(vmi *v1.VirtualMachineInstance, migr
 		return nil
 	}, 100*time.Second, 1*time.Second).ShouldNot(HaveOccurred())
 }
+
+func ConfirmMigrationMode(virtClient kubecli.KubevirtClient, vmi *v1.VirtualMachineInstance, expectedMode v1.MigrationMode) {
+	var err error
+	By("Retrieving the VMI post migration")
+	vmi, err = virtClient.VirtualMachineInstance(vmi.Namespace).Get(context.Background(), vmi.Name, metav1.GetOptions{})
+	ExpectWithOffset(1, err).ToNot(HaveOccurred(), fmt.Sprintf("couldn't find vmi err: %v \n", err))
+
+	By("Verifying the VMI's migration mode")
+	ExpectWithOffset(1, vmi.Status.MigrationState.Mode).To(Equal(expectedMode), fmt.Sprintf("expected migration state: %v got :%v \n", vmi.Status.MigrationState.Mode, expectedMode))
+}
