@@ -44,6 +44,8 @@ import (
 	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/flags"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
+	"kubevirt.io/kubevirt/tests/libmonitoring"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/util"
 )
 
@@ -90,7 +92,7 @@ var (
 var _ = Describe("[Serial][sig-monitoring]Component Monitoring", Serial, decorators.SigMonitoring, func() {
 	var err error
 	var virtClient kubecli.KubevirtClient
-	var scales *Scaling
+	var scales *libmonitoring.Scaling
 
 	BeforeEach(func() {
 		virtClient = kubevirt.Client()
@@ -115,10 +117,10 @@ var _ = Describe("[Serial][sig-monitoring]Component Monitoring", Serial, decorat
 
 	Context("Up metrics", func() {
 		BeforeEach(func() {
-			scales = NewScaling(virtClient, []string{virtOperator.deploymentName, virtController.deploymentName, virtApi.deploymentName})
+			scales = libmonitoring.NewScaling(virtClient, []string{virtOperator.deploymentName, virtController.deploymentName, virtApi.deploymentName})
 			scales.UpdateScale(virtOperator.deploymentName, int32(0))
 
-			reduceAlertPendingTime(virtClient)
+			libmonitoring.ReduceAlertPendingTime(virtClient)
 		})
 
 		AfterEach(func() {
@@ -130,55 +132,59 @@ var _ = Describe("[Serial][sig-monitoring]Component Monitoring", Serial, decorat
 				virtController.downAlert, virtController.noReadyAlert, virtController.lowCountAlert,
 				virtApi.downAlert, virtApi.noReadyAlert, virtApi.lowCountAlert,
 			}
-			waitUntilAlertDoesNotExist(virtClient, alerts...)
+			libmonitoring.WaitUntilAlertDoesNotExist(virtClient, alerts...)
 		})
 
 		It("VirtOperatorDown and NoReadyVirtOperator should be triggered when virt-operator is down", func() {
-			verifyAlertExist(virtClient, virtOperator.downAlert)
-			verifyAlertExist(virtClient, virtOperator.noReadyAlert)
+			libmonitoring.VerifyAlertExist(virtClient, virtOperator.downAlert)
+			libmonitoring.VerifyAlertExist(virtClient, virtOperator.noReadyAlert)
 		})
 
 		It("LowVirtOperatorCount should be triggered when virt-operator count is low", decorators.RequiresTwoSchedulableNodes, func() {
-			verifyAlertExist(virtClient, virtOperator.lowCountAlert)
+			libmonitoring.VerifyAlertExist(virtClient, virtOperator.lowCountAlert)
 		})
 
 		It("VirtControllerDown and NoReadyVirtController should be triggered when virt-controller is down", func() {
 			scales.UpdateScale(virtController.deploymentName, int32(0))
-			verifyAlertExist(virtClient, virtController.downAlert)
-			verifyAlertExist(virtClient, virtController.noReadyAlert)
+			libmonitoring.VerifyAlertExist(virtClient, virtController.downAlert)
+			libmonitoring.VerifyAlertExist(virtClient, virtController.noReadyAlert)
 		})
 
 		It("LowVirtControllersCount should be triggered when virt-controller count is low", decorators.RequiresTwoSchedulableNodes, func() {
 			scales.UpdateScale(virtController.deploymentName, int32(0))
-			verifyAlertExist(virtClient, virtController.lowCountAlert)
+			libmonitoring.VerifyAlertExist(virtClient, virtController.lowCountAlert)
 		})
 
 		It("VirtApiDown should be triggered when virt-api is down", func() {
 			scales.UpdateScale(virtApi.deploymentName, int32(0))
-			verifyAlertExist(virtClient, virtApi.downAlert)
+			libmonitoring.VerifyAlertExist(virtClient, virtApi.downAlert)
 		})
 
 		It("LowVirtAPICount should be triggered when virt-api count is low", decorators.RequiresTwoSchedulableNodes, func() {
 			scales.UpdateScale(virtApi.deploymentName, int32(0))
-			verifyAlertExist(virtClient, virtApi.lowCountAlert)
+			libmonitoring.VerifyAlertExist(virtClient, virtApi.lowCountAlert)
 		})
 	})
 
 	Context("Errors metrics", func() {
 		var crb *rbacv1.ClusterRoleBinding
+		const operatorRoleBindingName = "kubevirt-operator-rolebinding"
+		var operatorRoleBinding *rbacv1.RoleBinding
 
 		BeforeEach(func() {
 			virtClient = kubevirt.Client()
 
 			crb, err = virtClient.RbacV1().ClusterRoleBindings().Get(context.Background(), "kubevirt-operator", metav1.GetOptions{})
 			util.PanicOnError(err)
+			operatorRoleBinding, err = virtClient.RbacV1().RoleBindings(flags.KubeVirtInstallNamespace).Get(context.Background(), operatorRoleBindingName, metav1.GetOptions{})
+			Expect(err).ToNot(HaveOccurred())
 
 			increaseRateLimit()
 
-			scales = NewScaling(virtClient, []string{virtOperator.deploymentName})
+			scales = libmonitoring.NewScaling(virtClient, []string{virtOperator.deploymentName})
 			scales.UpdateScale(virtOperator.deploymentName, int32(0))
 
-			reduceAlertPendingTime(virtClient)
+			libmonitoring.ReduceAlertPendingTime(virtClient)
 		})
 
 		AfterEach(func() {
@@ -186,13 +192,17 @@ var _ = Describe("[Serial][sig-monitoring]Component Monitoring", Serial, decorat
 			crb.ObjectMeta.ResourceVersion = ""
 			crb.ObjectMeta.UID = ""
 			_, err = virtClient.RbacV1().ClusterRoleBindings().Create(context.Background(), crb, metav1.CreateOptions{})
-			if !errors.IsAlreadyExists(err) {
-				util.PanicOnError(err)
-			}
+			Expect(err).To(Or(Not(HaveOccurred()), MatchError(errors.IsAlreadyExists, "IsAlreadyExists")))
+
+			operatorRoleBinding.Annotations = nil
+			operatorRoleBinding.ObjectMeta.ResourceVersion = ""
+			operatorRoleBinding.ObjectMeta.UID = ""
+			_, err = virtClient.RbacV1().RoleBindings(flags.KubeVirtInstallNamespace).Create(context.Background(), operatorRoleBinding, metav1.CreateOptions{})
+			Expect(err).To(Or(Not(HaveOccurred()), MatchError(errors.IsAlreadyExists, "IsAlreadyExists")))
 			scales.RestoreAllScales()
 
 			time.Sleep(10 * time.Second)
-			waitUntilAlertDoesNotExist(virtClient, virtOperator.downAlert, virtApi.downAlert, virtController.downAlert, virtHandler.downAlert)
+			libmonitoring.WaitUntilAlertDoesNotExist(virtClient, virtOperator.downAlert, virtApi.downAlert, virtController.downAlert, virtHandler.downAlert)
 		})
 
 		It("VirtApiRESTErrorsBurst and VirtApiRESTErrorsHigh should be triggered when requests to virt-api are failing", func() {
@@ -203,8 +213,8 @@ var _ = Describe("[Serial][sig-monitoring]Component Monitoring", Serial, decorat
 				err := cmd.Execute()
 				Expect(err).To(HaveOccurred())
 
-				g.Expect(checkAlertExists(virtClient, virtApi.restErrorsBurtsAlert)).To(BeTrue())
-				g.Expect(checkAlertExists(virtClient, virtApi.restErrorsHighAlert)).To(BeTrue())
+				g.Expect(libmonitoring.CheckAlertExists(virtClient, virtApi.restErrorsBurtsAlert)).To(BeTrue())
+				g.Expect(libmonitoring.CheckAlertExists(virtClient, virtApi.restErrorsHighAlert)).To(BeTrue())
 			}, 5*time.Minute, 500*time.Millisecond).Should(Succeed())
 		})
 
@@ -212,72 +222,45 @@ var _ = Describe("[Serial][sig-monitoring]Component Monitoring", Serial, decorat
 			scales.RestoreScale(virtOperator.deploymentName)
 			err = virtClient.RbacV1().ClusterRoleBindings().Delete(context.Background(), crb.Name, metav1.DeleteOptions{})
 			Expect(err).ToNot(HaveOccurred())
+			err = virtClient.RbacV1().RoleBindings(flags.KubeVirtInstallNamespace).Delete(context.Background(), operatorRoleBindingName, metav1.DeleteOptions{})
+			Expect(err).ToNot(HaveOccurred())
 
 			Eventually(func(g Gomega) {
-				g.Expect(checkAlertExists(virtClient, virtOperator.restErrorsBurtsAlert)).To(BeTrue())
-				g.Expect(checkAlertExists(virtClient, virtOperator.restErrorsHighAlert)).To(BeTrue())
+				g.Expect(libmonitoring.CheckAlertExists(virtClient, virtOperator.restErrorsBurtsAlert)).To(BeTrue())
+				g.Expect(libmonitoring.CheckAlertExists(virtClient, virtOperator.restErrorsHighAlert)).To(BeTrue())
 			}, 5*time.Minute, 500*time.Millisecond).Should(Succeed())
 		})
 
-		It("VirtControllerRESTErrorsBurst and VirtControllerRESTErrorsHigh should be triggered when requests to virt-controller are failing", func() {
+		PIt("VirtControllerRESTErrorsBurst and VirtControllerRESTErrorsHigh should be triggered when requests to virt-controller are failing", func() {
 			err = virtClient.RbacV1().ClusterRoleBindings().Delete(context.Background(), "kubevirt-controller", metav1.DeleteOptions{})
 			Expect(err).ToNot(HaveOccurred())
 
-			vmi := tests.NewRandomVMI()
+			vmi := libvmifact.NewGuestless()
 
 			Eventually(func(g Gomega) {
 				_, _ = virtClient.VirtualMachineInstance(util.NamespaceTestDefault).Create(context.Background(), vmi, metav1.CreateOptions{})
 				_ = virtClient.VirtualMachineInstance(util.NamespaceTestDefault).Delete(context.Background(), vmi.Name, metav1.DeleteOptions{})
 
-				g.Expect(checkAlertExists(virtClient, virtController.restErrorsBurtsAlert)).To(BeTrue())
-				g.Expect(checkAlertExists(virtClient, virtController.restErrorsHighAlert)).To(BeTrue())
+				g.Expect(libmonitoring.CheckAlertExists(virtClient, virtController.restErrorsBurtsAlert)).To(BeTrue())
+				g.Expect(libmonitoring.CheckAlertExists(virtClient, virtController.restErrorsHighAlert)).To(BeTrue())
 			}, 5*time.Minute, 500*time.Millisecond).Should(Succeed())
 		})
 
-		It("VirtHandlerRESTErrorsBurst and VirtHandlerRESTErrorsHigh should be triggered when requests to virt-handler are failing", func() {
+		PIt("VirtHandlerRESTErrorsBurst and VirtHandlerRESTErrorsHigh should be triggered when requests to virt-handler are failing", func() {
 			err = virtClient.RbacV1().ClusterRoleBindings().Delete(context.Background(), "kubevirt-handler", metav1.DeleteOptions{})
 			Expect(err).ToNot(HaveOccurred())
 
-			vmi := tests.NewRandomVMI()
+			vmi := libvmifact.NewGuestless()
 
 			Eventually(func(g Gomega) {
 				_, _ = virtClient.VirtualMachineInstance(util.NamespaceTestDefault).Create(context.Background(), vmi, metav1.CreateOptions{})
 				_ = virtClient.VirtualMachineInstance(util.NamespaceTestDefault).Delete(context.Background(), vmi.Name, metav1.DeleteOptions{})
 
-				g.Expect(checkAlertExists(virtClient, virtHandler.restErrorsBurtsAlert)).To(BeTrue())
-				g.Expect(checkAlertExists(virtClient, virtHandler.restErrorsHighAlert)).To(BeTrue())
+				g.Expect(libmonitoring.CheckAlertExists(virtClient, virtHandler.restErrorsBurtsAlert)).To(BeTrue())
+				g.Expect(libmonitoring.CheckAlertExists(virtClient, virtHandler.restErrorsHighAlert)).To(BeTrue())
 			}, 5*time.Minute, 500*time.Millisecond).Should(Succeed())
 		})
 	})
-
-	Context("Resource metrics", func() {
-		var resourceAlerts = []string{
-			"KubeVirtComponentExceedsRequestedCPU",
-			"KubeVirtComponentExceedsRequestedMemory",
-		}
-
-		BeforeEach(func() {
-			virtClient = kubevirt.Client()
-			scales = NewScaling(virtClient, []string{virtOperator.deploymentName})
-			scales.UpdateScale(virtOperator.deploymentName, int32(0))
-			reduceAlertPendingTime(virtClient)
-		})
-
-		AfterEach(func() {
-			scales.RestoreAllScales()
-			time.Sleep(10 * time.Second)
-			waitUntilAlertDoesNotExist(virtClient, resourceAlerts...)
-		})
-
-		It("KubeVirtComponentExceedsRequestedCPU should be triggered when virt-api exceeds requested CPU", func() {
-			By("updating virt-api deployment CPU and Memory requests")
-			updateDeploymentResourcesRequest(virtClient, virtApi.deploymentName, resource.MustParse("0m"), resource.MustParse("0Mi"))
-
-			By("waiting for KubeVirtComponentExceedsRequestedCPU and KubeVirtComponentExceedsRequestedMemory alerts")
-			verifyAlertExist(virtClient, "KubeVirtComponentExceedsRequestedCPU")
-			verifyAlertExist(virtClient, "KubeVirtComponentExceedsRequestedMemory")
-		})
-	})
 })
 
 func updateDeploymentResourcesRequest(virtClient kubecli.KubevirtClient, deploymentName string, cpu, memory resource.Quantity) {
