@@ -36,10 +36,13 @@ import (
 	v1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 
-	"kubevirt.io/kubevirt/tests"
+	"kubevirt.io/kubevirt/pkg/libvmi"
+
 	"kubevirt.io/kubevirt/tests/console"
 	"kubevirt.io/kubevirt/tests/libnet"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libnet/cloudinit"
+	"kubevirt.io/kubevirt/tests/libpod"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/libwait"
 )
 
@@ -52,7 +55,8 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 	Describe("Status", func() {
 		AssertReportedIP := func(vmi *v1.VirtualMachineInstance) {
 			By("Getting pod of the VMI")
-			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, util.NamespaceTestDefault)
+			vmiPod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+			Expect(err).NotTo(HaveOccurred())
 
 			By("Making sure IP/s reported on the VMI matches the ones on the pod")
 			Expect(libnet.ValidateVMIandPodIPMatch(vmi, vmiPod)).To(Succeed(), "Should have matching IP/s between pod and vmi")
@@ -62,7 +66,7 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 			var vmi *v1.VirtualMachineInstance
 
 			BeforeEach(func() {
-				vmi = setupVMI(virtClient, libvmi.NewAlpine())
+				vmi = setupVMI(virtClient, libvmifact.NewAlpine())
 			})
 
 			It("should report PodIP as its own on interface status", func() { AssertReportedIP(vmi) })
@@ -95,12 +99,15 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 
 					vmi, err = virtClient.VirtualMachineInstance(util.NamespaceTestDefault).Create(context.Background(), vmi, metav1.CreateOptions{})
 					Expect(err).NotTo(HaveOccurred())
+
 					libwait.WaitForSuccessfulVMIStart(vmi)
 					Eventually(matcher.ThisVMI(vmi), 12*time.Minute, 2*time.Second).Should(matcher.HaveConditionTrue(v1.VirtualMachineInstanceAgentConnected))
 				})
 
 				It("should report PodIP/s on interface status", func() {
-					vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, vmi.Namespace)
+					vmiPod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+					Expect(err).NotTo(HaveOccurred())
+
 					Eventually(vmiIP, 2*time.Minute, 5*time.Second).Should(Equal(vmiPod.Status.PodIP), "should contain VMI Status IP as Pod status ip")
 					var podIPs []string
 					for _, ip := range vmiPod.Status.PodIPs {
@@ -115,7 +122,7 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 				BeforeEach(func() {
 					vmi = setupVMI(
 						virtClient,
-						libvmi.NewAlpine(
+						libvmifact.NewAlpine(
 							libvmi.WithInterface(*v1.DefaultBridgeNetworkInterface()),
 							libvmi.WithNetwork(v1.DefaultPodNetwork()),
 						),
@@ -142,7 +149,9 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 				})
 
 				It("[test_id:4153]should report PodIP/s as its own on interface status", func() {
-					vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, vmi.Namespace)
+					vmiPod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+					Expect(err).NotTo(HaveOccurred())
+
 					Consistently(func() error {
 						vmi, err := virtClient.VirtualMachineInstance(vmi.Namespace).Get(context.Background(), vmi.Name, metav1.GetOptions{})
 						if err != nil {
@@ -160,7 +169,7 @@ var _ = SIGDescribe("Primary Pod Network", func() {
 				BeforeEach(func() {
 					vmi = setupVMI(
 						virtClient,
-						libvmi.NewAlpine(
+						libvmifact.NewAlpine(
 							libvmi.WithInterface(*v1.DefaultMasqueradeNetworkInterface()),
 							libvmi.WithNetwork(v1.DefaultPodNetwork()),
 						),
@@ -186,9 +195,9 @@ func setupVMI(virtClient kubecli.KubevirtClient, vmi *v1.VirtualMachineInstance)
 }
 
 func newFedoraWithGuestAgentAndDefaultInterface(iface v1.Interface) (*v1.VirtualMachineInstance, error) {
-	networkData := libnet.CreateDefaultCloudInitNetworkData()
+	networkData := cloudinit.CreateDefaultCloudInitNetworkData()
 
-	vmi := libvmi.NewFedora(
+	vmi := libvmifact.NewFedora(
 		libvmi.WithInterface(iface),
 		libvmi.WithNetwork(v1.DefaultPodNetwork()),
 		libvmi.WithCloudInitNoCloudNetworkData(networkData),
