@@ -47,6 +47,7 @@ import (
 	"kubevirt.io/client-go/kubecli"
 
 	cloudinit "kubevirt.io/kubevirt/pkg/cloud-init"
+	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/network/vmispec"
 	"kubevirt.io/kubevirt/pkg/util/hardware"
 	"kubevirt.io/kubevirt/pkg/util/net/dns"
@@ -59,8 +60,10 @@ import (
 	"kubevirt.io/kubevirt/tests/framework/checks"
 	"kubevirt.io/kubevirt/tests/framework/matcher"
 	"kubevirt.io/kubevirt/tests/libnet"
+	netcloudinit "kubevirt.io/kubevirt/tests/libnet/cloudinit"
 	"kubevirt.io/kubevirt/tests/libnode"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libpod"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/libwait"
 	"kubevirt.io/kubevirt/tests/util"
 )
@@ -452,7 +455,7 @@ var _ = Describe("[Serial]SRIOV", Serial, decorators.SRIOV, func() {
 				To(Succeed(), shouldCreateNetwork)
 		})
 
-		It("[test_id:3956]should connect to another machine with sriov interface over IPv4", func() {
+		It("[test_id:3956]should connect to another machine with sriov interface over IP", func() {
 			cidrA := "192.168.1.1/24"
 			cidrB := "192.168.1.2/24"
 			ipA, err := libnet.CidrToIP(cidrA)
@@ -481,35 +484,6 @@ var _ = Describe("[Serial]SRIOV", Serial, decorators.SRIOV, func() {
 			}, 15*time.Second, time.Second).Should(Succeed())
 		})
 
-		It("[test_id:3957]should connect to another machine with sriov interface over IPv6", func() {
-			vmi1CIDR := "fc00::1/64"
-			vmi2CIDR := "fc00::2/64"
-			vmi1IP, err := libnet.CidrToIP(vmi1CIDR)
-			Expect(err).ToNot(HaveOccurred())
-			vmi2IP, err := libnet.CidrToIP(vmi2CIDR)
-			Expect(err).ToNot(HaveOccurred())
-
-			//create two vms on the same sriov network
-			vmi1, err := createSRIOVVmiOnNode(sriovNode, sriovnetLinkEnabled, vmi1CIDR)
-			Expect(err).ToNot(HaveOccurred())
-			DeferCleanup(deleteVMI, vmi1)
-			vmi2, err := createSRIOVVmiOnNode(sriovNode, sriovnetLinkEnabled, vmi2CIDR)
-			Expect(err).ToNot(HaveOccurred())
-			DeferCleanup(deleteVMI, vmi2)
-
-			vmi1, err = waitVMI(vmi1)
-			Expect(err).NotTo(HaveOccurred())
-			vmi2, err = waitVMI(vmi2)
-			Expect(err).NotTo(HaveOccurred())
-
-			Eventually(func() error {
-				return libnet.PingFromVMConsole(vmi1, vmi2IP)
-			}, 15*time.Second, time.Second).Should(Succeed())
-			Eventually(func() error {
-				return libnet.PingFromVMConsole(vmi2, vmi1IP)
-			}, 15*time.Second, time.Second).Should(Succeed())
-		})
-
 		Context("With VLAN", func() {
 			const (
 				cidrVlaned1     = "192.168.0.1/24"
@@ -605,15 +579,15 @@ func getInterfaceNetworkNameByMAC(vmi *v1.VirtualMachineInstance, macAddress str
 }
 
 func validateSRIOVSetup(virtClient kubecli.KubevirtClient, sriovResourceName string, minRequiredNodes int) error {
-	sriovNodes := getNodesWithAllocatedResource(virtClient, sriovResourceName)
+	sriovNodes := getNodesWithAllocatedResource(sriovResourceName)
 	if len(sriovNodes) < minRequiredNodes {
 		return fmt.Errorf("not enough compute nodes with SR-IOV support detected")
 	}
 	return nil
 }
 
-func getNodesWithAllocatedResource(virtClient kubecli.KubevirtClient, resourceName string) []k8sv1.Node {
-	nodes := libnode.GetAllSchedulableNodes(virtClient)
+func getNodesWithAllocatedResource(resourceName string) []k8sv1.Node {
+	nodes := libnode.GetAllSchedulableNodes(kubevirt.Client())
 	filteredNodes := []k8sv1.Node{}
 	for _, node := range nodes.Items {
 		resourceList := node.Status.Allocatable
@@ -631,9 +605,11 @@ func getNodesWithAllocatedResource(virtClient kubecli.KubevirtClient, resourceNa
 }
 
 func validatePodKubevirtResourceNameByVMI(virtClient kubecli.KubevirtClient, vmi *v1.VirtualMachineInstance, networkName, sriovResourceName string) error {
+	pod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+	Expect(err).NotTo(HaveOccurred())
+
 	out, err := exec.ExecuteCommandOnPod(
-		virtClient,
-		tests.GetRunningPodByVirtualMachineInstance(vmi, vmi.Namespace),
+		pod,
 		"compute",
 		[]string{"sh", "-c", fmt.Sprintf("echo $KUBEVIRT_RESOURCE_NAME_%s", networkName)},
 	)
@@ -650,7 +626,7 @@ func validatePodKubevirtResourceNameByVMI(virtClient kubecli.KubevirtClient, vmi
 }
 
 func defaultCloudInitNetworkData() string {
-	networkData := libnet.CreateDefaultCloudInitNetworkData()
+	networkData := netcloudinit.CreateDefaultCloudInitNetworkData()
 	return networkData
 }
 
@@ -690,7 +666,7 @@ func newSRIOVVmi(networks []string, cloudInitNetworkData string) *v1.VirtualMach
 			libvmi.WithNetwork(libvmi.MultusNetwork(name, name)),
 		)
 	}
-	return libvmi.NewFedora(options...)
+	return libvmifact.NewFedora(options...)
 }
 
 func checkInterfacesInGuest(vmi *v1.VirtualMachineInstance, interfaces []string) {
@@ -752,13 +728,11 @@ func deleteVMI(vmi *v1.VirtualMachineInstance) error {
 }
 
 func checkDefaultInterfaceInPod(vmi *v1.VirtualMachineInstance) error {
-	vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, vmi.Namespace)
-
-	virtClient := kubevirt.Client()
+	vmiPod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+	Expect(err).NotTo(HaveOccurred())
 
 	By("checking default interface is present")
-	_, err := exec.ExecuteCommandOnPod(
-		virtClient,
+	_, err = exec.ExecuteCommandOnPod(
 		vmiPod,
 		"compute",
 		[]string{"ip", "address", "show", "eth0"},
@@ -769,7 +743,6 @@ func checkDefaultInterfaceInPod(vmi *v1.VirtualMachineInstance) error {
 
 	By("checking default interface is attached to VMI")
 	_, err = exec.ExecuteCommandOnPod(
-		virtClient,
 		vmiPod,
 		"compute",
 		[]string{"ip", "address", "show", "k6t-eth0"},
@@ -789,7 +762,7 @@ func createSRIOVVmiOnNode(nodeName, networkName, cidr string) (*v1.VirtualMachin
 	//
 	// This step is needed to guarantee that no VFs on the PF carry a duplicate MAC address that may affect
 	// ability of VMIs to send and receive ICMP packets on their ports.
-	mac, err := GenerateRandomMac()
+	mac, err := libnet.GenerateRandomMac()
 	if err != nil {
 		return nil, err
 	}
@@ -798,7 +771,7 @@ func createSRIOVVmiOnNode(nodeName, networkName, cidr string) (*v1.VirtualMachin
 	// no DHCP server to serve the address to the guest
 	vmi := newSRIOVVmi(
 		[]string{networkName},
-		cloudInitNetworkDataWithStaticIPsByMac(networkName, mac.String(), cidr),
+		netcloudinit.CreateNetworkDataWithStaticIPsByMac(networkName, mac.String(), cidr),
 	)
 	libvmi.WithNodeAffinityFor(nodeName)(vmi)
 	const secondaryInterfaceIndex = 1
@@ -811,9 +784,7 @@ func createSRIOVVmiOnNode(nodeName, networkName, cidr string) (*v1.VirtualMachin
 }
 
 func sriovNodeName(sriovResourceName string) (string, error) {
-	virtClient := kubevirt.Client()
-
-	sriovNodes := getNodesWithAllocatedResource(virtClient, sriovResourceName)
+	sriovNodes := getNodesWithAllocatedResource(sriovResourceName)
 	if len(sriovNodes) == 0 {
 		return "", fmt.Errorf("failed to detect nodes with allocatable resources (%s)", sriovResourceName)
 	}
