@@ -7,7 +7,7 @@ import (
 	"github.com/onsi/gomega/gmeasure"
 
 	"kubevirt.io/kubevirt/tests"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 )
 
 // Replace PDescribe with FDescribe in order to measure if your changes made
@@ -19,7 +19,7 @@ var _ = PDescribe("Ensure stable functionality", func() {
 
 		experiment.Sample(func(idx int) {
 			experiment.MeasureDuration("Create VM", func() {
-				tests.RunVMIAndExpectLaunch(libvmi.NewCirros(), 30)
+				tests.RunVMIAndExpectLaunch(libvmifact.NewCirros(), 30)
 			})
 		}, gmeasure.SamplingConfig{N: 15, Duration: 10 * time.Minute})
 	})
