@@ -7,6 +7,7 @@ import (
 	"time"
 
 	"kubevirt.io/kubevirt/tests/decorators"
+	"kubevirt.io/kubevirt/tests/libpod"
 	"kubevirt.io/kubevirt/tests/watcher"
 
 	expect "github.com/google/goexpect"
@@ -24,15 +25,17 @@ import (
 	"k8s.io/utils/pointer"
 
 	"kubevirt.io/kubevirt/pkg/apimachinery/patch"
+	"kubevirt.io/kubevirt/pkg/libvmi"
 
 	"kubevirt.io/kubevirt/tests/exec"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 	"kubevirt.io/kubevirt/tests/framework/matcher"
+	. "kubevirt.io/kubevirt/tests/framework/matcher"
 	"kubevirt.io/kubevirt/tests/testsuite"
 
 	v1 "kubevirt.io/api/core/v1"
 	instancetypev1beta1 "kubevirt.io/api/instancetype/v1beta1"
-	snapshotv1 "kubevirt.io/api/snapshot/v1alpha1"
+	snapshotv1 "kubevirt.io/api/snapshot/v1beta1"
 	"kubevirt.io/client-go/kubecli"
 	cdiv1 "kubevirt.io/containerized-data-importer-api/pkg/apis/core/v1beta1"
 
@@ -40,8 +43,9 @@ import (
 	"kubevirt.io/kubevirt/tests/console"
 	cd "kubevirt.io/kubevirt/tests/containerdisk"
 	"kubevirt.io/kubevirt/tests/libdv"
+	"kubevirt.io/kubevirt/tests/libnet"
 	"kubevirt.io/kubevirt/tests/libstorage"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/libwait"
 )
 
@@ -230,7 +234,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 	Context("With simple VM", func() {
 		BeforeEach(func() {
 			var err error
-			vm = libvmi.NewVirtualMachine(libvmi.NewCirros())
+			vm = libvmi.NewVirtualMachine(libvmifact.NewCirros())
 			vm, err = virtClient.VirtualMachine(testsuite.GetTestNamespace(nil)).Create(context.Background(), vm, metav1.CreateOptions{})
 			Expect(err).ToNot(HaveOccurred())
 		})
@@ -291,15 +295,19 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			vm, err := virtClient.VirtualMachine(vm.Namespace).Patch(context.Background(), vm.Name, types.JSONPatchType, patch, metav1.PatchOptions{})
 			Expect(err).ToNot(HaveOccurred())
 
-			Eventually(func() bool {
+			Eventually(func() v1.VirtualMachineStatus {
 				vm2, err := virtClient.VirtualMachine(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				By(fmt.Sprintf("VM Statuses: %+v", vm2.Status))
-				return len(vm2.Status.VolumeSnapshotStatuses) == 2 &&
-					vm2.Status.VolumeSnapshotStatuses[0].Name == "disk0" &&
-					vm2.Status.VolumeSnapshotStatuses[1].Name == "disk1"
-			}, 180*time.Second, time.Second).Should(BeTrue())
+				return vm2.Status
+			}, 180*time.Second, time.Second).Should(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+				"VolumeSnapshotStatuses": HaveExactElements(
+					gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+						"Name": Equal("disk0")}),
+					gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+						"Name": Equal("disk1")}),
+				),
+			}))
 		})
 	})
 
@@ -330,14 +338,9 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				vm.Spec.Running = pointer.BoolPtr(true)
 				vm, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, metav1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
-				Eventually(func() bool {
-					vmi, err = virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
-					if errors.IsNotFound(err) {
-						return false
-					}
-					Expect(err).ToNot(HaveOccurred())
-					return vmi.Status.Phase == v1.Running
-				}, 360*time.Second, time.Second).Should(BeTrue())
+				Eventually(ThisVMIWith(vm.Namespace, vm.Name), 360).Should(BeInPhase(v1.Running))
+				vmi, err = virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
+				Expect(err).ToNot(HaveOccurred())
 
 				return vm, vmi
 			}
@@ -397,22 +400,21 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			}
 
 			callVeleroHook := func(vmi *v1.VirtualMachineInstance, annoContainer, annoCommand string) (string, string, error) {
-				pod := tests.GetPodByVirtualMachineInstance(vmi)
-
+				pod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+				Expect(err).NotTo(HaveOccurred())
 				command := pod.Annotations[annoCommand]
 				command = strings.Trim(command, "[]")
 				commandSlice := []string{}
 				for _, c := range strings.Split(command, ",") {
 					commandSlice = append(commandSlice, strings.Trim(c, "\" "))
 				}
-				virtClient := kubevirt.Client()
-				return exec.ExecuteCommandOnPodWithResults(virtClient, pod, pod.Annotations[annoContainer], commandSlice)
+				return exec.ExecuteCommandOnPodWithResults(pod, pod.Annotations[annoContainer], commandSlice)
 			}
 
 			It("[test_id:6767]with volumes and guest agent available", func() {
 				quantity, err := resource.ParseQuantity("1Gi")
 				Expect(err).ToNot(HaveOccurred())
-				vmi := tests.NewRandomFedoraVMI()
+				vmi := libvmifact.NewFedora(libnet.WithMasqueradeNetworking()...)
 				vmi.Namespace = testsuite.GetTestNamespace(nil)
 				vm = libvmi.NewVirtualMachine(vmi)
 				dvName := "dv-" + vm.Name
@@ -427,7 +429,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 							},
 							PVC: &corev1.PersistentVolumeClaimSpec{
 								AccessModes: []corev1.PersistentVolumeAccessMode{corev1.ReadWriteOnce},
-								Resources: corev1.ResourceRequirements{
+								Resources: corev1.VolumeResourceRequirements{
 									Requests: corev1.ResourceList{
 										"storage": quantity,
 									},
@@ -493,7 +495,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			It("[test_id:6768]with volumes and no guest agent available", func() {
 				quantity, err := resource.ParseQuantity("1Gi")
 				Expect(err).ToNot(HaveOccurred())
-				vmi := tests.NewRandomFedoraVMI()
+				vmi := libvmifact.NewFedora(libnet.WithMasqueradeNetworking()...)
 				vmi.Namespace = testsuite.GetTestNamespace(nil)
 				vm = libvmi.NewVirtualMachine(vmi)
 				dvName := "dv-" + vm.Name
@@ -508,7 +510,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 							},
 							PVC: &corev1.PersistentVolumeClaimSpec{
 								AccessModes: []corev1.PersistentVolumeAccessMode{corev1.ReadWriteOnce},
-								Resources: corev1.ResourceRequirements{
+								Resources: corev1.VolumeResourceRequirements{
 									Requests: corev1.ResourceList{
 										"storage": quantity,
 									},
@@ -555,7 +557,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			})
 
 			It("[test_id:6769]without volumes with guest agent available", func() {
-				vmi := tests.NewRandomFedoraVMI()
+				vmi := libvmifact.NewFedora(libnet.WithMasqueradeNetworking()...)
 				vmi.Namespace = testsuite.GetTestNamespace(nil)
 				vm = libvmi.NewVirtualMachine(vmi)
 
@@ -595,18 +597,18 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				_, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, metav1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				Eventually(func() bool {
+				Eventually(func() string {
 					updatedVMI, err := virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return updatedVMI.Status.FSFreezeStatus == "frozen"
-				}, time.Minute, 2*time.Second).Should(BeTrue())
+					return updatedVMI.Status.FSFreezeStatus
+				}, time.Minute, 2*time.Second).Should(Equal("frozen"))
 
 				deleteSnapshot()
-				Eventually(func() bool {
+				Eventually(func() string {
 					updatedVMI, err := virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return updatedVMI.Status.FSFreezeStatus == ""
-				}, time.Minute, 2*time.Second).Should(BeTrue())
+					return updatedVMI.Status.FSFreezeStatus
+				}, time.Minute, 2*time.Second).Should(BeEmpty())
 			})
 
 			It("[test_id:6949]should unfreeze vm if snapshot fails when deadline exceeded", func() {
@@ -626,36 +628,48 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				_, err = virtClient.VirtualMachineSnapshot(snapshot.Namespace).Create(context.Background(), snapshot, metav1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				Eventually(func() bool {
+				Eventually(func() *snapshotv1.VirtualMachineSnapshot {
 					snapshot, err = virtClient.VirtualMachineSnapshot(vm.Namespace).Get(context.Background(), snapshot.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
+					return snapshot
+				}, 30*time.Second, 2*time.Second).Should(matcher.BeInPhase(snapshotv1.InProgress))
+				Eventually(func() string {
 					updatedVMI, err := virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return snapshot.Status != nil &&
-						snapshot.Status.Phase == snapshotv1.InProgress &&
-						updatedVMI.Status.FSFreezeStatus == "frozen"
-				}, 30*time.Second, 2*time.Second).Should(BeTrue())
+					return updatedVMI.Status.FSFreezeStatus
+				}, 10*time.Second, 2*time.Second).Should(Equal("frozen"))
 
-				contentName := fmt.Sprintf("%s-%s", vmSnapshotContent, snapshot.UID)
-				Eventually(func() bool {
+				Eventually(func() *snapshotv1.VirtualMachineSnapshotStatus {
 					snapshot, err = virtClient.VirtualMachineSnapshot(vm.Namespace).Get(context.Background(), snapshot.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
+					return snapshot.Status
+				}, time.Minute, 2*time.Second).Should(gstruct.PointTo(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+					"Conditions": HaveExactElements(
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Type":   Equal(snapshotv1.ConditionProgressing),
+							"Status": Equal(corev1.ConditionFalse),
+							"Reason": Equal(snapshotDeadlineExceeded)}),
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Type":   Equal(snapshotv1.ConditionReady),
+							"Status": Equal(corev1.ConditionFalse),
+							"Reason": Equal(notReady)}),
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Type":   Equal(snapshotv1.ConditionFailure),
+							"Status": Equal(corev1.ConditionTrue),
+							"Reason": Equal(snapshotDeadlineExceeded)}),
+					),
+					"Phase": Equal(snapshotv1.Failed),
+				})))
+				contentName := fmt.Sprintf("%s-%s", vmSnapshotContent, snapshot.UID)
+				Eventually(func() error {
+					_, contentErr := virtClient.VirtualMachineSnapshotContent(vm.Namespace).Get(context.Background(), contentName, metav1.GetOptions{})
+					return contentErr
+				}, 30*time.Second, 1*time.Second).Should(MatchError(errors.IsNotFound, "k8serrors.IsNotFound"))
+				Eventually(func() string {
 					updatedVMI, err := virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					_, contentErr := virtClient.VirtualMachineSnapshotContent(vm.Namespace).Get(context.Background(), contentName, metav1.GetOptions{})
-					return snapshot.Status != nil &&
-						len(snapshot.Status.Conditions) == 3 &&
-						snapshot.Status.Conditions[0].Status == corev1.ConditionFalse &&
-						strings.Contains(snapshot.Status.Conditions[0].Reason, snapshotDeadlineExceeded) &&
-						snapshot.Status.Conditions[1].Status == corev1.ConditionFalse &&
-						strings.Contains(snapshot.Status.Conditions[1].Reason, notReady) &&
-						snapshot.Status.Conditions[2].Status == corev1.ConditionTrue &&
-						snapshot.Status.Conditions[2].Type == snapshotv1.ConditionFailure &&
-						strings.Contains(snapshot.Status.Conditions[2].Reason, snapshotDeadlineExceeded) &&
-						snapshot.Status.Phase == snapshotv1.Failed &&
-						updatedVMI.Status.FSFreezeStatus == "" &&
-						errors.IsNotFound(contentErr)
-				}, time.Minute, 2*time.Second).Should(BeTrue())
+					return updatedVMI.Status.FSFreezeStatus
+				}, 30*time.Second, 2*time.Second).Should(BeEmpty())
 			})
 
 			It("[test_id:7472]should succeed online snapshot with hot plug disk", func() {
@@ -741,7 +755,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 					"runcmd:\n" +
 					"  - sudo sed -i 's/^SELINUX=.*/SELINUX=enforcing/' /etc/selinux/config\n"
 
-				vmi := libvmi.NewFedora(
+				vmi := libvmifact.NewFedora(
 					libvmi.WithCloudInitNoCloudUserData(userData),
 					libvmi.WithNamespace(testsuite.GetTestNamespace(nil)))
 
@@ -800,7 +814,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 
 			It("Calling Velero hooks should freeze/unfreeze VM", func() {
 				By("Creating VM")
-				vmi := tests.NewRandomFedoraVMI()
+				vmi := libvmifact.NewFedora(libnet.WithMasqueradeNetworking()...)
 				vmi.Namespace = testsuite.GetTestNamespace(nil)
 				vm = libvmi.NewVirtualMachine(vmi)
 
@@ -826,11 +840,11 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 					&expect.BSnd{S: tests.EchoLastReturnValue},
 					&expect.BExp{R: console.RetValue("0")},
 				}, 30)).To(Succeed())
-				Eventually(func() bool {
+				Eventually(func() string {
 					vmi, err = virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return vmi.Status.FSFreezeStatus == "frozen"
-				}, 180*time.Second, time.Second).Should(BeTrue())
+					return vmi.Status.FSFreezeStatus
+				}, 180*time.Second, time.Second).Should(Equal("frozen"))
 
 				By("Calling Velero post-backup hook")
 				_, _, err = callVeleroHook(vmi, VELERO_POSTBACKUP_HOOK_CONTAINER_ANNOTATION, VELERO_POSTBACKUP_HOOK_COMMAND_ANNOTATION)
@@ -844,11 +858,11 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 					&expect.BSnd{S: tests.EchoLastReturnValue},
 					&expect.BExp{R: console.RetValue("0")},
 				}, 30)).To(Succeed())
-				Eventually(func() bool {
+				Eventually(func() string {
 					vmi, err = virtClient.VirtualMachineInstance(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return vmi.Status.FSFreezeStatus == ""
-				}, 180*time.Second, time.Second).Should(BeTrue())
+					return vmi.Status.FSFreezeStatus
+				}, 180*time.Second, time.Second).Should(BeEmpty())
 			})
 
 			It("[test_id:9647]Calling Velero hooks should not error if no guest agent", func() {
@@ -881,7 +895,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 
 			It("Calling Velero hooks should error if VM is Paused", func() {
 				By("Creating VM")
-				vmi := tests.NewRandomFedoraVMI()
+				vmi := libvmifact.NewFedora(libnet.WithMasqueradeNetworking()...)
 				vmi.Namespace = testsuite.GetTestNamespace(nil)
 				vm = libvmi.NewVirtualMachine(vmi)
 
@@ -937,16 +951,13 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				}
 
 				waitMemoryDumpCompletion := func(vm *v1.VirtualMachine) {
-					Eventually(func() bool {
+					Eventually(func() *v1.VirtualMachineMemoryDumpRequest {
 						updatedVM, err := virtClient.VirtualMachine(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 						Expect(err).ToNot(HaveOccurred())
-						if updatedVM.Status.MemoryDumpRequest == nil ||
-							updatedVM.Status.MemoryDumpRequest.Phase != v1.MemoryDumpCompleted {
-							return false
-						}
-
-						return true
-					}, 60*time.Second, time.Second).Should(BeTrue())
+						return updatedVM.Status.MemoryDumpRequest
+					}, 60*time.Second, time.Second).Should(gstruct.PointTo(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+						"Phase": Equal(v1.MemoryDumpCompleted),
+					})))
 				}
 
 				It("[test_id:8922]should include memory dump in vm snapshot", func() {
@@ -1059,63 +1070,52 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				Expect(err).ToNot(HaveOccurred())
 
 				origStatus := ss.Status
+				// zero out the times to be able to compare after
+				clearConditionsTimestamps(origStatus.Conditions)
 				ss.Status = nil
 				ss, err = virtClient.VirtualMachineSnapshot(ss.Namespace).Update(context.Background(), ss, metav1.UpdateOptions{})
 				Expect(err).ToNot(HaveOccurred())
 				Expect(ss.Status).To(BeNil())
 
-				Eventually(func() bool {
+				Eventually(func() *snapshotv1.VirtualMachineSnapshotStatus {
 					ss, err = virtClient.VirtualMachineSnapshot(ss.Namespace).Get(context.Background(), ss.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
 					if ss.Status == nil {
-						return false
+						return nil
 					}
-					if *ss.Status.SourceUID != *origStatus.SourceUID ||
-						*ss.Status.VirtualMachineSnapshotContentName != *origStatus.VirtualMachineSnapshotContentName ||
-						*ss.Status.CreationTime != *origStatus.CreationTime ||
-						ss.Status.Phase != origStatus.Phase ||
-						*ss.Status.ReadyToUse != *origStatus.ReadyToUse {
-						return false
-					}
-					if len(ss.Status.Conditions) != len(origStatus.Conditions) {
-						return false
-					}
-					for i, c := range ss.Status.Conditions {
-						oc := origStatus.Conditions[i]
-						if c.Type != oc.Type ||
-							c.Status != oc.Status {
-							return false
-						}
-					}
-					if len(ss.Status.Indications) != len(origStatus.Indications) {
-						return false
-					}
-					for i := range ss.Status.Indications {
-						if ss.Status.Indications[i] != origStatus.Indications[i] {
-							return false
-						}
-					}
-					return true
-				}, 180*time.Second, time.Second).Should(BeTrue())
+					// zero out the times to be able to compare to the original status
+					clearConditionsTimestamps(ss.Status.Conditions)
+					return ss.Status
+				}, 180*time.Second, time.Second).Should(gstruct.PointTo(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+					"SourceUID":                         gstruct.PointTo(Equal(*origStatus.SourceUID)),
+					"VirtualMachineSnapshotContentName": gstruct.PointTo(Equal(*origStatus.VirtualMachineSnapshotContentName)),
+					"CreationTime":                      gstruct.PointTo(Equal(*origStatus.CreationTime)),
+					"Phase":                             Equal(origStatus.Phase),
+					"ReadyToUse":                        gstruct.PointTo(Equal(*origStatus.ReadyToUse)),
+					"Conditions":                        HaveExactElements(origStatus.Conditions),
+					"Indications":                       HaveExactElements(origStatus.Indications),
+				})))
 			})
 
 			It("VM should contain snapshot status for all volumes", func() {
 				volumes := len(vm.Spec.Template.Spec.Volumes)
-				Eventually(func() int {
+				Eventually(func() []v1.VolumeSnapshotStatus {
 					vm, err := virtClient.VirtualMachine(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
 
-					return len(vm.Status.VolumeSnapshotStatuses)
-				}, 180*time.Second, time.Second).Should(Equal(volumes))
+					return vm.Status.VolumeSnapshotStatuses
+				}, 180*time.Second, time.Second).Should(HaveLen(volumes))
 
-				Eventually(func() bool {
+				Eventually(func() v1.VirtualMachineStatus {
 					vm2, err := virtClient.VirtualMachine(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
 
-					By(fmt.Sprintf("VM Statuses: %+v", vm2.Status))
-					return len(vm2.Status.VolumeSnapshotStatuses) == 1 &&
-						vm2.Status.VolumeSnapshotStatuses[0].Enabled
-				}, 180*time.Second, time.Second).Should(BeTrue())
+					return vm2.Status
+				}, 180*time.Second, time.Second).Should(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+					"VolumeSnapshotStatuses": HaveExactElements(
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Enabled": BeTrue()})),
+				}))
 			})
 
 			It("should error if VolumeSnapshot deleted", func() {
@@ -1140,11 +1140,11 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 					Delete(context.Background(), *vb.VolumeSnapshotName, metav1.DeleteOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				Eventually(func() bool {
+				Eventually(func() *bool {
 					snapshot, err = virtClient.VirtualMachineSnapshot(vm.Namespace).Get(context.Background(), snapshot.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return *snapshot.Status.ReadyToUse
-				}, 180*time.Second, time.Second).Should(BeFalse())
+					return snapshot.Status.ReadyToUse
+				}, 180*time.Second, time.Second).Should(gstruct.PointTo(BeFalse()))
 
 				errStr := fmt.Sprintf("VolumeSnapshots (%s) missing", *vb.VolumeSnapshotName)
 				Expect(snapshot.Status.Error).ToNot(BeNil())
@@ -1193,18 +1193,20 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 					return true
 				}, 180*time.Second, time.Second).Should(BeTrue())
 
-				Eventually(func() bool {
+				Eventually(func() *snapshotv1.VirtualMachineSnapshotContentStatus {
 					vmSnapshotContent, err = virtClient.VirtualMachineSnapshotContent(vm.Namespace).Get(context.Background(), *cn, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					vss := vmSnapshotContent.Status.VolumeSnapshotStatus[0]
-					if vss.Error != nil {
-						Expect(*vss.Error.Message).To(Equal(m))
-						Expect(vmSnapshotContent.Status.Error).To(BeNil())
-						Expect(*vmSnapshotContent.Status.ReadyToUse).To(BeTrue())
-						return true
-					}
-					return false
-				}, 180*time.Second, time.Second).Should(BeTrue())
+					return vmSnapshotContent.Status
+				}, 180*time.Second, time.Second).Should(gstruct.PointTo(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+					"VolumeSnapshotStatus": ContainElements(
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Error": gstruct.PointTo(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+								"Message": gstruct.PointTo(Equal(m)),
+							})),
+						})),
+					"Error":      BeNil(),
+					"ReadyToUse": gstruct.PointTo(BeTrue()),
+				})))
 
 				snapshot, err = virtClient.VirtualMachineSnapshot(vm.Namespace).Get(context.Background(), snapshot.Name, metav1.GetOptions{})
 				Expect(err).ToNot(HaveOccurred())
@@ -1315,7 +1317,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 			})
 
 			It("vmsnapshot should update error if vmsnapshotcontent is unready to use and error", func() {
-				vm = tests.StartVMAndExpectRunning(virtClient, vm)
+				vm = tests.RunVMAndExpectLaunchWithRunStrategy(virtClient, vm, v1.RunStrategyAlways)
 				// Delete DV and wait pvc get deletionTimestamp
 				// when pvc is deleting snapshot is not possible
 				volumeName := vm.Spec.DataVolumeTemplates[0].Name
@@ -1475,22 +1477,30 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				_, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, metav1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				Eventually(func() bool {
+				Eventually(func() v1.VirtualMachineStatus {
 					vm, err := virtClient.VirtualMachine(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return len(vm.Status.VolumeSnapshotStatuses) == 1 &&
-						!vm.Status.VolumeSnapshotStatuses[0].Enabled
-				}, 180*time.Second, 1*time.Second).Should(BeTrue())
+
+					return vm.Status
+				}, 180*time.Second, time.Second).Should(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+					"VolumeSnapshotStatuses": HaveExactElements(
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Enabled": BeFalse()})),
+				}))
 
 				dv, err = virtClient.CdiClient().CdiV1beta1().DataVolumes(testsuite.GetTestNamespace(nil)).Create(context.Background(), dataVolume, metav1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				Eventually(func() bool {
+				Eventually(func() v1.VirtualMachineStatus {
 					vm, err := virtClient.VirtualMachine(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return len(vm.Status.VolumeSnapshotStatuses) == 1 &&
-						vm.Status.VolumeSnapshotStatuses[0].Enabled
-				}, 180*time.Second, 1*time.Second).Should(BeTrue())
+
+					return vm.Status
+				}, 180*time.Second, time.Second).Should(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+					"VolumeSnapshotStatuses": HaveExactElements(
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Enabled": BeTrue()})),
+				}))
 			},
 				Entry("with DataVolume volume", libvmi.WithDataVolume, "1Gi"),
 				Entry("with PVC volume", libvmi.WithPersistentVolumeClaim, "128Mi"),
@@ -1533,16 +1543,17 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				_, err := virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, metav1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
 
-				volumeSnapshotStatusAsExpected := func(volumeSnapshotStatuses []v1.VolumeSnapshotStatus) bool {
-					return len(volumeSnapshotStatuses) == 2 &&
-						volumeSnapshotStatuses[0].Enabled &&
-						!volumeSnapshotStatuses[1].Enabled
-				}
-				Eventually(func() []v1.VolumeSnapshotStatus {
+				Eventually(func() v1.VirtualMachineStatus {
 					vm, err := virtClient.VirtualMachine(vm.Namespace).Get(context.Background(), vm.Name, metav1.GetOptions{})
 					Expect(err).ToNot(HaveOccurred())
-					return vm.Status.VolumeSnapshotStatuses
-				}, 180*time.Second, 3*time.Second).WithOffset(1).Should(Satisfy(volumeSnapshotStatusAsExpected))
+					return vm.Status
+				}, 180*time.Second, 3*time.Second).Should(gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+					"VolumeSnapshotStatuses": HaveExactElements(
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Enabled": BeTrue()}),
+						gstruct.MatchFields(gstruct.IgnoreExtras, gstruct.Fields{
+							"Enabled": BeFalse()})),
+				}))
 
 				By("Create Snapshot")
 				snapshot = newSnapshot()
@@ -1594,7 +1605,7 @@ var _ = SIGDescribe("VirtualMachineSnapshot Tests", func() {
 				By("Starting the VM and expecting it to run")
 				vm, err = virtClient.VirtualMachine(vm.Namespace).Create(context.Background(), vm, metav1.CreateOptions{})
 				Expect(err).ToNot(HaveOccurred())
-				Eventually(matcher.ThisVMIWith(vm.Namespace, vm.Name), 360).Should(matcher.BeInPhase(v1.Running))
+				Eventually(ThisVMIWith(vm.Namespace, vm.Name), 360).Should(BeInPhase(v1.Running))
 
 				for _, dvt := range vm.Spec.DataVolumeTemplates {
 					waitDataVolumePopulated(vm.Namespace, dvt.Name)
@@ -1667,3 +1678,11 @@ func AddVolumeAndVerify(virtClient kubecli.KubevirtClient, storageClass string,
 
 	return addVolumeName
 }
+
+func clearConditionsTimestamps(conditions []snapshotv1.Condition) {
+	emptyTime := metav1.Time{}
+	for i := range conditions {
+		conditions[i].LastProbeTime = emptyTime
+		conditions[i].LastTransitionTime = emptyTime
+	}
+}
