@@ -8,7 +8,6 @@ import (
 	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
-	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/rand"
@@ -16,9 +15,12 @@ import (
 	kubevirtv1 "kubevirt.io/api/core/v1"
 	"kubevirt.io/client-go/kubecli"
 
+	"kubevirt.io/kubevirt/pkg/libvmi"
+
 	"kubevirt.io/kubevirt/tests/clientcmd"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libsecret"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/util"
 )
 
@@ -48,7 +50,7 @@ var _ = Describe("[sig-compute][virtctl]credentials", func() {
 		sshKeySecretName = sshKeySecretNamePrefix + rand.String(6)
 		passwordSecretName = passwordSecretNamePrefix + rand.String(6)
 
-		vmi := libvmi.NewFedora()
+		vmi := libvmifact.NewFedora()
 		vmi.Namespace = util.NamespaceTestDefault
 
 		vm = libvmi.NewVirtualMachine(vmi)
@@ -89,22 +91,14 @@ var _ = Describe("[sig-compute][virtctl]credentials", func() {
 			))
 		})
 
-		keySecret := &corev1.Secret{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: sshKeySecretName,
-				OwnerReferences: []metav1.OwnerReference{{
-					APIVersion: kubevirtv1.VirtualMachineGroupVersionKind.GroupVersion().String(),
-					Kind:       kubevirtv1.VirtualMachineGroupVersionKind.Kind,
-					Name:       vm.Name,
-					UID:        vm.UID,
-					Controller: pointer.Bool(true),
-				}},
-			},
-			Data: map[string][]byte{
-				"key-file.pub": []byte(testKey1),
-			},
-		}
-
+		keySecret := libsecret.New(sshKeySecretName, libsecret.DataString{"key-file.pub": testKey1})
+		keySecret.OwnerReferences = []metav1.OwnerReference{{
+			APIVersion: kubevirtv1.VirtualMachineGroupVersionKind.GroupVersion().String(),
+			Kind:       kubevirtv1.VirtualMachineGroupVersionKind.Kind,
+			Name:       vm.Name,
+			UID:        vm.UID,
+			Controller: pointer.Bool(true),
+		}}
 		keySecret, err = cli.CoreV1().Secrets(util.NamespaceTestDefault).Create(context.Background(), keySecret, metav1.CreateOptions{})
 		Expect(err).ToNot(HaveOccurred())
 		DeferCleanup(func() {
@@ -115,22 +109,14 @@ var _ = Describe("[sig-compute][virtctl]credentials", func() {
 			))
 		})
 
-		passwordSecret := &corev1.Secret{
-			ObjectMeta: metav1.ObjectMeta{
-				Name: passwordSecretName,
-				OwnerReferences: []metav1.OwnerReference{{
-					APIVersion: kubevirtv1.VirtualMachineGroupVersionKind.GroupVersion().String(),
-					Kind:       kubevirtv1.VirtualMachineGroupVersionKind.Kind,
-					Name:       vm.Name,
-					UID:        vm.UID,
-					Controller: pointer.Bool(true),
-				}},
-			},
-			Data: map[string][]byte{
-				userName: []byte("test-password"),
-			},
-		}
-
+		passwordSecret := libsecret.New(passwordSecretName, libsecret.DataString{userName: "test-password"})
+		passwordSecret.OwnerReferences = []metav1.OwnerReference{{
+			APIVersion: kubevirtv1.VirtualMachineGroupVersionKind.GroupVersion().String(),
+			Kind:       kubevirtv1.VirtualMachineGroupVersionKind.Kind,
+			Name:       vm.Name,
+			UID:        vm.UID,
+			Controller: pointer.Bool(true),
+		}}
 		passwordSecret, err = cli.CoreV1().Secrets(util.NamespaceTestDefault).Create(context.Background(), passwordSecret, metav1.CreateOptions{})
 		Expect(err).ToNot(HaveOccurred())
 		DeferCleanup(func() {
