@@ -20,14 +20,18 @@
 package virtiofs
 
 import (
+	"context"
 	"fmt"
 
-	"kubevirt.io/client-go/kubecli"
+	"k8s.io/apimachinery/pkg/api/errors"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 
-	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/kubevirt"
 
+	"kubevirt.io/kubevirt/pkg/libvmi"
 	virtconfig "kubevirt.io/kubevirt/pkg/virt-config"
+
+	"kubevirt.io/kubevirt/tests/decorators"
 	"kubevirt.io/kubevirt/tests/framework/checks"
 
 	expect "github.com/google/goexpect"
@@ -41,14 +45,14 @@ import (
 	"kubevirt.io/kubevirt/pkg/config"
 	"kubevirt.io/kubevirt/tests"
 	"kubevirt.io/kubevirt/tests/console"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libconfigmap"
+	"kubevirt.io/kubevirt/tests/libpod"
+	"kubevirt.io/kubevirt/tests/libsecret"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 )
 
 var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute, func() {
-	var virtClient kubecli.KubevirtClient
-
 	BeforeEach(func() {
-		virtClient = kubevirt.Client()
 		checks.SkipTestIfNoFeatureGate(virtconfig.VirtIOFSGate)
 	})
 
@@ -68,14 +72,16 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 				"option2": "value2",
 				"option3": "value3",
 			}
-			tests.CreateConfigMap(configMapName, testsuite.GetTestNamespace(nil), data)
+			cm := libconfigmap.New(configMapName, data)
+			cm, err := kubevirt.Client().CoreV1().ConfigMaps(testsuite.GetTestNamespace(cm)).Create(context.Background(), cm, metav1.CreateOptions{})
+			Expect(err).ToNot(HaveOccurred())
 		})
 
 		It("Should be the mounted virtiofs layout the same for a pod and vmi", func() {
 			expectedOutput := "value1value2value3"
 
 			By("Running VMI")
-			vmi := libvmi.NewFedora(
+			vmi := libvmifact.NewFedora(
 				libvmi.WithConfigMapFs(configMapName, configMapName),
 			)
 			vmi = tests.RunVMIAndExpectLaunchIgnoreWarnings(vmi, 300)
@@ -84,9 +90,10 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 			Expect(console.LoginToFedora(vmi)).To(Succeed())
 
 			By("Checking if ConfigMap has been attached to the pod")
-			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+			vmiPod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+			Expect(err).ToNot(HaveOccurred())
+
 			podOutput, err := exec.ExecuteCommandOnPod(
-				virtClient,
 				vmiPod,
 				fmt.Sprintf("virtiofs-%s", configMapName),
 				[]string{"cat",
@@ -121,18 +128,18 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 			secretName = "secret-" + uuid.NewString()[:6]
 			secretPath = config.GetSecretSourcePath(secretName)
 
-			data := map[string]string{
-				"user":     "admin",
-				"password": "redhat",
+			secret := libsecret.New(secretName, libsecret.DataString{"user": "admin", "password": "redhat"})
+			secret, err := kubevirt.Client().CoreV1().Secrets(testsuite.GetTestNamespace(nil)).Create(context.Background(), secret, metav1.CreateOptions{})
+			if !errors.IsAlreadyExists(err) {
+				Expect(err).ToNot(HaveOccurred())
 			}
-			tests.CreateSecret(secretName, testsuite.GetTestNamespace(nil), data)
 		})
 
 		It("Should be the mounted virtiofs layout the same for a pod and vmi", func() {
 			expectedOutput := "adminredhat"
 
 			By("Running VMI")
-			vmi := libvmi.NewFedora(
+			vmi := libvmifact.NewFedora(
 				libvmi.WithSecretFs(secretName, secretName),
 			)
 			vmi = tests.RunVMIAndExpectLaunchIgnoreWarnings(vmi, 300)
@@ -141,9 +148,10 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 			Expect(console.LoginToFedora(vmi)).To(Succeed())
 
 			By("Checking if Secret has been attached to the pod")
-			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+			vmiPod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+			Expect(err).ToNot(HaveOccurred())
+
 			podOutput, err := exec.ExecuteCommandOnPod(
-				virtClient,
 				vmiPod,
 				fmt.Sprintf("virtiofs-%s", secretName),
 				[]string{"cat",
@@ -174,7 +182,7 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 			serviceAccountVolumeName := "default-disk"
 
 			By("Running VMI")
-			vmi := libvmi.NewFedora(
+			vmi := libvmifact.NewFedora(
 				libvmi.WithServiceAccountFs("default", serviceAccountVolumeName),
 			)
 			vmi = tests.RunVMIAndExpectLaunchIgnoreWarnings(vmi, 300)
@@ -183,9 +191,10 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 			Expect(console.LoginToFedora(vmi)).To(Succeed())
 
 			By("Checking if ServiceAccount has been attached to the pod")
-			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+			vmiPod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+			Expect(err).ToNot(HaveOccurred())
+
 			namespace, err := exec.ExecuteCommandOnPod(
-				virtClient,
 				vmiPod,
 				fmt.Sprintf("virtiofs-%s", serviceAccountVolumeName),
 				[]string{"cat",
@@ -196,7 +205,6 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 			Expect(namespace).To(Equal(testsuite.GetTestNamespace(vmi)))
 
 			token, err := exec.ExecuteCommandOnPod(
-				virtClient,
 				vmiPod,
 				fmt.Sprintf("virtiofs-%s", serviceAccountVolumeName),
 				[]string{"tail", "-c", "20",
@@ -232,7 +240,7 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 		It("Should be the namespace and token the same for a pod and vmi with virtiofs", func() {
 
 			By("Running VMI")
-			vmi := libvmi.NewFedora(
+			vmi := libvmifact.NewFedora(
 				libvmi.WithLabel(testLabelKey, testLabelVal),
 				libvmi.WithDownwardAPIFs(downwardAPIName),
 			)
@@ -242,9 +250,10 @@ var _ = Describe("[sig-compute] vitiofs config volumes", decorators.SigCompute,
 			Expect(console.LoginToFedora(vmi)).To(Succeed())
 
 			By("Checking if DownwardAPI has been attached to the pod")
-			vmiPod := tests.GetRunningPodByVirtualMachineInstance(vmi, testsuite.GetTestNamespace(vmi))
+			vmiPod, err := libpod.GetPodByVirtualMachineInstance(vmi, vmi.Namespace)
+			Expect(err).ToNot(HaveOccurred())
+
 			podOutput, err := exec.ExecuteCommandOnPod(
-				virtClient,
 				vmiPod,
 				fmt.Sprintf("virtiofs-%s", downwardAPIName),
 				[]string{"grep", testLabelKey,
