@@ -35,6 +35,7 @@ import (
 
 	"kubevirt.io/kubevirt/tests/libnode"
 
+	"kubevirt.io/kubevirt/pkg/libvmi"
 	"kubevirt.io/kubevirt/pkg/virt-controller/watch/topology"
 
 	. "github.com/onsi/ginkgo/v2"
@@ -47,7 +48,8 @@ import (
 	"kubevirt.io/kubevirt/pkg/network/dns"
 	"kubevirt.io/kubevirt/tests"
 	"kubevirt.io/kubevirt/tests/libnet"
-	"kubevirt.io/kubevirt/tests/libvmi"
+	"kubevirt.io/kubevirt/tests/libpod"
+	"kubevirt.io/kubevirt/tests/libvmifact"
 	"kubevirt.io/kubevirt/tests/libwait"
 	"kubevirt.io/kubevirt/tests/util"
 )
@@ -69,9 +71,9 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 	BeforeEach(func() {
 		const OSWindows = "windows"
 		virtClient = kubevirt.Client()
-		checks.SkipIfMissingRequiredImage(virtClient, libvmi.WindowsPVCName)
+		checks.SkipIfMissingRequiredImage(virtClient, libvmifact.WindowsPVCName)
 		libstorage.CreatePVC(OSWindows, testsuite.GetTestNamespace(nil), "30Gi", libstorage.Config.StorageClassWindows, true)
-		windowsVMI = libvmi.NewWindows(libvmi.WithMasqueradeNetworking()...)
+		windowsVMI = libvmifact.NewWindows(libnet.WithMasqueradeNetworking()...)
 		windowsVMI.Spec.Domain.Devices.Interfaces[0].Model = "e1000"
 	})
 
@@ -97,7 +99,7 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 				Expect(err).ToNot(HaveOccurred())
 				libwait.WaitForSuccessfulVMIStart(windowsVMI)
 
-				cli = winrnLoginCommand(virtClient, windowsVMI)
+				cli = winrnLoginCommand(windowsVMI)
 			})
 
 			It("[test_id:240]should have correct UUID", func() {
@@ -107,7 +109,6 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 				Eventually(func() error {
 					var err error
 					output, err = exec.ExecuteCommandOnPod(
-						virtClient,
 						winrmcliPod,
 						winrmcliPod.Spec.Containers[0].Name,
 						command,
@@ -115,7 +116,7 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 					return err
 				}, time.Minute*5, time.Second*15).ShouldNot(HaveOccurred())
 				By("Checking that the Windows VirtualMachineInstance has expected UUID")
-				Expect(output).Should(ContainSubstring(strings.ToUpper(libvmi.WindowsFirmware)))
+				Expect(output).Should(ContainSubstring(strings.ToUpper(libvmifact.WindowsFirmware)))
 			})
 
 			It("[test_id:3159]should have default masquerade IP", func() {
@@ -125,7 +126,6 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 				Eventually(func() error {
 					var err error
 					output, err = exec.ExecuteCommandOnPod(
-						virtClient,
 						winrmcliPod,
 						winrmcliPod.Spec.Containers[0].Name,
 						command,
@@ -141,7 +141,7 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 				searchDomain := getPodSearchDomain(windowsVMI)
 				Expect(searchDomain).To(HavePrefix(windowsVMI.Namespace), "should contain a searchdomain with the namespace of the VMI")
 
-				runCommandAndExpectOutput(virtClient,
+				runCommandAndExpectOutput(
 					winrmcliPod,
 					cli,
 					"wmic nicconfig get dnsdomain",
@@ -159,7 +159,7 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 				Expect(err).ToNot(HaveOccurred())
 				libwait.WaitForSuccessfulVMIStart(windowsVMI)
 
-				cli = winrnLoginCommand(virtClient, windowsVMI)
+				cli = winrnLoginCommand(windowsVMI)
 			})
 
 			It("should have the domain set properly with subdomain", func() {
@@ -167,7 +167,7 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 				Expect(searchDomain).To(HavePrefix(windowsVMI.Namespace), "should contain a searchdomain with the namespace of the VMI")
 
 				expectedSearchDomain := windowsVMI.Spec.Subdomain + "." + searchDomain
-				runCommandAndExpectOutput(virtClient,
+				runCommandAndExpectOutput(
 					winrmcliPod,
 					cli,
 					"wmic nicconfig get dnsdomain",
@@ -186,7 +186,7 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 					libwait.WithTimeout(420),
 				)
 
-				cli = winrnLoginCommand(virtClient, windowsVMI)
+				cli = winrnLoginCommand(windowsVMI)
 			})
 
 			It("should be recognized by other pods in cluster", func() {
@@ -198,7 +198,8 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 				Expect(err).ToNot(HaveOccurred())
 
 				getVirtHandlerPod := func() (*k8sv1.Pod, error) {
-					winVmiPod := tests.GetRunningPodByVirtualMachineInstance(windowsVMI, windowsVMI.Namespace)
+					winVmiPod, err := libpod.GetPodByVirtualMachineInstance(windowsVMI, windowsVMI.Namespace)
+					Expect(err).NotTo(HaveOccurred())
 					nodeName := winVmiPod.Spec.NodeName
 
 					pod, err := libnode.GetVirtHandlerPod(virtClient, nodeName)
@@ -218,7 +219,6 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 				By(fmt.Sprintf("Running \"%s\" command via winrm-cli", command))
 				Eventually(func() error {
 					_, err = exec.ExecuteCommandOnPod(
-						virtClient,
 						winrmcliPod,
 						winrmcliPod.Spec.Containers[0].Name,
 						command,
@@ -230,9 +230,9 @@ var _ = Describe("[Serial][sig-compute]Windows VirtualMachineInstance", Serial,
 	})
 })
 
-func winrnLoginCommand(virtClient kubecli.KubevirtClient, windowsVMI *v1.VirtualMachineInstance) []string {
+func winrnLoginCommand(windowsVMI *v1.VirtualMachineInstance) []string {
 	var err error
-	windowsVMI, err = virtClient.VirtualMachineInstance(windowsVMI.Namespace).Get(context.Background(), windowsVMI.Name, metav1.GetOptions{})
+	windowsVMI, err = kubevirt.Client().VirtualMachineInstance(windowsVMI.Namespace).Get(context.Background(), windowsVMI.Name, metav1.GetOptions{})
 	ExpectWithOffset(1, err).ToNot(HaveOccurred())
 
 	vmiIp := windowsVMI.Status.Interfaces[0].IP
@@ -266,13 +266,12 @@ func getPodSearchDomain(windowsVMI *v1.VirtualMachineInstance) string {
 	return searchDomain
 }
 
-func runCommandAndExpectOutput(virtClient kubecli.KubevirtClient, winrmcliPod *k8sv1.Pod, cli []string, command, expectedOutputRegex string) {
+func runCommandAndExpectOutput(winrmcliPod *k8sv1.Pod, cli []string, command, expectedOutputRegex string) {
 	cliCmd := append(cli, command)
 	By(fmt.Sprintf("Running \"%s\" command via winrm-cli", cliCmd))
 	By("first making sure that we can execute VMI commands")
 	EventuallyWithOffset(1, func() error {
 		_, err := exec.ExecuteCommandOnPod(
-			virtClient,
 			winrmcliPod,
 			winrmcliPod.Spec.Containers[0].Name,
 			cliCmd,
@@ -283,7 +282,6 @@ func runCommandAndExpectOutput(virtClient kubecli.KubevirtClient, winrmcliPod *k
 	By("repeatedly trying to get the search domain, since it may take some time until the domain is set")
 	EventuallyWithOffset(1, func() string {
 		output, err := exec.ExecuteCommandOnPod(
-			virtClient,
 			winrmcliPod,
 			winrmcliPod.Spec.Containers[0].Name,
 			cliCmd,
@@ -308,7 +306,7 @@ func isTSCFrequencyExposed(virtClient kubecli.KubevirtClient) bool {
 
 func removeTSCFrequencyFromNode(node k8sv1.Node) {
 	for _, baseLabelToRemove := range []string{topology.TSCFrequencyLabel, topology.TSCFrequencySchedulingLabel} {
-		for key, _ := range node.Labels {
+		for key := range node.Labels {
 			if strings.HasPrefix(key, baseLabelToRemove) {
 				libnode.RemoveLabelFromNode(node.Name, key)
 			}
